// Copyright (c) 1994-2009 Nokia Corporation and/or its subsidiary(-ies).
// All rights reserved.
// This component and the accompanying materials are made available
// under the terms of the License "Eclipse Public License v1.0"
// which accompanies this distribution, and is available
// at the URL "http://www.eclipse.org/legal/epl-v10.html".
//
// Initial Contributors:
// Nokia Corporation - initial contribution.
//
// Contributors:
//
// Description:
// e32test\buffer\t_collate.cpp
// Overview:
// Test Unicode collations.
// API Information:
// CompareC, TCollationMethod, TCollationKeyTable.
// Details:
// - Check the collation for characters, accents, different cases and standard 
// alphabetical ordering is as expected.
// - Check collation using standard collation method, overriding the collation tables, 
// collation keys is as expected.
// - Check collation for simplified Chinese characters is as expected.
// - Check collation and compare the Chinese ideological characters to other 
// characters which are not included in the Chinese collation table are as expected.
// - Check collation and compare Chinese to English alphabets.
// - Check collation and compare Chinese to Hiragana characters.
// - Check collation and compare Chinese to Katakana characters.
// - Check collation and compare Hiragana to a Katakana characters.
// - Check collation and compare full width and half width digits and letters.
// - Set the current collation key table to standard table, collation keys to default keys,
// constants to specified values, compare data and check it is as expected.
// Platforms/Drives/Compatibility:
// All 
// Assumptions/Requirement/Pre-requisites:
// Failures and causes:
// Base Port information:
// 
//

#include <e32test.h>
#include <collate.h>	  
#include "../../e32/euser/unicode/collateimp.h"
#include <u32std.h>

#ifdef __VC32__
    // Solve compilation problem caused by non-English locale
    #pragma setlocale("english")
#endif

LOCAL_D RTest test(_L("T_COLLATE"));


#ifndef _DEBUG
#pragma warning (disable :4710) //Function not expanded 
#pragma warning (disable :4700) //Local variable used without being initialized
#endif

///***************** copied from locale euser source code ***********************
#ifndef __TOOLS2__
static const TCollationMethod TheCollationMethod[] =
	{
		{
		KUidBasicCollationMethod,				// this is the standard unlocalised method
		NULL,									// null means use the standard table
		NULL,									// there's no override table
		0										// the flags are standard
		}
	};
static const TCollationDataSet TheCollationDataSet =
	{
	TheCollationMethod,
	1
	};
const LCharSet TheCharSet =
	{
	NULL,
	&TheCollationDataSet
	};
const LCharSet* GetLocaleCharSet()
	{
	return &TheCharSet;
	}
#endif
///*******************************************************************************




void test_unicode_collation(const TDesC& x,const TDesC& y,TInt desired_order,
							TInt level = 3,const TCollationMethod* method = NULL)
	{
	TInt order = x.CompareC(y,level,method);

	// Normalise order to -1, 0 or 1.
	if (order < 0)
		order = -1;
	else if (order > 0)
		order = 1;

	test(order == desired_order);
	}

static const TUint32 TheSwedishKey[] = 
	{
	0x8f60109,0x8f70109,0x8f80109,0x8f60121,0x8f70121,0x8f80121,0x8dd0109,0x8dd0121,
	0x8c50121,0x8c50109,
	};

static const TUint32 TheSwedishIndex[] = 
	{
	0x570008,0x770009,
	};

static const TUint16 TheSwedishStringElement[] = 
	{
	0x2,0x61,0x30a,0x2,0x61,0x308,0x2,0x6f,
	0x308,0x2,0x41,0x30a,0x2,0x41,0x308,0x2,
	0x4f,0x308,0x2,0x75,0x308,0x2,0x55,0x308,
	};

static const TUint32 TheSwedishStringIndex[] = 
	{
	0xc0004,0x90003,0xf0005,0x150007,0x30001,0x0,0x60002,0x120006,
	};

static const TCollationKeyTable TheSwedishTable = 
	{ TheSwedishKey, TheSwedishIndex, 2, TheSwedishStringElement, TheSwedishStringIndex, 8 };

static const TCollationMethod TheSwedishMethod =
	{ 0, NULL, &TheSwedishTable, 0 };

static const TCollationMethod TheSwapCaseMethod =
	{ 0, NULL, NULL, TCollationMethod::ESwapCase };

static const TUint32 TheKanaKey[] = 
	{
	0x102c013c,0xc949,0x103f013c,0xc949,0x1044013c,0xc949,0x1049013c,0xc949,
	0x104e013c,0xc949,0x1053013c,0xc949,0x1058013c,0xc949,0x105d013c,0xc949,
	0x1062013c,0xc949,0x1067013c,0xc949,0x106c013c,0xc949,0x1071013c,0xc949,
	0x1076013c,0xc949,0x107b013c,0xc949,0x1083013c,0xc949,0x1088013c,0xc949,
	0x109c013c,0xc949,0x10a3013c,0xc949,0x10aa013c,0xc949,0x10b1013c,0xc949,
	0x10b8013c,0xc949,0x109c013c,0xca49,0x10a3013c,0xca49,0x10aa013c,0xca49,
	0x10b1013c,0xca49,0x10b8013c,0xca49,0x10200134,0x10200135,0x10260134,0x10260135,
	0x102c0134,0x102c0135,0x10330134,0x10330135,0x10390134,0x10390135,0x103f0134,0x10200135,
	0x10440134,0x10260135,0x10490134,0x102c0135,0x104e0134,0x10330135,0x10530134,0x10390135,
	0x103f0134,0xc948,0x10200135,0x10440134,0xc948,0x10260135,0x10490134,0xc948,
	0x102c0135,0x104e0134,0xc948,0x10330135,0x10530134,0xc948,0x10390135,0x10580134,
	0x10200135,0x105d0134,0x10260135,0x10620134,0x102c0135,0x10670134,0x10330135,0x106c0134,
	0x10390135,0x10580134,0xc948,0x10200135,0x105d0134,0xc948,0x10260135,0x10620134,
	0xc948,0x102c0135,0x10670134,0xc948,0x10330135,0x106c0134,0xc948,0x10390135,
	0x10710134,0x10200135,0x10760134,0x10260135,0x107b0134,0x102c0135,0x10830134,0x10330135,
	0x10880134,0x10390135,0x10710134,0xc948,0x10200135,0x10760134,0xc948,0x10260135,
	0x107b0134,0xc948,0x102c0135,0x10830134,0xc948,0x10330135,0x10880134,0xc948,
	0x10390135,0x108d0134,0x10200135,0x10900134,0x10260135,0x10930134,0x102c0135,0x10960134,
	0x10330135,0x10990134,0x10390135,0x109c0134,0x10200135,0x10a30134,0x10260135,0x10aa0134,
	0x102c0135,0x10b10134,0x10330135,0x10b80134,0x10390135,0x109c0134,0xc948,0x10200135,
	0x10a30134,0xc948,0x10260135,0x10aa0134,0xc948,0x102c0135,0x10b10134,0xc948,
	0x10330135,0x10b80134,0xc948,0x10390135,0x109c0134,0xca08,0x10200135,0x10a30134,
	0xca08,0x10260135,0x10aa0134,0xca08,0x102c0135,0x10b10134,0xca08,0x10330135,
	0x10b80134,0xca08,0x10390135,0x10bf0134,0x10200135,0x10c20134,0x10260135,0x10c50134,
	0x102c0135,0x10c80134,0x10330135,0x10cb0134,0x10390135,0x10ce0134,0x10200135,0x10d40134,
	0x102c0135,0x10da0134,0x10390135,0x10e00134,0x10200135,0x10e30134,0x10260135,0x10e60134,
	0x102c0135,0x10e90134,0x10330135,0x10ec0134,0x10390135,0x10ef0134,0x10200135,0x103f0144,
	0x10200145,0x10440144,0x10260145,0x10490144,0x102c0145,0x104e0144,0x10330145,0x10530144,
	0x10390145,0x103f0144,0xc948,0x10200145,0x10440144,0xc948,0x10260145,0x10490144,
	0xc948,0x102c0145,0x104e0144,0xc948,0x10330145,0x10530144,0xc948,0x10390145,
	0x10580144,0x10200145,0x105d0144,0x10260145,0x10620144,0x102c0145,0x10670144,0x10330145,
	0x106c0144,0x10390145,0x10580144,0xc948,0x10200145,0x105d0144,0xc948,0x10260145,
	0x10620144,0xc948,0x102c0145,0x10670144,0xc948,0x10330145,0x106c0144,0xc948,
	0x10390145,0x10710144,0x10200145,0x10760144,0x10260145,0x107b0144,0x102c0145,0x10830144,
	0x10330145,0x10880144,0x10390145,0x10710144,0xc948,0x10200145,0x10760144,0xc948,
	0x10260145,0x107b0144,0xc948,0x102c0145,0x10830144,0xc948,0x10330145,0x10880144,
	0xc948,0x10390145,0x108d0144,0x10200145,0x10900144,0x10260145,0x10930144,0x102c0145,
	0x10960144,0x10330145,0x10990144,0x10390145,0x109c0144,0x10200145,0x10a30144,0x10260145,
	0x10aa0144,0x102c0145,0x10b10144,0x10330145,0x10b80144,0x10390145,0x109c0144,0xc948,
	0x10200145,0x10a30144,0xc948,0x10260145,0x10aa0144,0xc948,0x102c0145,0x10b10144,
	0xc948,0x10330145,0x10b80144,0xc948,0x10390145,0x109c0144,0xca08,0x10200145,
	0x10a30144,0xca08,0x10260145,0x10aa0144,0xca08,0x102c0145,0x10b10144,0xca08,
	0x10330145,0x10b80144,0xca08,0x10390145,0x10bf0144,0x10200145,0x10c20144,0x10260145,
	0x10c50144,0x102c0145,0x10c80144,0x10330145,0x10cb0144,0x10390145,0x10ce0144,0x10200145,
	0x10d40144,0x102c0145,0x10da0144,0x10390145,0x10e00144,0x10200145,0x10e30144,0x10260145,
	0x10e60144,0x102c0145,0x10e90144,0x10330145,0x10ec0144,0x10390145,0x10ef0144,0x10200145,
	0x10f40144,0x10260145,0x10f60144,0x10330145,0x10f80144,0x10390145,0x10ef0144,0xc948,
	0x10200145,0x10f40144,0xc948,0x10260145,0x102c0144,0xc948,0x102c0145,0x10f60144,
	0xc948,0x10330145,0x10f80144,0xc948,0x10390145,0x103f013c,0x1020013d,0x1044013c,
	0x1026013d,0x1049013c,0x102c013d,0x104e013c,0x1033013d,0x1053013c,0x1039013d,0x103f013c,
	0xc948,0x1020013d,0x1044013c,0xc948,0x1026013d,0x1049013c,0xc948,0x102c013d,
	0x104e013c,0xc948,0x1033013d,0x1053013c,0xc948,0x1039013d,0x1058013c,0x1020013d,
	0x105d013c,0x1026013d,0x1062013c,0x102c013d,0x1067013c,0x1033013d,0x106c013c,0x1039013d,
	0x1058013c,0xc948,0x1020013d,0x105d013c,0xc948,0x1026013d,0x1062013c,0xc948,
	0x102c013d,0x1067013c,0xc948,0x1033013d,0x106c013c,0xc948,0x1039013d,0x1071013c,
	0x1020013d,0x1076013c,0x1026013d,0x107b013c,0x102c013d,0x1083013c,0x1033013d,0x1088013c,
	0x1039013d,0x1071013c,0xc948,0x1020013d,0x1076013c,0xc948,0x1026013d,0x107b013c,
	0xc948,0x102c013d,0x1083013c,0xc948,0x1033013d,0x1088013c,0xc948,0x1039013d,
	0x108d013c,0x1020013d,0x1090013c,0x1026013d,0x1093013c,0x102c013d,0x1096013c,0x1033013d,
	0x1099013c,0x1039013d,0x109c013c,0x1020013d,0x10a3013c,0x1026013d,0x10aa013c,0x102c013d,
	0x10b1013c,0x1033013d,0x10b8013c,0x1039013d,0x109c013c,0xc948,0x1020013d,0x10a3013c,
	0xc948,0x1026013d,0x10aa013c,0xc948,0x102c013d,0x10b1013c,0xc948,0x1033013d,
	0x10b8013c,0xc948,0x1039013d,0x109c013c,0xca48,0x1020013d,0x10a3013c,0xca48,
	0x1026013d,0x10aa013c,0xca48,0x102c013d,0x10b1013c,0xca48,0x1033013d,0x10b8013c,
	0xca48,0x1039013d,0x10bf013c,0x1020013d,0x10c2013c,0x1026013d,0x10c5013c,0x102c013d,
	0x10c8013c,0x1033013d,0x10cb013c,0x1039013d,0x10ce013c,0x1020013d,0x10d4013c,0x102c013d,
	0x10da013c,0x1039013d,0x10e0013c,0x1020013d,0x10e3013c,0x1026013d,0x10e6013c,0x102c013d,
	0x10e9013c,0x1033013d,0x10ec013c,0x1039013d,0x10ef013c,0x1020013d,0x10ef013c,0xc948,
	0x1020013d,0xca09,0x2010f,0x20113,0x4010b,0x4010f,0x5010b,0x5010f,
	0x8010b,0x8010f,0xa010f,0xa014b,0xc010b,0xc010f,0xe010b,0xe010f,
	0xe013f,0x10010b,0x10010f,0x12010b,0x12010f,0x14c90b,0x14c90f,0x16ca0b,
	0x16ca0f,0x17010b,0x18030f,0x1a060b,0x1a060f,0x1c160f,0x1e0d0b,0x1e0d0f,
	0x20290f,0x22020b,0x22020f,0x24010d,0x28010d,0x2c010d,0x2e010d,0x30010d,
	0x32010d,0x34010d,0x36010b,0x36010f,0x38010f,0x3a010f,0x3c0109,0x3c010d,
	0x3e0109,0x3e010d,0x40010d,0x400109,0x42010d,0x440109,0x44010d,0x46010d,
	0x48010d,0x4a010f,0x4c010f,0x4e010b,0x4f010b,0x50010b,0x50010f,0x52010b,
	0x52010f,0x54010b,0x56010b,0x58010b,0x58010f,0x5a010b,0x5a010f,0x5c010b,
	0x5c010f,0x5e010b,0x5e010f,0x60010b,0x62010b,0x64010b,0x66010b,0x68010f,
	0x68010b,0x6a010f,0x6a010b,0x6c010b,0x6e010b,0x6f010b,0x70010b,0x72010b,
	0x72010f,0x74010b,0x74010f,0x76010f,0x78010f,0x7a010f,0x7c010b,0x7c010f,
	0x80010b,0x80010f,0x82010b,0x82010f,0x84010f,0x86010f,0x88010f,0x8a010f,
	0x8c010b,0x8e010f,0x90010f,0x92010f,0x94010d,0x960109,0x96010d,0x980109,
	0x98010d,0x9a010d,0x9c0109,0x9c010d,0x9e010b,0x9e010f,0x100010b,0x100010f,
	0x102010b,0x102010f,0x104010b,0x104010f,0x106010b,0x106010f,0x107010f,0x108010f,
	0x109010f,0x10a010f,0x10b010f,0x10c010f,0x10d010f,0x10e010f,0x10f010f,0x110010f,
	0x111010f,0x112010f,0x113010f,0x114010f,0x115010f,0x116010f,0x117010f,0x118010f,
	0x119010f,0x11a010f,0x11b010f,0x11c010f,0x11d010f,0x11e010f,0x11f010f,0x120010f,
	0x121010f,0x122010f,0x123010f,0x124010f,0x125010f,0x126010f,0x127010f,0x128010f,
	0x129010f,0x12a010f,0x12b010f,0x12c010f,0x12d010f,0x12e010f,0x12f010f,0x130010f,
	0x131010f,0x132010f,0x133010f,0x134010f,0x135010f,0x136010f,0x137010f,0x138010f,
	0x139010f,0x13b010f,0x13c010d,0x13d010d,0x13e010f,0x13f010f,0x140010f,0x141010f,
	0x142010f,0x143010d,0x144010d,0x145010d,0x146010d,0x147010d,0x148010d,0x149010d,
	0x14a010d,0x14b010d,0x14c010d,0x14d010d,0x14e010d,0x14f010d,0x150010d,0x151010d,
	0x152010d,0x153010d,0x154010d,0x155010d,0x156010d,0x157010d,0x158010d,0x159010d,
	0x15a010d,0x15b010d,0x15c010d,0x15d010d,0x15e010d,0x15f010d,0x160010f,0x161010f,
	0x162010f,0x163010f,0x164010f,0x165010f,0x166010f,0x167010f,0x168010f,0x169010f,
	0x16a010f,0x16b010f,0x16c010f,0x16d010f,0x16e010f,0x16f010f,0x170010f,0x171010f,
	0x172010f,0x174010f,0x175010f,0x176010f,0x177010f,0x178010f,0x179010f,0x17a010d,
	0x17b010d,0x17c010d,0x17d0119,0x17e0119,0x17f0119,0x1800119,0x1810119,0x182010d,
	0x183010d,0x184010d,0x185010d,0x186010d,0x187010d,0x189010f,0x18a010f,0x18b010f,
	0x18c010f,0x18d0111,0x18e0111,0x18f0111,0x1900111,0x1910111,0x1920111,0x1930111,
	0x1940111,0x1950111,0x1960111,0x197010f,0x198010f,0x199010b,0x199010f,0x6c50109,
	0x6c60109,0x6c70109,0x6c80109,0x6c90109,0x6ca0109,0x6cb0109,0x6cc0109,0x6cd0109,
	0x6ce0109,0x6cf0109,0x6cf010d,0x6cf0121,0x6cf0125,0x6e30109,0x6e3010d,0x6e30121,
	0x6e30125,0x6fb0109,0x6fb010d,0x6fb0121,0x6fb0125,0x7070109,0x707010d,0x7070121,
	0x7070125,0x72f0109,0x72f010d,0x72f0121,0x72f0125,0x75b0109,0x75b010d,0x75b0121,
	0x75b0125,0x7630109,0x763010d,0x7630121,0x7630125,0x7830109,0x783010d,0x7830121,
	0x7830125,0x79d0109,0x79d010d,0x79d0121,0x79d0125,0x7b10109,0x7b1010d,0x7b10121,
	0x7b10125,0x7c10109,0x7c1010d,0x7c10121,0x7c10125,0x7cd0109,0x7cd010d,0x7cd0121,
	0x7cd0125,0x7f50109,0x7f5010d,0x7f50121,0x7f50125,0x7fd0109,0x7fd010d,0x7fd0121,
	0x7fd0125,0x8150109,0x815010d,0x8150121,0x8150125,0x82d0109,0x82d010d,0x82d0121,
	0x82d0125,0x8390109,0x839010d,0x8390121,0x8390125,0x8450109,0x845010d,0x8450121,
	0x8450125,0x86d0109,0x86d010d,0x86d0121,0x86d0125,0x8890109,0x889010d,0x8890121,
	0x8890125,0x8ad0109,0x8ad010d,0x8ad0121,0x8ad0125,0x8c50109,0x8c5010d,0x8c50121,
	0x8c50125,0x8d10109,0x8d1010d,0x8d10121,0x8d10125,0x8d90109,0x8d9010d,0x8d90121,
	0x8d90125,0x8dd0109,0x8dd010d,0x8dd0121,0x8dd0125,0x8e90109,0x8e9010d,0x8e90121,
	0x8e90125,0x10200139,0x10200149,0x10200141,0x10260139,0x10260149,0x10260141,0x102c0139,
	0x102c0149,0x102c0141,0x10330139,0x10330149,0x10330141,0x10390139,0x10390149,0x10390141,
	0x103f0135,0x103f0145,0x103f013d,0x10440135,0x10440145,0x1044013d,0x10490135,0x10490145,
	0x1049013d,0x104e0135,0x104e0145,0x104e013d,0x10530135,0x10530145,0x1053013d,0x10580135,
	0x10580145,0x1058013d,0x105d0135,0x105d0145,0x105d013d,0x10620135,0x10620145,0x1062013d,
	0x10670135,0x10670145,0x1067013d,0x106c0135,0x106c0145,0x106c013d,0x10710135,0x10710145,
	0x1071013d,0x10760135,0x10760145,0x1076013d,0x107b0139,0x107b0135,0x107b0149,0x107b0141,
	0x107b0145,0x107b013d,0x10830135,0x10830145,0x1083013d,0x10880135,0x10880145,0x1088013d,
	0x108d0135,0x108d0145,0x108d013d,0x10900135,0x10900145,0x1090013d,0x10930135,0x10930145,
	0x1093013d,0x10960135,0x10960145,0x1096013d,0x10990135,0x10990145,0x1099013d,0x109c0135,
	0x109c0145,0x109c013d,0x10a30135,0x10a30145,0x10a3013d,0x10aa0135,0x10aa0145,0x10aa013d,
	0x10b10135,0x10b10145,0x10b1013d,0x10b80135,0x10b80145,0x10b8013d,0x10bf0135,0x10bf0145,
	0x10bf013d,0x10c20135,0x10c20145,0x10c2013d,0x10c50135,0x10c50145,0x10c5013d,0x10c80135,
	0x10c80145,0x10c8013d,0x10cb0135,0x10cb0145,0x10cb013d,0x10ce0139,0x10ce0135,0x10ce0149,
	0x10ce0141,0x10ce0145,0x10ce013d,0x10d40139,0x10d40135,0x10d40149,0x10d40141,0x10d40145,
	0x10d4013d,0x10da0139,0x10da0135,0x10da0149,0x10da0141,0x10da0145,0x10da013d,0x10e00135,
	0x10e00145,0x10e0013d,0x10e30135,0x10e30145,0x10e3013d,0x10e60135,0x10e60145,0x10e6013d,
	0x10e90135,0x10e90145,0x10e9013d,0x10ec0135,0x10ec0145,0x10ec013d,0x10ef0139,0x10ef0135,
	0x10ef0149,0x10ef0145,0x10ef013d,0x10f40135,0x10f40145,0x10f60135,0x10f60145,0x10f80135,
	0x10f80145,0x10f8013d,0x10fb0135,0x10fb0145,
	};

static const TUint32 TheKanaIndex[] = 
	{
	0x210233,0x22032d,0x230296,0x24028f,0x250294,0x260298,0x270239,0x28025d,
	0x29025f,0x2a029a,0x2b0277,0x2c0226,0x2d0279,0x2e0228,0x2f024e,0x30032f,
	0x310330,0x320331,0x330332,0x340333,0x350334,0x360335,0x370336,0x380337,
	0x390338,0x3a022c,0x3b022e,0x3c0280,0x3d027e,0x3e0282,0x3f0231,0x40029c,
	0x41033b,0x42033f,0x430343,0x440347,0x45034b,0x46034f,0x470353,0x480357,
	0x49035b,0x4a035f,0x4b0363,0x4c0367,0x4d036b,0x4e036f,0x4f0373,0x500377,
	0x51037b,0x52037f,0x530383,0x540387,0x55038b,0x56038f,0x570393,0x580397,
	0x59039b,0x5a039f,0x5b0263,0x5c0250,0x5d0265,0x5e023e,0x5f0241,0x60023b,
	0x610339,0x62033d,0x630341,0x640345,0x650349,0x66034d,0x670351,0x680355,
	0x690359,0x6a035d,0x6b0361,0x6c0365,0x6d0369,0x6e036d,0x6f0371,0x700375,
	0x710379,0x72037d,0x730381,0x740385,0x750389,0x76038d,0x770391,0x780395,
	0x790399,0x7a039d,0x7b0267,0x7c0255,0x7d0269,0x7e0253,0xa20291,0xa30292,
	0xa5028d,0xa7029e,0xa8023d,0xb00289,0xb1027b,0xb4023a,0xb602d7,0xd7027c,
	0xf7027d,0x2010024d,0x2015024c,0x20180259,0x2019025a,0x201c025b,0x201d025c,0x202002d5,
	0x202102d6,0x20250258,0x20260257,0x203002d1,0x2032028a,0x2033028b,0x203b02ac,0x2103028c,
	0x2116030f,0x21210311,0x216002ec,0x216102ed,0x216202ee,0x216302ef,0x216402f0,0x216502f1,
	0x216602f2,0x216702f3,0x216802f4,0x216902f5,0x21700321,0x21710322,0x21720323,0x21730324,
	0x21740325,0x21750326,0x21760327,0x21770328,0x21780329,0x2179032a,0x219002af,0x219102b0,
	0x219202ae,0x219302b1,0x21d202be,0x21d402bf,0x220002c0,0x220202c5,0x220302c1,0x220702c6,
	0x220802b3,0x220b02b4,0x2211031e,0x2212027a,0x221a02cb,0x221d02cd,0x221e0286,0x221f031f,
	0x222002c2,0x22250254,0x222702bb,0x222802bc,0x222902ba,0x222a02b9,0x222b02cf,0x222c02d0,
	0x222e031d,0x22340286,0x223502ce,0x223d02cc,0x225202c8,0x226102c7,0x22660284,0x22670285,
	0x226a02c9,0x226b02ca,0x228202b7,0x228302b8,0x228602b5,0x228702b6,0x22a502c3,0x22bf0320,
	0x231202c4,0x246002d9,0x246102da,0x246202db,0x246302dc,0x246402dd,0x246502de,0x246602df,
	0x246702e0,0x246802e1,0x246902e2,0x246a02e3,0x246b02e3,0x246c02e4,0x246d02e5,0x246e02e6,
	0x246f02e7,0x247002e8,0x247102e9,0x247202ea,0x247302eb,0x25a002a7,0x25a102a6,0x25b202a9,
	0x25b302a8,0x25bc02ab,0x25bd02aa,0x25c602a5,0x25c702a4,0x25cb02a1,0x25ce02a3,0x25cf02a2,
	0x25ef02d8,0x260502a0,0x2606029f,0x26400288,0x26420287,0x266a02d4,0x266d02d3,0x266f02d2,
	0x30010223,0x30020225,0x30030245,0x30050247,0x30060248,0x30070249,0x3008026b,0x3009026c,
	0x300a026d,0x300b026e,0x300c026f,0x300d0271,0x300e0273,0x300f0274,0x30100275,0x30110276,
	0x301202ad,0x301302b2,0x30140261,0x30150262,0x301c0252,0x301d030d,0x301f030e,0x304103a1,
	0x304200d6,0x304303a4,0x304400ce,0x304503a7,0x304600d0,0x304703aa,0x304800d2,0x304903ad,
	0x304a00d4,0x304b03b0,0x304d03b3,0x304f03b6,0x305103b9,0x305303bc,0x305503bf,0x305703c2,
	0x305903c5,0x305b03c8,0x305d03cb,0x305f03ce,0x306103d1,0x306303d4,0x306403d5,0x306603da,
	0x306803dd,0x306a03e0,0x306b03e3,0x306c03e6,0x306d03e9,0x306e03ec,0x306f03ef,0x307203f2,
	0x307503f5,0x307803f8,0x307b03fb,0x307e03fe,0x307f0401,0x30800404,0x30810407,0x3082040a,
	0x3083040d,0x3084040e,0x30850413,0x30860414,0x30870419,0x3088041a,0x3089041f,0x308a0422,
	0x308b0425,0x308c0428,0x308d042b,0x308e042e,0x308f042f,0x30900433,0x30910435,0x30920437,
	0x3093043a,0x30990029,0x309a0221,0x309b0236,0x309c0238,0x309d0244,0x30a103a2,0x30a20178,
	0x30a303a5,0x30a4017b,0x30a503a8,0x30a6017e,0x30a703ab,0x30a80181,0x30a903ae,0x30aa0184,
	0x30ab03b1,0x30ad03b4,0x30af03b7,0x30b103ba,0x30b303bd,0x30b503c0,0x30b703c3,0x30b903c6,
	0x30bb03c9,0x30bd03cc,0x30bf03cf,0x30c103d2,0x30c303d6,0x30c403d8,0x30c603db,0x30c803de,
	0x30ca03e1,0x30cb03e4,0x30cc03e7,0x30cd03ea,0x30ce03ed,0x30cf03f0,0x30d203f3,0x30d503f6,
	0x30d803f9,0x30db03fc,0x30de03ff,0x30df0402,0x30e00405,0x30e10408,0x30e2040b,0x30e3040f,
	0x30e40411,0x30e50415,0x30e60417,0x30e7041b,0x30e8041d,0x30e90420,0x30ea0423,0x30eb0426,
	0x30ec0429,0x30ed042c,0x30ee0430,0x30ef0431,0x30f00434,0x30f10436,0x30f20438,0x30f3043b,
	0x30fb022a,0x30fc024b,0x30fd0243,0x32310317,0x32320318,0x32390319,0x32a40312,0x32a50313,
	0x32a60314,0x32a70315,0x32a80316,0x330302fc,0x330d0300,0x331402f7,0x331802fa,0x332202f8,
	0x33230302,0x33260301,0x332702fb,0x332b0303,0x333602fd,0x333b0305,0x334902f6,0x334a0304,
	0x334d02f9,0x335102fe,0x335702ff,0x337b030c,0x337c031c,0x337d031b,0x337e031a,0x338f0309,
	0x339c0306,0x339d0307,0x339e0308,0x33a1030b,0x33c4030a,0x33cd0310,0x4edd0246,0xfe540230,
	0xff010234,0xff02032e,0xff030297,0xff040290,0xff050295,0xff060299,0xff07032c,0xff08025e,
	0xff090260,0xff0a029b,0xff0b0278,0xff0c0227,0xff0d027a,0xff0e0229,0xff0f024f,0xff1a022d,
	0xff1b022f,0xff1c0281,0xff1d027f,0xff1e0283,0xff1f0232,0xff20029d,0xff21033c,0xff220340,
	0xff230344,0xff240348,0xff25034c,0xff260350,0xff270354,0xff280358,0xff29035c,0xff2a0360,
	0xff2b0364,0xff2c0368,0xff2d036c,0xff2e0370,0xff2f0374,0xff300378,0xff31037c,0xff320380,
	0xff330384,0xff340388,0xff35038c,0xff360390,0xff370394,0xff380398,0xff39039c,0xff3a03a0,
	0xff3b0264,0xff3c0251,0xff3d0266,0xff3e023f,0xff3f0242,0xff40023c,0xff41033a,0xff42033e,
	0xff430342,0xff440346,0xff45034a,0xff46034e,0xff470352,0xff480356,0xff49035a,0xff4a035e,
	0xff4b0362,0xff4c0366,0xff4d036a,0xff4e036e,0xff4f0372,0xff500376,0xff51037a,0xff52037e,
	0xff530382,0xff540386,0xff55038a,0xff56038e,0xff570392,0xff580396,0xff59039a,0xff5a039e,
	0xff5b0268,0xff5c0256,0xff5d026a,0xff5e0252,0xff610224,0xff620270,0xff630272,0xff640222,
	0xff65022b,0xff660439,0xff6703a3,0xff6803a6,0xff6903a9,0xff6a03ac,0xff6b03af,0xff6c0410,
	0xff6d0416,0xff6e041c,0xff6f03d7,0xff70024a,0xff710220,0xff720215,0xff730217,0xff740219,
	0xff75021b,0xff7603b2,0xff7703b5,0xff7803b8,0xff7903bb,0xff7a03be,0xff7b03c1,0xff7c03c4,
	0xff7d03c7,0xff7e03ca,0xff7f03cd,0xff8003d0,0xff8103d3,0xff8203d9,0xff8303dc,0xff8403df,
	0xff8503e2,0xff8603e5,0xff8703e8,0xff8803eb,0xff8903ee,0xff8a03f1,0xff8b03f4,0xff8c03f7,
	0xff8d03fa,0xff8e03fd,0xff8f0400,0xff900403,0xff910406,0xff920409,0xff93040c,0xff940412,
	0xff950418,0xff96041e,0xff970421,0xff980424,0xff990427,0xff9a042a,0xff9b042d,0xff9c0432,
	0xff9e0235,0xff9f0237,0xffe00291,0xffe10293,0xffe202bd,0xffe30240,0xffe4032b,0xffe5028e,
	};

static const TUint16 TheKanaStringElement[] = 
	{
	0x2,0xff73,0xff9e,0x2,0xff76,0xff9e,0x2,0xff77,
	0xff9e,0x2,0xff78,0xff9e,0x2,0xff79,0xff9e,0x2,
	0xff7a,0xff9e,0x2,0xff7b,0xff9e,0x2,0xff7c,0xff9e,
	0x2,0xff7d,0xff9e,0x2,0xff7e,0xff9e,0x2,0xff7f,
	0xff9e,0x2,0xff80,0xff9e,0x2,0xff81,0xff9e,0x2,
	0xff82,0xff9e,0x2,0xff83,0xff9e,0x2,0xff84,0xff9e,
	0x2,0xff8a,0xff9e,0x2,0xff8b,0xff9e,0x2,0xff8c,
	0xff9e,0x2,0xff8d,0xff9e,0x2,0xff8e,0xff9e,0x2,
	0xff8a,0xff9f,0x2,0xff8b,0xff9f,0x2,0xff8c,0xff9f,
	0x2,0xff8d,0xff9f,0x2,0xff8e,0xff9f,0x2,0x3042,
	0x30fc,0x2,0x3044,0x30fc,0x2,0x3046,0x30fc,0x2,
	0x3048,0x30fc,0x2,0x304a,0x30fc,0x2,0x304b,0x30fc,
	0x2,0x304d,0x30fc,0x2,0x304f,0x30fc,0x2,0x3051,
	0x30fc,0x2,0x3053,0x30fc,0x3,0x304b,0x3099,0x30fc,
	0x3,0x304d,0x3099,0x30fc,0x3,0x304f,0x3099,0x30fc,
	0x3,0x3051,0x3099,0x30fc,0x3,0x3053,0x3099,0x30fc,
	0x2,0x3055,0x30fc,0x2,0x3057,0x30fc,0x2,0x3059,
	0x30fc,0x2,0x305b,0x30fc,0x2,0x305d,0x30fc,0x3,
	0x3055,0x3099,0x30fc,0x3,0x3057,0x3099,0x30fc,0x3,
	0x3059,0x3099,0x30fc,0x3,0x305b,0x3099,0x30fc,0x3,
	0x305d,0x3099,0x30fc,0x2,0x305f,0x30fc,0x2,0x3061,
	0x30fc,0x2,0x3064,0x30fc,0x2,0x3066,0x30fc,0x2,
	0x3068,0x30fc,0x3,0x305f,0x3099,0x30fc,0x3,0x3061,
	0x3099,0x30fc,0x3,0x3064,0x3099,0x30fc,0x3,0x3066,
	0x3099,0x30fc,0x3,0x3068,0x3099,0x30fc,0x2,0x306a,
	0x30fc,0x2,0x306b,0x30fc,0x2,0x306c,0x30fc,0x2,
	0x306d,0x30fc,0x2,0x306e,0x30fc,0x2,0x306f,0x30fc,
	0x2,0x3072,0x30fc,0x2,0x3075,0x30fc,0x2,0x3078,
	0x30fc,0x2,0x307b,0x30fc,0x3,0x306f,0x3099,0x30fc,
	0x3,0x3072,0x3099,0x30fc,0x3,0x3075,0x3099,0x30fc,
	0x3,0x3078,0x3099,0x30fc,0x3,0x307b,0x3099,0x30fc,
	0x3,0x306f,0x309a,0x30fc,0x3,0x3072,0x309a,0x30fc,
	0x3,0x3075,0x309a,0x30fc,0x3,0x3078,0x309a,0x30fc,
	0x3,0x307b,0x309a,0x30fc,0x2,0x307e,0x30fc,0x2,
	0x307f,0x30fc,0x2,0x3080,0x30fc,0x2,0x3081,0x30fc,
	0x2,0x3082,0x30fc,0x2,0x3084,0x30fc,0x2,0x3086,
	0x30fc,0x2,0x3088,0x30fc,0x2,0x3089,0x30fc,0x2,
	0x308a,0x30fc,0x2,0x308b,0x30fc,0x2,0x308c,0x30fc,
	0x2,0x308d,0x30fc,0x2,0x308f,0x30fc,0x2,0x30ab,
	0x30fc,0x2,0x30ad,0x30fc,0x2,0x30af,0x30fc,0x2,
	0x30b1,0x30fc,0x2,0x30b3,0x30fc,0x3,0x30ab,0x3099,
	0x30fc,0x3,0x30ad,0x3099,0x30fc,0x3,0x30af,0x3099,
	0x30fc,0x3,0x30b1,0x3099,0x30fc,0x3,0x30b3,0x3099,
	0x30fc,0x2,0x30b5,0x30fc,0x2,0x30b7,0x30fc,0x2,
	0x30b9,0x30fc,0x2,0x30bb,0x30fc,0x2,0x30bd,0x30fc,
	0x3,0x30b5,0x3099,0x30fc,0x3,0x30b7,0x3099,0x30fc,
	0x3,0x30b9,0x3099,0x30fc,0x3,0x30bb,0x3099,0x30fc,
	0x3,0x30bd,0x3099,0x30fc,0x2,0x30bf,0x30fc,0x2,
	0x30c1,0x30fc,0x2,0x30c4,0x30fc,0x2,0x30c6,0x30fc,
	0x2,0x30c8,0x30fc,0x3,0x30bf,0x3099,0x30fc,0x3,
	0x30c1,0x3099,0x30fc,0x3,0x30c4,0x3099,0x30fc,0x3,
	0x30c6,0x3099,0x30fc,0x3,0x30c8,0x3099,0x30fc,0x2,
	0x30ca,0x30fc,0x2,0x30cb,0x30fc,0x2,0x30cc,0x30fc,
	0x2,0x30cd,0x30fc,0x2,0x30ce,0x30fc,0x2,0x30cf,
	0x30fc,0x2,0x30d2,0x30fc,0x2,0x30d5,0x30fc,0x2,
	0x30d8,0x30fc,0x2,0x30db,0x30fc,0x3,0x30cf,0x3099,
	0x30fc,0x3,0x30d2,0x3099,0x30fc,0x3,0x30d5,0x3099,
	0x30fc,0x3,0x30d8,0x3099,0x30fc,0x3,0x30db,0x3099,
	0x30fc,0x3,0x30cf,0x309a,0x30fc,0x3,0x30d2,0x309a,
	0x30fc,0x3,0x30d5,0x309a,0x30fc,0x3,0x30d8,0x309a,
	0x30fc,0x3,0x30db,0x309a,0x30fc,0x2,0x30de,0x30fc,
	0x2,0x30df,0x30fc,0x2,0x30e0,0x30fc,0x2,0x30e1,
	0x30fc,0x2,0x30e2,0x30fc,0x2,0x30e4,0x30fc,0x2,
	0x30e6,0x30fc,0x2,0x30e8,0x30fc,0x2,0x30e9,0x30fc,
	0x2,0x30ea,0x30fc,0x2,0x30eb,0x30fc,0x2,0x30ec,
	0x30fc,0x2,0x30ed,0x30fc,0x2,0x30ef,0x30fc,0x2,
	0x30f0,0x30fc,0x2,0x30f1,0x30fc,0x2,0x30f2,0x30fc,
	0x3,0x30ef,0x3099,0x30fc,0x3,0x30f0,0x3099,0x30fc,
	0x3,0x30ef,0x3099,0x30fc,0x3,0x30f1,0x3099,0x30fc,
	0x3,0x30f2,0x3099,0x30fc,0x2,0xff76,0xff70,0x2,
	0xff77,0xff70,0x2,0xff78,0xff70,0x2,0xff79,0xff70,
	0x2,0xff7a,0xff70,0x3,0xff76,0xff9e,0xff70,0x3,
	0xff77,0xff9e,0xff70,0x3,0xff78,0xff9e,0xff70,0x3,
	0xff79,0xff9e,0xff70,0x3,0xff7a,0xff9e,0xff70,0x2,
	0xff7b,0xff70,0x2,0xff7c,0xff70,0x2,0xff7d,0xff70,
	0x2,0xff7e,0xff70,0x2,0xff7f,0xff70,0x3,0xff7b,
	0xff9e,0xff70,0x3,0xff7c,0xff9e,0xff70,0x3,0xff7d,
	0xff9e,0xff70,0x3,0xff7e,0xff9e,0xff70,0x3,0xff7f,
	0xff9e,0xff70,0x2,0xff80,0xff70,0x2,0xff81,0xff70,
	0x2,0xff82,0xff70,0x2,0xff83,0xff70,0x2,0xff84,
	0xff70,0x3,0xff80,0xff9e,0xff70,0x3,0xff81,0xff9e,
	0xff70,0x3,0xff82,0xff9e,0xff70,0x3,0xff83,0xff9e,
	0xff70,0x3,0xff84,0xff9e,0xff70,0x2,0xff85,0xff70,
	0x2,0xff86,0xff70,0x2,0xff87,0xff70,0x2,0xff88,
	0xff70,0x2,0xff89,0xff70,0x2,0xff8a,0xff70,0x2,
	0xff8b,0xff70,0x2,0xff8c,0xff70,0x2,0xff8d,0xff70,
	0x2,0xff8e,0xff70,0x3,0xff8a,0xff9e,0xff70,0x3,
	0xff8b,0xff9e,0xff70,0x3,0xff8c,0xff9e,0xff70,0x3,
	0xff8d,0xff9e,0xff70,0x3,0xff8e,0xff9e,0xff70,0x3,
	0xff8a,0xff9f,0xff70,0x3,0xff8b,0xff9f,0xff70,0x3,
	0xff8c,0xff9f,0xff70,0x3,0xff8d,0xff9f,0xff70,0x3,
	0xff8e,0xff9f,0xff70,0x2,0xff8f,0xff70,0x2,0xff90,
	0xff70,0x2,0xff91,0xff70,0x2,0xff92,0xff70,0x2,
	0xff93,0xff70,0x2,0xff94,0xff70,0x2,0xff95,0xff70,
	0x2,0xff96,0xff70,0x2,0xff97,0xff70,0x2,0xff98,
	0xff70,0x2,0xff99,0xff70,0x2,0xff9a,0xff70,0x2,
	0xff9b,0xff70,0x2,0xff9c,0xff70,0x3,0xff9c,0xff9e,
	0xff70,
	};

static const TUint32 TheKanaStringIndex[] = 
	{
	0x4e0034,0x510036,0x540038,0x57003a,0x5a003c,0x6c0048,0x5d003e,0x70004b,
	0x600040,0x74004e,0x630042,0x780051,0x660044,0x7c0054,0x690046,0x8f0061,
	0x800057,0x930064,0x830059,0x970067,0x86005b,0x9b006a,0x89005d,0x9f006d,
	0x8c005f,0xb2007a,0xa30070,0xb6007d,0xa60072,0xba0080,0xa90074,0xbe0083,
	0xac0076,0xc20086,0xaf0078,0xc60089,0xc9008b,0xcc008d,0xcf008f,0xd20091,
	0xe4009d,0xf800ac,0xd50093,0xe800a0,0xfc00af,0xd80095,0xec00a3,0x10000b2,
	0xdb0097,0xf000a6,0x10400b5,0xde0099,0xf400a9,0x10800b8,0xe1009b,0x10c00bb,
	0x10f00bd,0x11200bf,0x11500c1,0x11800c3,0x11b00c5,0x11e00c7,0x12100c9,0x12400cb,
	0x12700cd,0x12a00cf,0x12d00d1,0x13000d3,0x13300d5,0x14500e1,0x13600d7,0x14900e4,
	0x13900d9,0x14d00e7,0x13c00db,0x15100ea,0x13f00dd,0x15500ed,0x14200df,0x16800fa,
	0x15900f0,0x16c00fd,0x15c00f2,0x1700100,0x15f00f4,0x1740103,0x16200f6,0x1780106,
	0x16500f8,0x18b0113,0x17c0109,0x18f0116,0x17f010b,0x1930119,0x182010d,0x197011c,
	0x185010f,0x19b011f,0x1880111,0x19f0122,0x1a20124,0x1a50126,0x1a80128,0x1ab012a,
	0x1bd0136,0x1d10145,0x1ae012c,0x1c10139,0x1d50148,0x1b1012e,0x1c5013c,0x1d9014b,
	0x1b40130,0x1c9013f,0x1dd014e,0x1b70132,0x1cd0142,0x1e10151,0x1ba0134,0x1e50154,
	0x1e80156,0x1eb0158,0x1ee015a,0x1f1015c,0x1f4015e,0x1f70160,0x1fa0162,0x1fd0164,
	0x2000166,0x2030168,0x206016a,0x209016c,0x2180176,0x220017c,0x20c016e,0x21c0179,
	0x20f0170,0x224017f,0x2120172,0x2280182,0x2150174,0x0,0x22c0185,0x30002,
	0x23b018f,0x22f0187,0x60004,0x23f0192,0x2320189,0x90006,0x2430195,0x235018b,
	0xc0008,0x2470198,0x238018d,0xf000a,0x24b019b,0x24f019e,0x12000c,0x25e01a8,
	0x25201a0,0x15000e,0x26201ab,0x25501a2,0x180010,0x26601ae,0x25801a4,0x1b0012,
	0x26a01b1,0x25b01a6,0x1e0014,0x26e01b4,0x27201b7,0x210016,0x28101c1,0x27501b9,
	0x240018,0x28501c4,0x27801bb,0x27001a,0x28901c7,0x27b01bd,0x2a001c,0x28d01ca,
	0x27e01bf,0x2d001e,0x29101cd,0x29501d0,0x29801d2,0x29b01d4,0x29e01d6,0x2a101d8,
	0x2a401da,0x300020,0x2b301e4,0x3f002a,0x2c701f3,0x2a701dc,0x330022,0x2b701e7,
	0x42002c,0x2cb01f6,0x2aa01de,0x360024,0x2bb01ea,0x45002e,0x2cf01f9,0x2ad01e0,
	0x390026,0x2bf01ed,0x480030,0x2d301fc,0x2b001e2,0x3c0028,0x2c301f0,0x4b0032,
	0x2d701ff,0x2db0202,0x2de0204,0x2e10206,0x2e40208,0x2e7020a,0x2ea020c,0x2ed020e,
	0x2f00210,0x2f30212,0x2f60214,0x2f90216,0x2fc0218,0x2ff021a,0x302021c,0x305021e,
	};

static const TCollationKeyTable TheKanaTable = 
	{ TheKanaKey, TheKanaIndex, 560, TheKanaStringElement, TheKanaStringIndex, 232 };


static const TCollationMethod TheKanaMethod =
	{ 0, NULL, &TheKanaTable, 0 };

static const TCollationMethod TheSwapKanaMethod =
	{ 0, NULL, &TheKanaTable, TCollationMethod::ESwapKana };

// Simplified Chinese. The data is extracted from loce32\Is_unic_template_chinese_simplified.cpp
static const TUint32 TheChineseKey[] = 
	{
	0x4e01001d,0x4e02001d,0x4e03001d,0x4e04001d,0x4e05001d,0x4e06001d,0x4e07001d,0x4e08001d,
	0x4e09001d,0x4e0a001d,0x4e0b001d,0x4e0c001d,0x4e0d001d,0x4e0e001d,0x4e0f001d,0x4e10001d,
	0x4e11001d,0x4e12001d,0x4e13001d,0x4e14001d,0x4e15001d,0x4e16001d,0x4e17001d,0x4e18001d,
	0x4e19001d,0x4e1a001d,0x4e1b001d,0x4e1c001d,0x4e1d001d,0x4e1e001d,0x4e1f001d,0x4e20001d,
	0x4e21001d,0x4e22001d,0x4e23001d,0x4e24001d,0x4e25001d,0x4e26001d,0x4e27001d,0x4e28001d,
	0x4e29001d,0x4e2a001d,0x4e2b001d,0x4e2c001d,0x4e2d001d,0x4e2e001d,0x4e2f001d,0x4e30001d,
	0x4e31001d,0x4e32001d,0x4e33001d,0x4e34001d,0x4e35001d,0x4e36001d,0x4e37001d,0x4e38001d,
	0x4e39001d,0x4e3a001d,0x4e3b001d,0x4e3c001d,0x4e3d001d,0x4e3e001d,0x4e3f001d,0x4e40001d,
	0x4e41001d,0x4e42001d,0x4e43001d,0x4e44001d,0x4e45001d,0x4e46001d,0x4e47001d,0x4e48001d,
	0x4e49001d,0x4e4a001d,0x4e4b001d,0x4e4c001d,0x4e4d001d,0x4e4e001d,0x4e4f001d,0x4e50001d,
	0x4e51001d,0x4e52001d,0x4e53001d,0x4e54001d,0x4e55001d,0x4e56001d,0x4e57001d,0x4e58001d,
	0x4e59001d,0x4e5a001d,0x4e5b001d,0x4e5c001d,0x4e5d001d,0x4e5e001d,0x4e5f001d,0x4e60001d,
	0x4e61001d,0x4e62001d,0x4e63001d,0x4e64001d,0x4e65001d,0x4e66001d,0x4e67001d,0x4e68001d,
	0x4e69001d,0x4e6a001d,0x4e6b001d,0x4e6c001d,0x4e6d001d,0x4e6e001d,0x4e6f001d,0x4e70001d,
	0x4e71001d,0x4e72001d,0x4e73001d,0x4e74001d,0x4e75001d,0x4e76001d,0x4e77001d,0x4e78001d,
	0x4e79001d,0x4e7a001d,0x4e7b001d,0x4e7c001d,0x4e7d001d,0x4e7e001d,0x4e7f001d,0x4e80001d,
	0x4e81001d,0x4e82001d,0x4e83001d,0x4e84001d,0x4e85001d,0x4e86001d,0x4e87001d,0x4e88001d,
	0x4e89001d,0x4e8a001d,0x4e8b001d,0x4e8c001d,0x4e8d001d,0x4e8e001d,0x4e8f001d,0x4e90001d,
	0x4e91001d,0x4e92001d,0x4e93001d,0x4e94001d,0x4e95001d,0x4e96001d,0x4e97001d,0x4e98001d,
	0x4e99001d,0x4e9a001d,0x4e9b001d,0x4e9c001d,0x4e9d001d,0x4e9e001d,0x4e9f001d,0x4ea0001d,
	0x4ea1001d,0x4ea2001d,0x4ea3001d,0x4ea4001d,0x4ea5001d,0x4ea6001d,0x4ea7001d,0x4ea8001d,
	0x4ea9001d,0x4eaa001d,0x4eab001d,0x4eac001d,0x4ead001d,0x4eae001d,0x4eaf001d,0x4eb0001d,
	0x4eb1001d,0x4eb2001d,0x4eb3001d,0x4eb4001d,0x4eb5001d,0x4eb6001d,0x4eb7001d,0x4eb8001d,
	0x4eb9001d,0x4eba001d,0x4ebb001d,0x4ebc001d,0x4ebd001d,0x4ebe001d,0x4ebf001d,0x4ec0001d,
	0x4ec1001d,0x4ec2001d,0x4ec3001d,0x4ec4001d,0x4ec5001d,0x4ec6001d,0x4ec7001d,0x4ec8001d,
	0x4ec9001d,0x4eca001d,0x4ecb001d,0x4ecc001d,0x4ecd001d,0x4ece001d,0x4ecf001d,0x4ed0001d,
	0x4ed1001d,0x4ed2001d,0x4ed3001d,0x4ed4001d,0x4ed5001d,0x4ed6001d,0x4ed7001d,0x4ed8001d,
	0x4ed9001d,0x4eda001d,0x4edb001d,0x4edc001d,0x4edd001d,0x4ede001d,0x4edf001d,0x4ee0001d,
	0x4ee1001d,0x4ee2001d,0x4ee3001d,0x4ee4001d,0x4ee5001d,0x4ee6001d,0x4ee7001d,0x4ee8001d,
	0x4ee9001d,0x4eea001d,0x4eeb001d,0x4eec001d,0x4eed001d,0x4eee001d,0x4eef001d,0x4ef0001d,
	0x4ef1001d,0x4ef2001d,0x4ef3001d,0x4ef4001d,0x4ef5001d,0x4ef6001d,0x4ef7001d,0x4ef8001d,
	0x4ef9001d,0x4efa001d,0x4efb001d,0x4efc001d,0x4efd001d,0x4efe001d,0x4eff001d,0x4f00001d,
	0x4f01001d,0x4f02001d,0x4f03001d,0x4f04001d,0x4f05001d,0x4f06001d,0x4f07001d,0x4f08001d,
	0x4f09001d,0x4f0a001d,0x4f0b001d,0x4f0c001d,0x4f0d001d,0x4f0e001d,0x4f0f001d,0x4f10001d,
	0x4f11001d,0x4f12001d,0x4f13001d,0x4f14001d,0x4f15001d,0x4f16001d,0x4f17001d,0x4f18001d,
	0x4f19001d,0x4f1a001d,0x4f1b001d,0x4f1c001d,0x4f1d001d,0x4f1e001d,0x4f1f001d,0x4f20001d,
	0x4f21001d,0x4f22001d,0x4f23001d,0x4f24001d,0x4f25001d,0x4f26001d,0x4f27001d,0x4f28001d,
	0x4f29001d,0x4f2a001d,0x4f2b001d,0x4f2c001d,0x4f2d001d,0x4f2e001d,0x4f2f001d,0x4f30001d,
	0x4f31001d,0x4f32001d,0x4f33001d,0x4f34001d,0x4f35001d,0x4f36001d,0x4f37001d,0x4f38001d,
	0x4f39001d,0x4f3a001d,0x4f3b001d,0x4f3c001d,0x4f3d001d,0x4f3e001d,0x4f3f001d,0x4f40001d,
	0x4f41001d,0x4f42001d,0x4f43001d,0x4f44001d,0x4f45001d,0x4f46001d,0x4f47001d,0x4f48001d,
	0x4f49001d,0x4f4a001d,0x4f4b001d,0x4f4c001d,0x4f4d001d,0x4f4e001d,0x4f4f001d,0x4f50001d,
	0x4f51001d,0x4f52001d,0x4f53001d,0x4f54001d,0x4f55001d,0x4f56001d,0x4f57001d,0x4f58001d,
	0x4f59001d,0x4f5a001d,0x4f5b001d,0x4f5c001d,0x4f5d001d,0x4f5e001d,0x4f5f001d,0x4f60001d,
	0x4f61001d,0x4f62001d,0x4f63001d,0x4f64001d,0x4f65001d,0x4f66001d,0x4f67001d,0x4f68001d,
	0x4f69001d,0x4f6a001d,0x4f6b001d,0x4f6c001d,0x4f6d001d,0x4f6e001d,0x4f6f001d,0x4f70001d,
	0x4f71001d,0x4f72001d,0x4f73001d,0x4f74001d,0x4f75001d,0x4f76001d,0x4f77001d,0x4f78001d,
	0x4f79001d,0x4f7a001d,0x4f7b001d,0x4f7c001d,0x4f7d001d,0x4f7e001d,0x4f7f001d,0x4f80001d,
	0x4f81001d,0x4f82001d,0x4f83001d,0x4f84001d,0x4f85001d,0x4f86001d,0x4f87001d,0x4f88001d,
	0x4f89001d,0x4f8a001d,0x4f8b001d,0x4f8c001d,0x4f8d001d,0x4f8e001d,0x4f8f001d,0x4f90001d,
	0x4f91001d,0x4f92001d,0x4f93001d,0x4f94001d,0x4f95001d,0x4f96001d,0x4f97001d,0x4f98001d,
	0x4f99001d,0x4f9a001d,0x4f9b001d,0x4f9c001d,0x4f9d001d,0x4f9e001d,0x4f9f001d,0x4fa0001d,
	0x4fa1001d,0x4fa2001d,0x4fa3001d,0x4fa4001d,0x4fa5001d,0x4fa6001d,0x4fa7001d,0x4fa8001d,
	0x4fa9001d,0x4faa001d,0x4fab001d,0x4fac001d,0x4fad001d,0x4fae001d,0x4faf001d,0x4fb0001d,
	0x4fb1001d,0x4fb2001d,0x4fb3001d,0x4fb4001d,0x4fb5001d,0x4fb6001d,0x4fb7001d,0x4fb8001d,
	0x4fb9001d,0x4fba001d,0x4fbb001d,0x4fbc001d,0x4fbd001d,0x4fbe001d,0x4fbf001d,0x4fc0001d,
	0x4fc1001d,0x4fc2001d,0x4fc3001d,0x4fc4001d,0x4fc5001d,0x4fc6001d,0x4fc7001d,0x4fc8001d,
	0x4fc9001d,0x4fca001d,0x4fcb001d,0x4fcc001d,0x4fcd001d,0x4fce001d,0x4fcf001d,0x4fd0001d,
	0x4fd1001d,0x4fd2001d,0x4fd3001d,0x4fd4001d,0x4fd5001d,0x4fd6001d,0x4fd7001d,0x4fd8001d,
	0x4fd9001d,0x4fda001d,0x4fdb001d,0x4fdc001d,0x4fdd001d,0x4fde001d,0x4fdf001d,0x4fe0001d,
	0x4fe1001d,0x4fe2001d,0x4fe3001d,0x4fe4001d,0x4fe5001d,0x4fe6001d,0x4fe7001d,0x4fe8001d,
	0x4fe9001d,0x4fea001d,0x4feb001d,0x4fec001d,0x4fed001d,0x4fee001d,0x4fef001d,0x4ff0001d,
	0x4ff1001d,0x4ff2001d,0x4ff3001d,0x4ff4001d,0x4ff5001d,0x4ff6001d,0x4ff7001d,0x4ff8001d,
	0x4ff9001d,0x4ffa001d,0x4ffb001d,0x4ffc001d,0x4ffd001d,0x4ffe001d,0x4fff001d,0x5000001d,
	0x5001001d,0x5002001d,0x5003001d,0x5004001d,0x5005001d,0x5006001d,0x5007001d,0x5008001d,
	0x5009001d,0x500a001d,0x500b001d,0x500c001d,0x500d001d,0x500e001d,0x500f001d,0x5010001d,
	0x5011001d,0x5012001d,0x5013001d,0x5014001d,0x5015001d,0x5016001d,0x5017001d,0x5018001d,
	0x5019001d,0x501a001d,0x501b001d,0x501c001d,0x501d001d,0x501e001d,0x501f001d,0x5020001d,
	0x5021001d,0x5022001d,0x5023001d,0x5024001d,0x5025001d,0x5026001d,0x5027001d,0x5028001d,
	0x5029001d,0x502a001d,0x502b001d,0x502c001d,0x502d001d,0x502e001d,0x502f001d,0x5030001d,
	0x5031001d,0x5032001d,0x5033001d,0x5034001d,0x5035001d,0x5036001d,0x5037001d,0x5038001d,
	0x5039001d,0x503a001d,0x503b001d,0x503c001d,0x503d001d,0x503e001d,0x503f001d,0x5040001d,
	0x5041001d,0x5042001d,0x5043001d,0x5044001d,0x5045001d,0x5046001d,0x5047001d,0x5048001d,
	0x5049001d,0x504a001d,0x504b001d,0x504c001d,0x504d001d,0x504e001d,0x504f001d,0x5050001d,
	0x5051001d,0x5052001d,0x5053001d,0x5054001d,0x5055001d,0x5056001d,0x5057001d,0x5058001d,
	0x5059001d,0x505a001d,0x505b001d,0x505c001d,0x505d001d,0x505e001d,0x505f001d,0x5060001d,
	0x5061001d,0x5062001d,0x5063001d,0x5064001d,0x5065001d,0x5066001d,0x5067001d,0x5068001d,
	0x5069001d,0x506a001d,0x506b001d,0x506c001d,0x506d001d,0x506e001d,0x506f001d,0x5070001d,
	0x5071001d,0x5072001d,0x5073001d,0x5074001d,0x5075001d,0x5076001d,0x5077001d,0x5078001d,
	0x5079001d,0x507a001d,0x507b001d,0x507c001d,0x507d001d,0x507e001d,0x507f001d,0x5080001d,
	0x5081001d,0x5082001d,0x5083001d,0x5084001d,0x5085001d,0x5086001d,0x5087001d,0x5088001d,
	0x5089001d,0x508a001d,0x508b001d,0x508c001d,0x508d001d,0x508e001d,0x508f001d,0x5090001d,
	0x5091001d,0x5092001d,0x5093001d,0x5094001d,0x5095001d,0x5096001d,0x5097001d,0x5098001d,
	0x5099001d,0x509a001d,0x509b001d,0x509c001d,0x509d001d,0x509e001d,0x509f001d,0x50a0001d,
	0x50a1001d,0x50a2001d,0x50a3001d,0x50a4001d,0x50a5001d,0x50a6001d,0x50a7001d,0x50a8001d,
	0x50a9001d,0x50aa001d,0x50ab001d,0x50ac001d,0x50ad001d,0x50ae001d,0x50af001d,0x50b0001d,
	0x50b1001d,0x50b2001d,0x50b3001d,0x50b4001d,0x50b5001d,0x50b6001d,0x50b7001d,0x50b8001d,
	0x50b9001d,0x50ba001d,0x50bb001d,0x50bc001d,0x50bd001d,0x50be001d,0x50bf001d,0x50c0001d,
	0x50c1001d,0x50c2001d,0x50c3001d,0x50c4001d,0x50c5001d,0x50c6001d,0x50c7001d,0x50c8001d,
	0x50c9001d,0x50ca001d,0x50cb001d,0x50cc001d,0x50cd001d,0x50ce001d,0x50cf001d,0x50d0001d,
	0x50d1001d,0x50d2001d,0x50d3001d,0x50d4001d,0x50d5001d,0x50d6001d,0x50d7001d,0x50d8001d,
	0x50d9001d,0x50da001d,0x50db001d,0x50dc001d,0x50dd001d,0x50de001d,0x50df001d,0x50e0001d,
	0x50e1001d,0x50e2001d,0x50e3001d,0x50e4001d,0x50e5001d,0x50e6001d,0x50e7001d,0x50e8001d,
	0x50e9001d,0x50ea001d,0x50eb001d,0x50ec001d,0x50ed001d,0x50ee001d,0x50ef001d,0x50f0001d,
	0x50f1001d,0x50f2001d,0x50f3001d,0x50f4001d,0x50f5001d,0x50f6001d,0x50f7001d,0x50f8001d,
	0x50f9001d,0x50fa001d,0x50fb001d,0x50fc001d,0x50fd001d,0x50fe001d,0x50ff001d,0x5100001d,
	0x5101001d,0x5102001d,0x5103001d,0x5104001d,0x5105001d,0x5106001d,0x5107001d,0x5108001d,
	0x5109001d,0x510a001d,0x510b001d,0x510c001d,0x510d001d,0x510e001d,0x510f001d,0x5110001d,
	0x5111001d,0x5112001d,0x5113001d,0x5114001d,0x5115001d,0x5116001d,0x5117001d,0x5118001d,
	0x5119001d,0x511a001d,0x511b001d,0x511c001d,0x511d001d,0x511e001d,0x511f001d,0x5120001d,
	0x5121001d,0x5122001d,0x5123001d,0x5124001d,0x5125001d,0x5126001d,0x5127001d,0x5128001d,
	0x5129001d,0x512a001d,0x512b001d,0x512c001d,0x512d001d,0x512e001d,0x512f001d,0x5130001d,
	0x5131001d,0x5132001d,0x5133001d,0x5134001d,0x5135001d,0x5136001d,0x5137001d,0x5138001d,
	0x5139001d,0x513a001d,0x513b001d,0x513c001d,0x513d001d,0x513e001d,0x513f001d,0x5140001d,
	0x5141001d,0x5142001d,0x5143001d,0x5144001d,0x5145001d,0x5146001d,0x5147001d,0x5148001d,
	0x5149001d,0x514a001d,0x514b001d,0x514c001d,0x514d001d,0x514e001d,0x514f001d,0x5150001d,
	0x5151001d,0x5152001d,0x5153001d,0x5154001d,0x5155001d,0x5156001d,0x5157001d,0x5158001d,
	0x5159001d,0x515a001d,0x515b001d,0x515c001d,0x515d001d,0x515e001d,0x515f001d,0x5160001d,
	0x5161001d,0x5162001d,0x5163001d,0x5164001d,0x5165001d,0x5166001d,0x5167001d,0x5168001d,
	0x5169001d,0x516a001d,0x516b001d,0x516c001d,0x516d001d,0x516e001d,0x516f001d,0x5170001d,
	0x5171001d,0x5172001d,0x5173001d,0x5174001d,0x5175001d,0x5176001d,0x5177001d,0x5178001d,
	0x5179001d,0x517a001d,0x517b001d,0x517c001d,0x517d001d,0x517e001d,0x517f001d,0x5180001d,
	0x5181001d,0x5182001d,0x5183001d,0x5184001d,0x5185001d,0x5186001d,0x5187001d,0x5188001d,
	0x5189001d,0x518a001d,0x518b001d,0x518c001d,0x518d001d,0x518e001d,0x518f001d,0x5190001d,
	0x5191001d,0x5192001d,0x5193001d,0x5194001d,0x5195001d,0x5196001d,0x5197001d,0x5198001d,
	0x5199001d,0x519a001d,0x519b001d,0x519c001d,0x519d001d,0x519e001d,0x519f001d,0x51a0001d,
	0x51a1001d,0x51a2001d,0x51a3001d,0x51a4001d,0x51a5001d,0x51a6001d,0x51a7001d,0x51a8001d,
	0x51a9001d,0x51aa001d,0x51ab001d,0x51ac001d,0x51ad001d,0x51ae001d,0x51af001d,0x51b0001d,
	0x51b1001d,0x51b2001d,0x51b3001d,0x51b4001d,0x51b5001d,0x51b6001d,0x51b7001d,0x51b8001d,
	0x51b9001d,0x51ba001d,0x51bb001d,0x51bc001d,0x51bd001d,0x51be001d,0x51bf001d,0x51c0001d,
	0x51c1001d,0x51c2001d,0x51c3001d,0x51c4001d,0x51c5001d,0x51c6001d,0x51c7001d,0x51c8001d,
	0x51c9001d,0x51ca001d,0x51cb001d,0x51cc001d,0x51cd001d,0x51ce001d,0x51cf001d,0x51d0001d,
	0x51d1001d,0x51d2001d,0x51d3001d,0x51d4001d,0x51d5001d,0x51d6001d,0x51d7001d,0x51d8001d,
	0x51d9001d,0x51da001d,0x51db001d,0x51dc001d,0x51dd001d,0x51de001d,0x51df001d,0x51e0001d,
	0x51e1001d,0x51e2001d,0x51e3001d,0x51e4001d,0x51e5001d,0x51e6001d,0x51e7001d,0x51e8001d,
	0x51e9001d,0x51ea001d,0x51eb001d,0x51ec001d,0x51ed001d,0x51ee001d,0x51ef001d,0x51f0001d,
	0x51f1001d,0x51f2001d,0x51f3001d,0x51f4001d,0x51f5001d,0x51f6001d,0x51f7001d,0x51f8001d,
	0x51f9001d,0x51fa001d,0x51fb001d,0x51fc001d,0x51fd001d,0x51fe001d,0x51ff001d,0x5200001d,
	0x5201001d,0x5202001d,0x5203001d,0x5204001d,0x5205001d,0x5206001d,0x5207001d,0x5208001d,
	0x5209001d,0x520a001d,0x520b001d,0x520c001d,0x520d001d,0x520e001d,0x520f001d,0x5210001d,
	0x5211001d,0x5212001d,0x5213001d,0x5214001d,0x5215001d,0x5216001d,0x5217001d,0x5218001d,
	0x5219001d,0x521a001d,0x521b001d,0x521c001d,0x521d001d,0x521e001d,0x521f001d,0x5220001d,
	0x5221001d,0x5222001d,0x5223001d,0x5224001d,0x5225001d,0x5226001d,0x5227001d,0x5228001d,
	0x5229001d,0x522a001d,0x522b001d,0x522c001d,0x522d001d,0x522e001d,0x522f001d,0x5230001d,
	0x5231001d,0x5232001d,0x5233001d,0x5234001d,0x5235001d,0x5236001d,0x5237001d,0x5238001d,
	0x5239001d,0x523a001d,0x523b001d,0x523c001d,0x523d001d,0x523e001d,0x523f001d,0x5240001d,
	0x5241001d,0x5242001d,0x5243001d,0x5244001d,0x5245001d,0x5246001d,0x5247001d,0x5248001d,
	0x5249001d,0x524a001d,0x524b001d,0x524c001d,0x524d001d,0x524e001d,0x524f001d,0x5250001d,
	0x5251001d,0x5252001d,0x5253001d,0x5254001d,0x5255001d,0x5256001d,0x5257001d,0x5258001d,
	0x5259001d,0x525a001d,0x525b001d,0x525c001d,0x525d001d,0x525e001d,0x525f001d,0x5260001d,
	0x5261001d,0x5262001d,0x5263001d,0x5264001d,0x5265001d,0x5266001d,0x5267001d,0x5268001d,
	0x5269001d,0x526a001d,0x526b001d,0x526c001d,0x526d001d,0x526e001d,0x526f001d,0x5270001d,
	0x5271001d,0x5272001d,0x5273001d,0x5274001d,0x5275001d,0x5276001d,0x5277001d,0x5278001d,
	0x5279001d,0x527a001d,0x527b001d,0x527c001d,0x527d001d,0x527e001d,0x527f001d,0x5280001d,
	0x5281001d,0x5282001d,0x5283001d,0x5284001d,0x5285001d,0x5286001d,0x5287001d,0x5288001d,
	0x5289001d,0x528a001d,0x528b001d,0x528c001d,0x528d001d,0x528e001d,0x528f001d,0x5290001d,
	0x5291001d,0x5292001d,0x5293001d,0x5294001d,0x5295001d,0x5296001d,0x5297001d,0x5298001d,
	0x5299001d,0x529a001d,0x529b001d,0x529c001d,0x529d001d,0x529e001d,0x529f001d,0x52a0001d,
	0x52a1001d,0x52a2001d,0x52a3001d,0x52a4001d,0x52a5001d,0x52a6001d,0x52a7001d,0x52a8001d,
	0x52a9001d,0x52aa001d,0x52ab001d,0x52ac001d,0x52ad001d,0x52ae001d,0x52af001d,0x52b0001d,
	0x52b1001d,0x52b2001d,0x52b3001d,0x52b4001d,0x52b5001d,0x52b6001d,0x52b7001d,0x52b8001d,
	0x52b9001d,0x52ba001d,0x52bb001d,0x52bc001d,0x52bd001d,0x52be001d,0x52bf001d,0x52c0001d,
	0x52c1001d,0x52c2001d,0x52c3001d,0x52c4001d,0x52c5001d,0x52c6001d,0x52c7001d,0x52c8001d,
	0x52c9001d,0x52ca001d,0x52cb001d,0x52cc001d,0x52cd001d,0x52ce001d,0x52cf001d,0x52d0001d,
	0x52d1001d,0x52d2001d,0x52d3001d,0x52d4001d,0x52d5001d,0x52d6001d,0x52d7001d,0x52d8001d,
	0x52d9001d,0x52da001d,0x52db001d,0x52dc001d,0x52dd001d,0x52de001d,0x52df001d,0x52e0001d,
	0x52e1001d,0x52e2001d,0x52e3001d,0x52e4001d,0x52e5001d,0x52e6001d,0x52e7001d,0x52e8001d,
	0x52e9001d,0x52ea001d,0x52eb001d,0x52ec001d,0x52ed001d,0x52ee001d,0x52ef001d,0x52f0001d,
	0x52f1001d,0x52f2001d,0x52f3001d,0x52f4001d,0x52f5001d,0x52f6001d,0x52f7001d,0x52f8001d,
	0x52f9001d,0x52fa001d,0x52fb001d,0x52fc001d,0x52fd001d,0x52fe001d,0x52ff001d,0x5300001d,
	0x5301001d,0x5302001d,0x5303001d,0x5304001d,0x5305001d,0x5306001d,0x5307001d,0x5308001d,
	0x5309001d,0x530a001d,0x530b001d,0x530c001d,0x530d001d,0x530e001d,0x530f001d,0x5310001d,
	0x5311001d,0x5312001d,0x5313001d,0x5314001d,0x5315001d,0x5316001d,0x5317001d,0x5318001d,
	0x5319001d,0x531a001d,0x531b001d,0x531c001d,0x531d001d,0x531e001d,0x531f001d,0x5320001d,
	0x5321001d,0x5322001d,0x5323001d,0x5324001d,0x5325001d,0x5326001d,0x5327001d,0x5328001d,
	0x5329001d,0x532a001d,0x532b001d,0x532c001d,0x532d001d,0x532e001d,0x532f001d,0x5330001d,
	0x5331001d,0x5332001d,0x5333001d,0x5334001d,0x5335001d,0x5336001d,0x5337001d,0x5338001d,
	0x5339001d,0x533a001d,0x533b001d,0x533c001d,0x533d001d,0x533e001d,0x533f001d,0x5340001d,
	0x5341001d,0x5342001d,0x5343001d,0x5344001d,0x5345001d,0x5346001d,0x5347001d,0x5348001d,
	0x5349001d,0x534a001d,0x534b001d,0x534c001d,0x534d001d,0x534e001d,0x534f001d,0x5350001d,
	0x5351001d,0x5352001d,0x5353001d,0x5354001d,0x5355001d,0x5356001d,0x5357001d,0x5358001d,
	0x5359001d,0x535a001d,0x535b001d,0x535c001d,0x535d001d,0x535e001d,0x535f001d,0x5360001d,
	0x5361001d,0x5362001d,0x5363001d,0x5364001d,0x5365001d,0x5366001d,0x5367001d,0x5368001d,
	0x5369001d,0x536a001d,0x536b001d,0x536c001d,0x536d001d,0x536e001d,0x536f001d,0x5370001d,
	0x5371001d,0x5372001d,0x5373001d,0x5374001d,0x5375001d,0x5376001d,0x5377001d,0x5378001d,
	0x5379001d,0x537a001d,0x537b001d,0x537c001d,0x537d001d,0x537e001d,0x537f001d,0x5380001d,
	0x5381001d,0x5382001d,0x5383001d,0x5384001d,0x5385001d,0x5386001d,0x5387001d,0x5388001d,
	0x5389001d,0x538a001d,0x538b001d,0x538c001d,0x538d001d,0x538e001d,0x538f001d,0x5390001d,
	0x5391001d,0x5392001d,0x5393001d,0x5394001d,0x5395001d,0x5396001d,0x5397001d,0x5398001d,
	0x5399001d,0x539a001d,0x539b001d,0x539c001d,0x539d001d,0x539e001d,0x539f001d,0x53a0001d,
	0x53a1001d,0x53a2001d,0x53a3001d,0x53a4001d,0x53a5001d,0x53a6001d,0x53a7001d,0x53a8001d,
	0x53a9001d,0x53aa001d,0x53ab001d,0x53ac001d,0x53ad001d,0x53ae001d,0x53af001d,0x53b0001d,
	0x53b1001d,0x53b2001d,0x53b3001d,0x53b4001d,0x53b5001d,0x53b6001d,0x53b7001d,0x53b8001d,
	0x53b9001d,0x53ba001d,0x53bb001d,0x53bc001d,0x53bd001d,0x53be001d,0x53bf001d,0x53c0001d,
	0x53c1001d,0x53c2001d,0x53c3001d,0x53c4001d,0x53c5001d,0x53c6001d,0x53c7001d,0x53c8001d,
	0x53c9001d,0x53ca001d,0x53cb001d,0x53cc001d,0x53cd001d,0x53ce001d,0x53cf001d,0x53d0001d,
	0x53d1001d,0x53d2001d,0x53d3001d,0x53d4001d,0x53d5001d,0x53d6001d,0x53d7001d,0x53d8001d,
	0x53d9001d,0x53da001d,0x53db001d,0x53dc001d,0x53dd001d,0x53de001d,0x53df001d,0x53e0001d,
	0x53e1001d,0x53e2001d,0x53e3001d,0x53e4001d,0x53e5001d,0x53e6001d,0x53e7001d,0x53e8001d,
	0x53e9001d,0x53ea001d,0x53eb001d,0x53ec001d,0x53ed001d,0x53ee001d,0x53ef001d,0x53f0001d,
	0x53f1001d,0x53f2001d,0x53f3001d,0x53f4001d,0x53f5001d,0x53f6001d,0x53f7001d,0x53f8001d,
	0x53f9001d,0x53fa001d,0x53fb001d,0x53fc001d,0x53fd001d,0x53fe001d,0x53ff001d,0x5400001d,
	0x5401001d,0x5402001d,0x5403001d,0x5404001d,0x5405001d,0x5406001d,0x5407001d,0x5408001d,
	0x5409001d,0x540a001d,0x540b001d,0x540c001d,0x540d001d,0x540e001d,0x540f001d,0x5410001d,
	0x5411001d,0x5412001d,0x5413001d,0x5414001d,0x5415001d,0x5416001d,0x5417001d,0x5418001d,
	0x5419001d,0x541a001d,0x541b001d,0x541c001d,0x541d001d,0x541e001d,0x541f001d,0x5420001d,
	0x5421001d,0x5422001d,0x5423001d,0x5424001d,0x5425001d,0x5426001d,0x5427001d,0x5428001d,
	0x5429001d,0x542a001d,0x542b001d,0x542c001d,0x542d001d,0x542e001d,0x542f001d,0x5430001d,
	0x5431001d,0x5432001d,0x5433001d,0x5434001d,0x5435001d,0x5436001d,0x5437001d,0x5438001d,
	0x5439001d,0x543a001d,0x543b001d,0x543c001d,0x543d001d,0x543e001d,0x543f001d,0x5440001d,
	0x5441001d,0x5442001d,0x5443001d,0x5444001d,0x5445001d,0x5446001d,0x5447001d,0x5448001d,
	0x5449001d,0x544a001d,0x544b001d,0x544c001d,0x544d001d,0x544e001d,0x544f001d,0x5450001d,
	0x5451001d,0x5452001d,0x5453001d,0x5454001d,0x5455001d,0x5456001d,0x5457001d,0x5458001d,
	0x5459001d,0x545a001d,0x545b001d,0x545c001d,0x545d001d,0x545e001d,0x545f001d,0x5460001d,
	0x5461001d,0x5462001d,0x5463001d,0x5464001d,0x5465001d,0x5466001d,0x5467001d,0x5468001d,
	0x5469001d,0x546a001d,0x546b001d,0x546c001d,0x546d001d,0x546e001d,0x546f001d,0x5470001d,
	0x5471001d,0x5472001d,0x5473001d,0x5474001d,0x5475001d,0x5476001d,0x5477001d,0x5478001d,
	0x5479001d,0x547a001d,0x547b001d,0x547c001d,0x547d001d,0x547e001d,0x547f001d,0x5480001d,
	0x5481001d,0x5482001d,0x5483001d,0x5484001d,0x5485001d,0x5486001d,0x5487001d,0x5488001d,
	0x5489001d,0x548a001d,0x548b001d,0x548c001d,0x548d001d,0x548e001d,0x548f001d,0x5490001d,
	0x5491001d,0x5492001d,0x5493001d,0x5494001d,0x5495001d,0x5496001d,0x5497001d,0x5498001d,
	0x5499001d,0x549a001d,0x549b001d,0x549c001d,0x549d001d,0x549e001d,0x549f001d,0x54a0001d,
	0x54a1001d,0x54a2001d,0x54a3001d,0x54a4001d,0x54a5001d,0x54a6001d,0x54a7001d,0x54a8001d,
	0x54a9001d,0x54aa001d,0x54ab001d,0x54ac001d,0x54ad001d,0x54ae001d,0x54af001d,0x54b0001d,
	0x54b1001d,0x54b2001d,0x54b3001d,0x54b4001d,0x54b5001d,0x54b6001d,0x54b7001d,0x54b8001d,
	0x54b9001d,0x54ba001d,0x54bb001d,0x54bc001d,0x54bd001d,0x54be001d,0x54bf001d,0x54c0001d,
	0x54c1001d,0x54c2001d,0x54c3001d,0x54c4001d,0x54c5001d,0x54c6001d,0x54c7001d,0x54c8001d,
	0x54c9001d,0x54ca001d,0x54cb001d,0x54cc001d,0x54cd001d,0x54ce001d,0x54cf001d,0x54d0001d,
	0x54d1001d,0x54d2001d,0x54d3001d,0x54d4001d,0x54d5001d,0x54d6001d,0x54d7001d,0x54d8001d,
	0x54d9001d,0x54da001d,0x54db001d,0x54dc001d,0x54dd001d,0x54de001d,0x54df001d,0x54e0001d,
	0x54e1001d,0x54e2001d,0x54e3001d,0x54e4001d,0x54e5001d,0x54e6001d,0x54e7001d,0x54e8001d,
	0x54e9001d,0x54ea001d,0x54eb001d,0x54ec001d,0x54ed001d,0x54ee001d,0x54ef001d,0x54f0001d,
	0x54f1001d,0x54f2001d,0x54f3001d,0x54f4001d,0x54f5001d,0x54f6001d,0x54f7001d,0x54f8001d,
	0x54f9001d,0x54fa001d,0x54fb001d,0x54fc001d,0x54fd001d,0x54fe001d,0x54ff001d,0x5500001d,
	0x5501001d,0x5502001d,0x5503001d,0x5504001d,0x5505001d,0x5506001d,0x5507001d,0x5508001d,
	0x5509001d,0x550a001d,0x550b001d,0x550c001d,0x550d001d,0x550e001d,0x550f001d,0x5510001d,
	0x5511001d,0x5512001d,0x5513001d,0x5514001d,0x5515001d,0x5516001d,0x5517001d,0x5518001d,
	0x5519001d,0x551a001d,0x551b001d,0x551c001d,0x551d001d,0x551e001d,0x551f001d,0x5520001d,
	0x5521001d,0x5522001d,0x5523001d,0x5524001d,0x5525001d,0x5526001d,0x5527001d,0x5528001d,
	0x5529001d,0x552a001d,0x552b001d,0x552c001d,0x552d001d,0x552e001d,0x552f001d,0x5530001d,
	0x5531001d,0x5532001d,0x5533001d,0x5534001d,0x5535001d,0x5536001d,0x5537001d,0x5538001d,
	0x5539001d,0x553a001d,0x553b001d,0x553c001d,0x553d001d,0x553e001d,0x553f001d,0x5540001d,
	0x5541001d,0x5542001d,0x5543001d,0x5544001d,0x5545001d,0x5546001d,0x5547001d,0x5548001d,
	0x5549001d,0x554a001d,0x554b001d,0x554c001d,0x554d001d,0x554e001d,0x554f001d,0x5550001d,
	0x5551001d,0x5552001d,0x5553001d,0x5554001d,0x5555001d,0x5556001d,0x5557001d,0x5558001d,
	0x5559001d,0x555a001d,0x555b001d,0x555c001d,0x555d001d,0x555e001d,0x555f001d,0x5560001d,
	0x5561001d,0x5562001d,0x5563001d,0x5564001d,0x5565001d,0x5566001d,0x5567001d,0x5568001d,
	0x5569001d,0x556a001d,0x556b001d,0x556c001d,0x556d001d,0x556e001d,0x556f001d,0x5570001d,
	0x5571001d,0x5572001d,0x5573001d,0x5574001d,0x5575001d,0x5576001d,0x5577001d,0x5578001d,
	0x5579001d,0x557a001d,0x557b001d,0x557c001d,0x557d001d,0x557e001d,0x557f001d,0x5580001d,
	0x5581001d,0x5582001d,0x5583001d,0x5584001d,0x5585001d,0x5586001d,0x5587001d,0x5588001d,
	0x5589001d,0x558a001d,0x558b001d,0x558c001d,0x558d001d,0x558e001d,0x558f001d,0x5590001d,
	0x5591001d,0x5592001d,0x5593001d,0x5594001d,0x5595001d,0x5596001d,0x5597001d,0x5598001d,
	0x5599001d,0x559a001d,0x559b001d,0x559c001d,0x559d001d,0x559e001d,0x559f001d,0x55a0001d,
	0x55a1001d,0x55a2001d,0x55a3001d,0x55a4001d,0x55a5001d,0x55a6001d,0x55a7001d,0x55a8001d,
	0x55a9001d,0x55aa001d,0x55ab001d,0x55ac001d,0x55ad001d,0x55ae001d,0x55af001d,0x55b0001d,
	0x55b1001d,0x55b2001d,0x55b3001d,0x55b4001d,0x55b5001d,0x55b6001d,0x55b7001d,0x55b8001d,
	0x55b9001d,0x55ba001d,0x55bb001d,0x55bc001d,0x55bd001d,0x55be001d,0x55bf001d,0x55c0001d,
	0x55c1001d,0x55c2001d,0x55c3001d,0x55c4001d,0x55c5001d,0x55c6001d,0x55c7001d,0x55c8001d,
	0x55c9001d,0x55ca001d,0x55cb001d,0x55cc001d,0x55cd001d,0x55ce001d,0x55cf001d,0x55d0001d,
	0x55d1001d,0x55d2001d,0x55d3001d,0x55d4001d,0x55d5001d,0x55d6001d,0x55d7001d,0x55d8001d,
	0x55d9001d,0x55da001d,0x55db001d,0x55dc001d,0x55dd001d,0x55de001d,0x55df001d,0x55e0001d,
	0x55e1001d,0x55e2001d,0x55e3001d,0x55e4001d,0x55e5001d,0x55e6001d,0x55e7001d,0x55e8001d,
	0x55e9001d,0x55ea001d,0x55eb001d,0x55ec001d,0x55ed001d,0x55ee001d,0x55ef001d,0x55f0001d,
	0x55f1001d,0x55f2001d,0x55f3001d,0x55f4001d,0x55f5001d,0x55f6001d,0x55f7001d,0x55f8001d,
	0x55f9001d,0x55fa001d,0x55fb001d,0x55fc001d,0x55fd001d,0x55fe001d,0x55ff001d,0x5600001d,
	0x5601001d,0x5602001d,0x5603001d,0x5604001d,0x5605001d,0x5606001d,0x5607001d,0x5608001d,
	0x5609001d,0x560a001d,0x560b001d,0x560c001d,0x560d001d,0x560e001d,0x560f001d,0x5610001d,
	0x5611001d,0x5612001d,0x5613001d,0x5614001d,0x5615001d,0x5616001d,0x5617001d,0x5618001d,
	0x5619001d,0x561a001d,0x561b001d,0x561c001d,0x561d001d,0x561e001d,0x561f001d,0x5620001d,
	0x5621001d,0x5622001d,0x5623001d,0x5624001d,0x5625001d,0x5626001d,0x5627001d,0x5628001d,
	0x5629001d,0x562a001d,0x562b001d,0x562c001d,0x562d001d,0x562e001d,0x562f001d,0x5630001d,
	0x5631001d,0x5632001d,0x5633001d,0x5634001d,0x5635001d,0x5636001d,0x5637001d,0x5638001d,
	0x5639001d,0x563a001d,0x563b001d,0x563c001d,0x563d001d,0x563e001d,0x563f001d,0x5640001d,
	0x5641001d,0x5642001d,0x5643001d,0x5644001d,0x5645001d,0x5646001d,0x5647001d,0x5648001d,
	0x5649001d,0x564a001d,0x564b001d,0x564c001d,0x564d001d,0x564e001d,0x564f001d,0x5650001d,
	0x5651001d,0x5652001d,0x5653001d,0x5654001d,0x5655001d,0x5656001d,0x5657001d,0x5658001d,
	0x5659001d,0x565a001d,0x565b001d,0x565c001d,0x565d001d,0x565e001d,0x565f001d,0x5660001d,
	0x5661001d,0x5662001d,0x5663001d,0x5664001d,0x5665001d,0x5666001d,0x5667001d,0x5668001d,
	0x5669001d,0x566a001d,0x566b001d,0x566c001d,0x566d001d,0x566e001d,0x566f001d,0x5670001d,
	0x5671001d,0x5672001d,0x5673001d,0x5674001d,0x5675001d,0x5676001d,0x5677001d,0x5678001d,
	0x5679001d,0x567a001d,0x567b001d,0x567c001d,0x567d001d,0x567e001d,0x567f001d,0x5680001d,
	0x5681001d,0x5682001d,0x5683001d,0x5684001d,0x5685001d,0x5686001d,0x5687001d,0x5688001d,
	0x5689001d,0x568a001d,0x568b001d,0x568c001d,0x568d001d,0x568e001d,0x568f001d,0x5690001d,
	0x5691001d,0x5692001d,0x5693001d,0x5694001d,0x5695001d,0x5696001d,0x5697001d,0x5698001d,
	0x5699001d,0x569a001d,0x569b001d,0x569c001d,0x569d001d,0x569e001d,0x569f001d,0x56a0001d,
	0x56a1001d,0x56a2001d,0x56a3001d,0x56a4001d,0x56a5001d,0x56a6001d,0x56a7001d,0x56a8001d,
	0x56a9001d,0x56aa001d,0x56ab001d,0x56ac001d,0x56ad001d,0x56ae001d,0x56af001d,0x56b0001d,
	0x56b1001d,0x56b2001d,0x56b3001d,0x56b4001d,0x56b5001d,0x56b6001d,0x56b7001d,0x56b8001d,
	0x56b9001d,0x56ba001d,0x56bb001d,0x56bc001d,0x56bd001d,0x56be001d,0x56bf001d,0x56c0001d,
	0x56c1001d,0x56c2001d,0x56c3001d,0x56c4001d,0x56c5001d,0x56c6001d,0x56c7001d,0x56c8001d,
	0x56c9001d,0x56ca001d,0x56cb001d,0x56cc001d,0x56cd001d,0x56ce001d,0x56cf001d,0x56d0001d,
	0x56d1001d,0x56d2001d,0x56d3001d,0x56d4001d,0x56d5001d,0x56d6001d,0x56d7001d,0x56d8001d,
	0x56d9001d,0x56da001d,0x56db001d,0x56dc001d,0x56dd001d,0x56de001d,0x56df001d,0x56e0001d,
	0x56e1001d,0x56e2001d,0x56e3001d,0x56e4001d,0x56e5001d,0x56e6001d,0x56e7001d,0x56e8001d,
	0x56e9001d,0x56ea001d,0x56eb001d,0x56ec001d,0x56ed001d,0x56ee001d,0x56ef001d,0x56f0001d,
	0x56f1001d,0x56f2001d,0x56f3001d,0x56f4001d,0x56f5001d,0x56f6001d,0x56f7001d,0x56f8001d,
	0x56f9001d,0x56fa001d,0x56fb001d,0x56fc001d,0x56fd001d,0x56fe001d,0x56ff001d,0x5700001d,
	0x5701001d,0x5702001d,0x5703001d,0x5704001d,0x5705001d,0x5706001d,0x5707001d,0x5708001d,
	0x5709001d,0x570a001d,0x570b001d,0x570c001d,0x570d001d,0x570e001d,0x570f001d,0x5710001d,
	0x5711001d,0x5712001d,0x5713001d,0x5714001d,0x5715001d,0x5716001d,0x5717001d,0x5718001d,
	0x5719001d,0x571a001d,0x571b001d,0x571c001d,0x571d001d,0x571e001d,0x571f001d,0x5720001d,
	0x5721001d,0x5722001d,0x5723001d,0x5724001d,0x5725001d,0x5726001d,0x5727001d,0x5728001d,
	0x5729001d,0x572a001d,0x572b001d,0x572c001d,0x572d001d,0x572e001d,0x572f001d,0x5730001d,
	0x5731001d,0x5732001d,0x5733001d,0x5734001d,0x5735001d,0x5736001d,0x5737001d,0x5738001d,
	0x5739001d,0x573a001d,0x573b001d,0x573c001d,0x573d001d,0x573e001d,0x573f001d,0x5740001d,
	0x5741001d,0x5742001d,0x5743001d,0x5744001d,0x5745001d,0x5746001d,0x5747001d,0x5748001d,
	0x5749001d,0x574a001d,0x574b001d,0x574c001d,0x574d001d,0x574e001d,0x574f001d,0x5750001d,
	0x5751001d,0x5752001d,0x5753001d,0x5754001d,0x5755001d,0x5756001d,0x5757001d,0x5758001d,
	0x5759001d,0x575a001d,0x575b001d,0x575c001d,0x575d001d,0x575e001d,0x575f001d,0x5760001d,
	0x5761001d,0x5762001d,0x5763001d,0x5764001d,0x5765001d,0x5766001d,0x5767001d,0x5768001d,
	0x5769001d,0x576a001d,0x576b001d,0x576c001d,0x576d001d,0x576e001d,0x576f001d,0x5770001d,
	0x5771001d,0x5772001d,0x5773001d,0x5774001d,0x5775001d,0x5776001d,0x5777001d,0x5778001d,
	0x5779001d,0x577a001d,0x577b001d,0x577c001d,0x577d001d,0x577e001d,0x577f001d,0x5780001d,
	0x5781001d,0x5782001d,0x5783001d,0x5784001d,0x5785001d,0x5786001d,0x5787001d,0x5788001d,
	0x5789001d,0x578a001d,0x578b001d,0x578c001d,0x578d001d,0x578e001d,0x578f001d,0x5790001d,
	0x5791001d,0x5792001d,0x5793001d,0x5794001d,0x5795001d,0x5796001d,0x5797001d,0x5798001d,
	0x5799001d,0x579a001d,0x579b001d,0x579c001d,0x579d001d,0x579e001d,0x579f001d,0x57a0001d,
	0x57a1001d,0x57a2001d,0x57a3001d,0x57a4001d,0x57a5001d,0x57a6001d,0x57a7001d,0x57a8001d,
	0x57a9001d,0x57aa001d,0x57ab001d,0x57ac001d,0x57ad001d,0x57ae001d,0x57af001d,0x57b0001d,
	0x57b1001d,0x57b2001d,0x57b3001d,0x57b4001d,0x57b5001d,0x57b6001d,0x57b7001d,0x57b8001d,
	0x57b9001d,0x57ba001d,0x57bb001d,0x57bc001d,0x57bd001d,0x57be001d,0x57bf001d,0x57c0001d,
	0x57c1001d,0x57c2001d,0x57c3001d,0x57c4001d,0x57c5001d,0x57c6001d,0x57c7001d,0x57c8001d,
	0x57c9001d,0x57ca001d,0x57cb001d,0x57cc001d,0x57cd001d,0x57ce001d,0x57cf001d,0x57d0001d,
	0x57d1001d,0x57d2001d,0x57d3001d,0x57d4001d,0x57d5001d,0x57d6001d,0x57d7001d,0x57d8001d,
	0x57d9001d,0x57da001d,0x57db001d,0x57dc001d,0x57dd001d,0x57de001d,0x57df001d,0x57e0001d,
	0x57e1001d,0x57e2001d,0x57e3001d,0x57e4001d,0x57e5001d,0x57e6001d,0x57e7001d,0x57e8001d,
	0x57e9001d,0x57ea001d,0x57eb001d,0x57ec001d,0x57ed001d,0x57ee001d,0x57ef001d,0x57f0001d,
	0x57f1001d,0x57f2001d,0x57f3001d,0x57f4001d,0x57f5001d,0x57f6001d,0x57f7001d,0x57f8001d,
	0x57f9001d,0x57fa001d,0x57fb001d,0x57fc001d,0x57fd001d,0x57fe001d,0x57ff001d,0x5800001d,
	0x5801001d,0x5802001d,0x5803001d,0x5804001d,0x5805001d,0x5806001d,0x5807001d,0x5808001d,
	0x5809001d,0x580a001d,0x580b001d,0x580c001d,0x580d001d,0x580e001d,0x580f001d,0x5810001d,
	0x5811001d,0x5812001d,0x5813001d,0x5814001d,0x5815001d,0x5816001d,0x5817001d,0x5818001d,
	0x5819001d,0x581a001d,0x581b001d,0x581c001d,0x581d001d,0x581e001d,0x581f001d,0x5820001d,
	0x5821001d,0x5822001d,0x5823001d,0x5824001d,0x5825001d,0x5826001d,0x5827001d,0x5828001d,
	0x5829001d,0x582a001d,0x582b001d,0x582c001d,0x582d001d,0x582e001d,0x582f001d,0x5830001d,
	0x5831001d,0x5832001d,0x5833001d,0x5834001d,0x5835001d,0x5836001d,0x5837001d,0x5838001d,
	0x5839001d,0x583a001d,0x583b001d,0x583c001d,0x583d001d,0x583e001d,0x583f001d,0x5840001d,
	0x5841001d,0x5842001d,0x5843001d,0x5844001d,0x5845001d,0x5846001d,0x5847001d,0x5848001d,
	0x5849001d,0x584a001d,0x584b001d,0x584c001d,0x584d001d,0x584e001d,0x584f001d,0x5850001d,
	0x5851001d,0x5852001d,0x5853001d,0x5854001d,0x5855001d,0x5856001d,0x5857001d,0x5858001d,
	0x5859001d,0x585a001d,0x585b001d,0x585c001d,0x585d001d,0x585e001d,0x585f001d,0x5860001d,
	0x5861001d,0x5862001d,0x5863001d,0x5864001d,0x5865001d,0x5866001d,0x5867001d,0x5868001d,
	0x5869001d,0x586a001d,0x586b001d,0x586c001d,0x586d001d,0x586e001d,0x586f001d,0x5870001d,
	0x5871001d,0x5872001d,0x5873001d,0x5874001d,0x5875001d,0x5876001d,0x5877001d,0x5878001d,
	0x5879001d,0x587a001d,0x587b001d,0x587c001d,0x587d001d,0x587e001d,0x587f001d,0x5880001d,
	0x5881001d,0x5882001d,0x5883001d,0x5884001d,0x5885001d,0x5886001d,0x5887001d,0x5888001d,
	0x5889001d,0x588a001d,0x588b001d,0x588c001d,0x588d001d,0x588e001d,0x588f001d,0x5890001d,
	0x5891001d,0x5892001d,0x5893001d,0x5894001d,0x5895001d,0x5896001d,0x5897001d,0x5898001d,
	0x5899001d,0x589a001d,0x589b001d,0x589c001d,0x589d001d,0x589e001d,0x589f001d,0x58a0001d,
	0x58a1001d,0x58a2001d,0x58a3001d,0x58a4001d,0x58a5001d,0x58a6001d,0x58a7001d,0x58a8001d,
	0x58a9001d,0x58aa001d,0x58ab001d,0x58ac001d,0x58ad001d,0x58ae001d,0x58af001d,0x58b0001d,
	0x58b1001d,0x58b2001d,0x58b3001d,0x58b4001d,0x58b5001d,0x58b6001d,0x58b7001d,0x58b8001d,
	0x58b9001d,0x58ba001d,0x58bb001d,0x58bc001d,0x58bd001d,0x58be001d,0x58bf001d,0x58c0001d,
	0x58c1001d,0x58c2001d,0x58c3001d,0x58c4001d,0x58c5001d,0x58c6001d,0x58c7001d,0x58c8001d,
	0x58c9001d,0x58ca001d,0x58cb001d,0x58cc001d,0x58cd001d,0x58ce001d,0x58cf001d,0x58d0001d,
	0x58d1001d,0x58d2001d,0x58d3001d,0x58d4001d,0x58d5001d,0x58d6001d,0x58d7001d,0x58d8001d,
	0x58d9001d,0x58da001d,0x58db001d,0x58dc001d,0x58dd001d,0x58de001d,0x58df001d,0x58e0001d,
	0x58e1001d,0x58e2001d,0x58e3001d,0x58e4001d,0x58e5001d,0x58e6001d,0x58e7001d,0x58e8001d,
	0x58e9001d,0x58ea001d,0x58eb001d,0x58ec001d,0x58ed001d,0x58ee001d,0x58ef001d,0x58f0001d,
	0x58f1001d,0x58f2001d,0x58f3001d,0x58f4001d,0x58f5001d,0x58f6001d,0x58f7001d,0x58f8001d,
	0x58f9001d,0x58fa001d,0x58fb001d,0x58fc001d,0x58fd001d,0x58fe001d,0x58ff001d,0x5900001d,
	0x5901001d,0x5902001d,0x5903001d,0x5904001d,0x5905001d,0x5906001d,0x5907001d,0x5908001d,
	0x5909001d,0x590a001d,0x590b001d,0x590c001d,0x590d001d,0x590e001d,0x590f001d,0x5910001d,
	0x5911001d,0x5912001d,0x5913001d,0x5914001d,0x5915001d,0x5916001d,0x5917001d,0x5918001d,
	0x5919001d,0x591a001d,0x591b001d,0x591c001d,0x591d001d,0x591e001d,0x591f001d,0x5920001d,
	0x5921001d,0x5922001d,0x5923001d,0x5924001d,0x5925001d,0x5926001d,0x5927001d,0x5928001d,
	0x5929001d,0x592a001d,0x592b001d,0x592c001d,0x592d001d,0x592e001d,0x592f001d,0x5930001d,
	0x5931001d,0x5932001d,0x5933001d,0x5934001d,0x5935001d,0x5936001d,0x5937001d,0x5938001d,
	0x5939001d,0x593a001d,0x593b001d,0x593c001d,0x593d001d,0x593e001d,0x593f001d,0x5940001d,
	0x5941001d,0x5942001d,0x5943001d,0x5944001d,0x5945001d,0x5946001d,0x5947001d,0x5948001d,
	0x5949001d,0x594a001d,0x594b001d,0x594c001d,0x594d001d,0x594e001d,0x594f001d,0x5950001d,
	0x5951001d,0x5952001d,0x5953001d,0x5954001d,0x5955001d,0x5956001d,0x5957001d,0x5958001d,
	0x5959001d,0x595a001d,0x595b001d,0x595c001d,0x595d001d,0x595e001d,0x595f001d,0x5960001d,
	0x5961001d,0x5962001d,0x5963001d,0x5964001d,0x5965001d,0x5966001d,0x5967001d,0x5968001d,
	0x5969001d,0x596a001d,0x596b001d,0x596c001d,0x596d001d,0x596e001d,0x596f001d,0x5970001d,
	0x5971001d,0x5972001d,0x5973001d,0x5974001d,0x5975001d,0x5976001d,0x5977001d,0x5978001d,
	0x5979001d,0x597a001d,0x597b001d,0x597c001d,0x597d001d,0x597e001d,0x597f001d,0x5980001d,
	0x5981001d,0x5982001d,0x5983001d,0x5984001d,0x5985001d,0x5986001d,0x5987001d,0x5988001d,
	0x5989001d,0x598a001d,0x598b001d,0x598c001d,0x598d001d,0x598e001d,0x598f001d,0x5990001d,
	0x5991001d,0x5992001d,0x5993001d,0x5994001d,0x5995001d,0x5996001d,0x5997001d,0x5998001d,
	0x5999001d,0x599a001d,0x599b001d,0x599c001d,0x599d001d,0x599e001d,0x599f001d,0x59a0001d,
	0x59a1001d,0x59a2001d,0x59a3001d,0x59a4001d,0x59a5001d,0x59a6001d,0x59a7001d,0x59a8001d,
	0x59a9001d,0x59aa001d,0x59ab001d,0x59ac001d,0x59ad001d,0x59ae001d,0x59af001d,0x59b0001d,
	0x59b1001d,0x59b2001d,0x59b3001d,0x59b4001d,0x59b5001d,0x59b6001d,0x59b7001d,0x59b8001d,
	0x59b9001d,0x59ba001d,0x59bb001d,0x59bc001d,0x59bd001d,0x59be001d,0x59bf001d,0x59c0001d,
	0x59c1001d,0x59c2001d,0x59c3001d,0x59c4001d,0x59c5001d,0x59c6001d,0x59c7001d,0x59c8001d,
	0x59c9001d,0x59ca001d,0x59cb001d,0x59cc001d,0x59cd001d,0x59ce001d,0x59cf001d,0x59d0001d,
	0x59d1001d,0x59d2001d,0x59d3001d,0x59d4001d,0x59d5001d,0x59d6001d,0x59d7001d,0x59d8001d,
	0x59d9001d,0x59da001d,0x59db001d,0x59dc001d,0x59dd001d,0x59de001d,0x59df001d,0x59e0001d,
	0x59e1001d,0x59e2001d,0x59e3001d,0x59e4001d,0x59e5001d,0x59e6001d,0x59e7001d,0x59e8001d,
	0x59e9001d,0x59ea001d,0x59eb001d,0x59ec001d,0x59ed001d,0x59ee001d,0x59ef001d,0x59f0001d,
	0x59f1001d,0x59f2001d,0x59f3001d,0x59f4001d,0x59f5001d,0x59f6001d,0x59f7001d,0x59f8001d,
	0x59f9001d,0x59fa001d,0x59fb001d,0x59fc001d,0x59fd001d,0x59fe001d,0x59ff001d,0x5a00001d,
	0x5a01001d,0x5a02001d,0x5a03001d,0x5a04001d,0x5a05001d,0x5a06001d,0x5a07001d,0x5a08001d,
	0x5a09001d,0x5a0a001d,0x5a0b001d,0x5a0c001d,0x5a0d001d,0x5a0e001d,0x5a0f001d,0x5a10001d,
	0x5a11001d,0x5a12001d,0x5a13001d,0x5a14001d,0x5a15001d,0x5a16001d,0x5a17001d,0x5a18001d,
	0x5a19001d,0x5a1a001d,0x5a1b001d,0x5a1c001d,0x5a1d001d,0x5a1e001d,0x5a1f001d,0x5a20001d,
	0x5a21001d,0x5a22001d,0x5a23001d,0x5a24001d,0x5a25001d,0x5a26001d,0x5a27001d,0x5a28001d,
	0x5a29001d,0x5a2a001d,0x5a2b001d,0x5a2c001d,0x5a2d001d,0x5a2e001d,0x5a2f001d,0x5a30001d,
	0x5a31001d,0x5a32001d,0x5a33001d,0x5a34001d,0x5a35001d,0x5a36001d,0x5a37001d,0x5a38001d,
	0x5a39001d,0x5a3a001d,0x5a3b001d,0x5a3c001d,0x5a3d001d,0x5a3e001d,0x5a3f001d,0x5a40001d,
	0x5a41001d,0x5a42001d,0x5a43001d,0x5a44001d,0x5a45001d,0x5a46001d,0x5a47001d,0x5a48001d,
	0x5a49001d,0x5a4a001d,0x5a4b001d,0x5a4c001d,0x5a4d001d,0x5a4e001d,0x5a4f001d,0x5a50001d,
	0x5a51001d,0x5a52001d,0x5a53001d,0x5a54001d,0x5a55001d,0x5a56001d,0x5a57001d,0x5a58001d,
	0x5a59001d,0x5a5a001d,0x5a5b001d,0x5a5c001d,0x5a5d001d,0x5a5e001d,0x5a5f001d,0x5a60001d,
	0x5a61001d,0x5a62001d,0x5a63001d,0x5a64001d,0x5a65001d,0x5a66001d,0x5a67001d,0x5a68001d,
	0x5a69001d,0x5a6a001d,0x5a6b001d,0x5a6c001d,0x5a6d001d,0x5a6e001d,0x5a6f001d,0x5a70001d,
	0x5a71001d,0x5a72001d,0x5a73001d,0x5a74001d,0x5a75001d,0x5a76001d,0x5a77001d,0x5a78001d,
	0x5a79001d,0x5a7a001d,0x5a7b001d,0x5a7c001d,0x5a7d001d,0x5a7e001d,0x5a7f001d,0x5a80001d,
	0x5a81001d,0x5a82001d,0x5a83001d,0x5a84001d,0x5a85001d,0x5a86001d,0x5a87001d,0x5a88001d,
	0x5a89001d,0x5a8a001d,0x5a8b001d,0x5a8c001d,0x5a8d001d,0x5a8e001d,0x5a8f001d,0x5a90001d,
	0x5a91001d,0x5a92001d,0x5a93001d,0x5a94001d,0x5a95001d,0x5a96001d,0x5a97001d,0x5a98001d,
	0x5a99001d,0x5a9a001d,0x5a9b001d,0x5a9c001d,0x5a9d001d,0x5a9e001d,0x5a9f001d,0x5aa0001d,
	0x5aa1001d,0x5aa2001d,0x5aa3001d,0x5aa4001d,0x5aa5001d,0x5aa6001d,0x5aa7001d,0x5aa8001d,
	0x5aa9001d,0x5aaa001d,0x5aab001d,0x5aac001d,0x5aad001d,0x5aae001d,0x5aaf001d,0x5ab0001d,
	0x5ab1001d,0x5ab2001d,0x5ab3001d,0x5ab4001d,0x5ab5001d,0x5ab6001d,0x5ab7001d,0x5ab8001d,
	0x5ab9001d,0x5aba001d,0x5abb001d,0x5abc001d,0x5abd001d,0x5abe001d,0x5abf001d,0x5ac0001d,
	0x5ac1001d,0x5ac2001d,0x5ac3001d,0x5ac4001d,0x5ac5001d,0x5ac6001d,0x5ac7001d,0x5ac8001d,
	0x5ac9001d,0x5aca001d,0x5acb001d,0x5acc001d,0x5acd001d,0x5ace001d,0x5acf001d,0x5ad0001d,
	0x5ad1001d,0x5ad2001d,0x5ad3001d,0x5ad4001d,0x5ad5001d,0x5ad6001d,0x5ad7001d,0x5ad8001d,
	0x5ad9001d,0x5ada001d,0x5adb001d,0x5adc001d,0x5add001d,0x5ade001d,0x5adf001d,0x5ae0001d,
	0x5ae1001d,0x5ae2001d,0x5ae3001d,0x5ae4001d,0x5ae5001d,0x5ae6001d,0x5ae7001d,0x5ae8001d,
	0x5ae9001d,0x5aea001d,0x5aeb001d,0x5aec001d,0x5aed001d,0x5aee001d,0x5aef001d,0x5af0001d,
	0x5af1001d,0x5af2001d,0x5af3001d,0x5af4001d,0x5af5001d,0x5af6001d,0x5af7001d,0x5af8001d,
	0x5af9001d,0x5afa001d,0x5afb001d,0x5afc001d,0x5afd001d,0x5afe001d,0x5aff001d,0x5b00001d,
	0x5b01001d,0x5b02001d,0x5b03001d,0x5b04001d,0x5b05001d,0x5b06001d,0x5b07001d,0x5b08001d,
	0x5b09001d,0x5b0a001d,0x5b0b001d,0x5b0c001d,0x5b0d001d,0x5b0e001d,0x5b0f001d,0x5b10001d,
	0x5b11001d,0x5b12001d,0x5b13001d,0x5b14001d,0x5b15001d,0x5b16001d,0x5b17001d,0x5b18001d,
	0x5b19001d,0x5b1a001d,0x5b1b001d,0x5b1c001d,0x5b1d001d,0x5b1e001d,0x5b1f001d,0x5b20001d,
	0x5b21001d,0x5b22001d,0x5b23001d,0x5b24001d,0x5b25001d,0x5b26001d,0x5b27001d,0x5b28001d,
	0x5b29001d,0x5b2a001d,0x5b2b001d,0x5b2c001d,0x5b2d001d,0x5b2e001d,0x5b2f001d,0x5b30001d,
	0x5b31001d,0x5b32001d,0x5b33001d,0x5b34001d,0x5b35001d,0x5b36001d,0x5b37001d,0x5b38001d,
	0x5b39001d,0x5b3a001d,0x5b3b001d,0x5b3c001d,0x5b3d001d,0x5b3e001d,0x5b3f001d,0x5b40001d,
	0x5b41001d,0x5b42001d,0x5b43001d,0x5b44001d,0x5b45001d,0x5b46001d,0x5b47001d,0x5b48001d,
	0x5b49001d,0x5b4a001d,0x5b4b001d,0x5b4c001d,0x5b4d001d,0x5b4e001d,0x5b4f001d,0x5b50001d,
	0x5b51001d,0x5b52001d,0x5b53001d,0x5b54001d,0x5b55001d,0x5b56001d,0x5b57001d,0x5b58001d,
	0x5b59001d,0x5b5a001d,0x5b5b001d,0x5b5c001d,0x5b5d001d,0x5b5e001d,0x5b5f001d,0x5b60001d,
	0x5b61001d,0x5b62001d,0x5b63001d,0x5b64001d,0x5b65001d,0x5b66001d,0x5b67001d,0x5b68001d,
	0x5b69001d,0x5b6a001d,0x5b6b001d,0x5b6c001d,0x5b6d001d,0x5b6e001d,0x5b6f001d,0x5b70001d,
	0x5b71001d,0x5b72001d,0x5b73001d,0x5b74001d,0x5b75001d,0x5b76001d,0x5b77001d,0x5b78001d,
	0x5b79001d,0x5b7a001d,0x5b7b001d,0x5b7c001d,0x5b7d001d,0x5b7e001d,0x5b7f001d,0x5b80001d,
	0x5b81001d,0x5b82001d,0x5b83001d,0x5b84001d,0x5b85001d,0x5b86001d,0x5b87001d,0x5b88001d,
	0x5b89001d,0x5b8a001d,0x5b8b001d,0x5b8c001d,0x5b8d001d,0x5b8e001d,0x5b8f001d,0x5b90001d,
	0x5b91001d,0x5b92001d,0x5b93001d,0x5b94001d,0x5b95001d,0x5b96001d,0x5b97001d,0x5b98001d,
	0x5b99001d,0x5b9a001d,0x5b9b001d,0x5b9c001d,0x5b9d001d,0x5b9e001d,0x5b9f001d,0x5ba0001d,
	0x5ba1001d,0x5ba2001d,0x5ba3001d,0x5ba4001d,0x5ba5001d,0x5ba6001d,0x5ba7001d,0x5ba8001d,
	0x5ba9001d,0x5baa001d,0x5bab001d,0x5bac001d,0x5bad001d,0x5bae001d,0x5baf001d,0x5bb0001d,
	0x5bb1001d,0x5bb2001d,0x5bb3001d,0x5bb4001d,0x5bb5001d,0x5bb6001d,0x5bb7001d,0x5bb8001d,
	0x5bb9001d,0x5bba001d,0x5bbb001d,0x5bbc001d,0x5bbd001d,0x5bbe001d,0x5bbf001d,0x5bc0001d,
	0x5bc1001d,0x5bc2001d,0x5bc3001d,0x5bc4001d,0x5bc5001d,0x5bc6001d,0x5bc7001d,0x5bc8001d,
	0x5bc9001d,0x5bca001d,0x5bcb001d,0x5bcc001d,0x5bcd001d,0x5bce001d,0x5bcf001d,0x5bd0001d,
	0x5bd1001d,0x5bd2001d,0x5bd3001d,0x5bd4001d,0x5bd5001d,0x5bd6001d,0x5bd7001d,0x5bd8001d,
	0x5bd9001d,0x5bda001d,0x5bdb001d,0x5bdc001d,0x5bdd001d,0x5bde001d,0x5bdf001d,0x5be0001d,
	0x5be1001d,0x5be2001d,0x5be3001d,0x5be4001d,0x5be5001d,0x5be6001d,0x5be7001d,0x5be8001d,
	0x5be9001d,0x5bea001d,0x5beb001d,0x5bec001d,0x5bed001d,0x5bee001d,0x5bef001d,0x5bf0001d,
	0x5bf1001d,0x5bf2001d,0x5bf3001d,0x5bf4001d,0x5bf5001d,0x5bf6001d,0x5bf7001d,0x5bf8001d,
	0x5bf9001d,0x5bfa001d,0x5bfb001d,0x5bfc001d,0x5bfd001d,0x5bfe001d,0x5bff001d,0x5c00001d,
	0x5c01001d,0x5c02001d,0x5c03001d,0x5c04001d,0x5c05001d,0x5c06001d,0x5c07001d,0x5c08001d,
	0x5c09001d,0x5c0a001d,0x5c0b001d,0x5c0c001d,0x5c0d001d,0x5c0e001d,0x5c0f001d,0x5c10001d,
	0x5c11001d,0x5c12001d,0x5c13001d,0x5c14001d,0x5c15001d,0x5c16001d,0x5c17001d,0x5c18001d,
	0x5c19001d,0x5c1a001d,0x5c1b001d,0x5c1c001d,0x5c1d001d,0x5c1e001d,0x5c1f001d,0x5c20001d,
	0x5c21001d,0x5c22001d,0x5c23001d,0x5c24001d,0x5c25001d,0x5c26001d,0x5c27001d,0x5c28001d,
	0x5c29001d,0x5c2a001d,0x5c2b001d,0x5c2c001d,0x5c2d001d,0x5c2e001d,0x5c2f001d,0x5c30001d,
	0x5c31001d,0x5c32001d,0x5c33001d,0x5c34001d,0x5c35001d,0x5c36001d,0x5c37001d,0x5c38001d,
	0x5c39001d,0x5c3a001d,0x5c3b001d,0x5c3c001d,0x5c3d001d,0x5c3e001d,0x5c3f001d,0x5c40001d,
	0x5c41001d,0x5c42001d,0x5c43001d,0x5c44001d,0x5c45001d,0x5c46001d,0x5c47001d,0x5c48001d,
	0x5c49001d,0x5c4a001d,0x5c4b001d,0x5c4c001d,0x5c4d001d,0x5c4e001d,0x5c4f001d,0x5c50001d,
	0x5c51001d,0x5c52001d,0x5c53001d,0x5c54001d,0x5c55001d,0x5c56001d,0x5c57001d,0x5c58001d,
	0x5c59001d,0x5c5a001d,0x5c5b001d,0x5c5c001d,0x5c5d001d,0x5c5e001d,0x5c5f001d,0x5c60001d,
	0x5c61001d,0x5c62001d,0x5c63001d,0x5c64001d,0x5c65001d,0x5c66001d,0x5c67001d,0x5c68001d,
	0x5c69001d,0x5c6a001d,0x5c6b001d,0x5c6c001d,0x5c6d001d,0x5c6e001d,0x5c6f001d,0x5c70001d,
	0x5c71001d,0x5c72001d,0x5c73001d,0x5c74001d,0x5c75001d,0x5c76001d,0x5c77001d,0x5c78001d,
	0x5c79001d,0x5c7a001d,0x5c7b001d,0x5c7c001d,0x5c7d001d,0x5c7e001d,0x5c7f001d,0x5c80001d,
	0x5c81001d,0x5c82001d,0x5c83001d,0x5c84001d,0x5c85001d,0x5c86001d,0x5c87001d,0x5c88001d,
	0x5c89001d,0x5c8a001d,0x5c8b001d,0x5c8c001d,0x5c8d001d,0x5c8e001d,0x5c8f001d,0x5c90001d,
	0x5c91001d,0x5c92001d,0x5c93001d,0x5c94001d,0x5c95001d,0x5c96001d,0x5c97001d,0x5c98001d,
	0x5c99001d,0x5c9a001d,0x5c9b001d,0x5c9c001d,0x5c9d001d,0x5c9e001d,0x5c9f001d,0x5ca0001d,
	0x5ca1001d,0x5ca2001d,0x5ca3001d,0x5ca4001d,0x5ca5001d,0x5ca6001d,0x5ca7001d,0x5ca8001d,
	0x5ca9001d,0x5caa001d,0x5cab001d,0x5cac001d,0x5cad001d,0x5cae001d,0x5caf001d,0x5cb0001d,
	0x5cb1001d,0x5cb2001d,0x5cb3001d,0x5cb4001d,0x5cb5001d,0x5cb6001d,0x5cb7001d,0x5cb8001d,
	0x5cb9001d,0x5cba001d,0x5cbb001d,0x5cbc001d,0x5cbd001d,0x5cbe001d,0x5cbf001d,0x5cc0001d,
	0x5cc1001d,0x5cc2001d,0x5cc3001d,0x5cc4001d,0x5cc5001d,0x5cc6001d,0x5cc7001d,0x5cc8001d,
	0x5cc9001d,0x5cca001d,0x5ccb001d,0x5ccc001d,0x5ccd001d,0x5cce001d,0x5ccf001d,0x5cd0001d,
	0x5cd1001d,0x5cd2001d,0x5cd3001d,0x5cd4001d,0x5cd5001d,0x5cd6001d,0x5cd7001d,0x5cd8001d,
	0x5cd9001d,0x5cda001d,0x5cdb001d,0x5cdc001d,0x5cdd001d,0x5cde001d,0x5cdf001d,0x5ce0001d,
	0x5ce1001d,0x5ce2001d,0x5ce3001d,0x5ce4001d,0x5ce5001d,0x5ce6001d,0x5ce7001d,0x5ce8001d,
	0x5ce9001d,0x5cea001d,0x5ceb001d,0x5cec001d,0x5ced001d,0x5cee001d,0x5cef001d,0x5cf0001d,
	0x5cf1001d,0x5cf2001d,0x5cf3001d,0x5cf4001d,0x5cf5001d,0x5cf6001d,0x5cf7001d,0x5cf8001d,
	0x5cf9001d,0x5cfa001d,0x5cfb001d,0x5cfc001d,0x5cfd001d,0x5cfe001d,0x5cff001d,0x5d00001d,
	0x5d01001d,0x5d02001d,0x5d03001d,0x5d04001d,0x5d05001d,0x5d06001d,0x5d07001d,0x5d08001d,
	0x5d09001d,0x5d0a001d,0x5d0b001d,0x5d0c001d,0x5d0d001d,0x5d0e001d,0x5d0f001d,0x5d10001d,
	0x5d11001d,0x5d12001d,0x5d13001d,0x5d14001d,0x5d15001d,0x5d16001d,0x5d17001d,0x5d18001d,
	0x5d19001d,0x5d1a001d,0x5d1b001d,0x5d1c001d,0x5d1d001d,0x5d1e001d,0x5d1f001d,0x5d20001d,
	0x5d21001d,0x5d22001d,0x5d23001d,0x5d24001d,0x5d25001d,0x5d26001d,0x5d27001d,0x5d28001d,
	0x5d29001d,0x5d2a001d,0x5d2b001d,0x5d2c001d,0x5d2d001d,0x5d2e001d,0x5d2f001d,0x5d30001d,
	0x5d31001d,0x5d32001d,0x5d33001d,0x5d34001d,0x5d35001d,0x5d36001d,0x5d37001d,0x5d38001d,
	0x5d39001d,0x5d3a001d,0x5d3b001d,0x5d3c001d,0x5d3d001d,0x5d3e001d,0x5d3f001d,0x5d40001d,
	0x5d41001d,0x5d42001d,0x5d43001d,0x5d44001d,0x5d45001d,0x5d46001d,0x5d47001d,0x5d48001d,
	0x5d49001d,0x5d4a001d,0x5d4b001d,0x5d4c001d,0x5d4d001d,0x5d4e001d,0x5d4f001d,0x5d50001d,
	0x5d51001d,0x5d52001d,0x5d53001d,0x5d54001d,0x5d55001d,0x5d56001d,0x5d57001d,0x5d58001d,
	0x5d59001d,0x5d5a001d,0x5d5b001d,0x5d5c001d,0x5d5d001d,0x5d5e001d,0x5d5f001d,0x5d60001d,
	0x5d61001d,0x5d62001d,0x5d63001d,0x5d64001d,0x5d65001d,0x5d66001d,0x5d67001d,0x5d68001d,
	0x5d69001d,0x5d6a001d,0x5d6b001d,0x5d6c001d,0x5d6d001d,0x5d6e001d,0x5d6f001d,0x5d70001d,
	0x5d71001d,0x5d72001d,0x5d73001d,0x5d74001d,0x5d75001d,0x5d76001d,0x5d77001d,0x5d78001d,
	0x5d79001d,0x5d7a001d,0x5d7b001d,0x5d7c001d,0x5d7d001d,0x5d7e001d,0x5d7f001d,0x5d80001d,
	0x5d81001d,0x5d82001d,0x5d83001d,0x5d84001d,0x5d85001d,0x5d86001d,0x5d87001d,0x5d88001d,
	0x5d89001d,0x5d8a001d,0x5d8b001d,0x5d8c001d,0x5d8d001d,0x5d8e001d,0x5d8f001d,0x5d90001d,
	0x5d91001d,0x5d92001d,0x5d93001d,0x5d94001d,0x5d95001d,0x5d96001d,0x5d97001d,0x5d98001d,
	0x5d99001d,0x5d9a001d,0x5d9b001d,0x5d9c001d,0x5d9d001d,0x5d9e001d,0x5d9f001d,0x5da0001d,
	0x5da1001d,0x5da2001d,0x5da3001d,0x5da4001d,0x5da5001d,0x5da6001d,0x5da7001d,0x5da8001d,
	0x5da9001d,0x5daa001d,0x5dab001d,0x5dac001d,0x5dad001d,0x5dae001d,0x5daf001d,0x5db0001d,
	0x5db1001d,0x5db2001d,0x5db3001d,0x5db4001d,0x5db5001d,0x5db6001d,0x5db7001d,0x5db8001d,
	0x5db9001d,0x5dba001d,0x5dbb001d,0x5dbc001d,0x5dbd001d,0x5dbe001d,0x5dbf001d,0x5dc0001d,
	0x5dc1001d,0x5dc2001d,0x5dc3001d,0x5dc4001d,0x5dc5001d,0x5dc6001d,0x5dc7001d,0x5dc8001d,
	0x5dc9001d,0x5dca001d,0x5dcb001d,0x5dcc001d,0x5dcd001d,0x5dce001d,0x5dcf001d,0x5dd0001d,
	0x5dd1001d,0x5dd2001d,0x5dd3001d,0x5dd4001d,0x5dd5001d,0x5dd6001d,0x5dd7001d,0x5dd8001d,
	0x5dd9001d,0x5dda001d,0x5ddb001d,0x5ddc001d,0x5ddd001d,0x5dde001d,0x5ddf001d,0x5de0001d,
	0x5de1001d,0x5de2001d,0x5de3001d,0x5de4001d,0x5de5001d,0x5de6001d,0x5de7001d,0x5de8001d,
	0x5de9001d,0x5dea001d,0x5deb001d,0x5dec001d,0x5ded001d,0x5dee001d,0x5def001d,0x5df0001d,
	0x5df1001d,0x5df2001d,0x5df3001d,0x5df4001d,0x5df5001d,0x5df6001d,0x5df7001d,0x5df8001d,
	0x5df9001d,0x5dfa001d,0x5dfb001d,0x5dfc001d,0x5dfd001d,0x5dfe001d,0x5dff001d,0x5e00001d,
	0x5e01001d,0x5e02001d,0x5e03001d,0x5e04001d,0x5e05001d,0x5e06001d,0x5e07001d,0x5e08001d,
	0x5e09001d,0x5e0a001d,0x5e0b001d,0x5e0c001d,0x5e0d001d,0x5e0e001d,0x5e0f001d,0x5e10001d,
	0x5e11001d,0x5e12001d,0x5e13001d,0x5e14001d,0x5e15001d,0x5e16001d,0x5e17001d,0x5e18001d,
	0x5e19001d,0x5e1a001d,0x5e1b001d,0x5e1c001d,0x5e1d001d,0x5e1e001d,0x5e1f001d,0x5e20001d,
	0x5e21001d,0x5e22001d,0x5e23001d,0x5e24001d,0x5e25001d,0x5e26001d,0x5e27001d,0x5e28001d,
	0x5e29001d,0x5e2a001d,0x5e2b001d,0x5e2c001d,0x5e2d001d,0x5e2e001d,0x5e2f001d,0x5e30001d,
	0x5e31001d,0x5e32001d,0x5e33001d,0x5e34001d,0x5e35001d,0x5e36001d,0x5e37001d,0x5e38001d,
	0x5e39001d,0x5e3a001d,0x5e3b001d,0x5e3c001d,0x5e3d001d,0x5e3e001d,0x5e3f001d,0x5e40001d,
	0x5e41001d,0x5e42001d,0x5e43001d,0x5e44001d,0x5e45001d,0x5e46001d,0x5e47001d,0x5e48001d,
	0x5e49001d,0x5e4a001d,0x5e4b001d,0x5e4c001d,0x5e4d001d,0x5e4e001d,0x5e4f001d,0x5e50001d,
	0x5e51001d,0x5e52001d,0x5e53001d,0x5e54001d,0x5e55001d,0x5e56001d,0x5e57001d,0x5e58001d,
	0x5e59001d,0x5e5a001d,0x5e5b001d,0x5e5c001d,0x5e5d001d,0x5e5e001d,0x5e5f001d,0x5e60001d,
	0x5e61001d,0x5e62001d,0x5e63001d,0x5e64001d,0x5e65001d,0x5e66001d,0x5e67001d,0x5e68001d,
	0x5e69001d,0x5e6a001d,0x5e6b001d,0x5e6c001d,0x5e6d001d,0x5e6e001d,0x5e6f001d,0x5e70001d,
	0x5e71001d,0x5e72001d,0x5e73001d,0x5e74001d,0x5e75001d,0x5e76001d,0x5e77001d,0x5e78001d,
	0x5e79001d,0x5e7a001d,0x5e7b001d,0x5e7c001d,0x5e7d001d,0x5e7e001d,0x5e7f001d,0x5e80001d,
	0x5e81001d,0x5e82001d,0x5e83001d,0x5e84001d,0x5e85001d,0x5e86001d,0x5e87001d,0x5e88001d,
	0x5e89001d,0x5e8a001d,0x5e8b001d,0x5e8c001d,0x5e8d001d,0x5e8e001d,0x5e8f001d,0x5e90001d,
	0x5e91001d,0x5e92001d,0x5e93001d,0x5e94001d,0x5e95001d,0x5e96001d,0x5e97001d,0x5e98001d,
	0x5e99001d,0x5e9a001d,0x5e9b001d,0x5e9c001d,0x5e9d001d,0x5e9e001d,0x5e9f001d,0x5ea0001d,
	0x5ea1001d,0x5ea2001d,0x5ea3001d,0x5ea4001d,0x5ea5001d,0x5ea6001d,0x5ea7001d,0x5ea8001d,
	0x5ea9001d,0x5eaa001d,0x5eab001d,0x5eac001d,0x5ead001d,0x5eae001d,0x5eaf001d,0x5eb0001d,
	0x5eb1001d,0x5eb2001d,0x5eb3001d,0x5eb4001d,0x5eb5001d,0x5eb6001d,0x5eb7001d,0x5eb8001d,
	0x5eb9001d,0x5eba001d,0x5ebb001d,0x5ebc001d,0x5ebd001d,0x5ebe001d,0x5ebf001d,0x5ec0001d,
	0x5ec1001d,0x5ec2001d,0x5ec3001d,0x5ec4001d,0x5ec5001d,0x5ec6001d,0x5ec7001d,0x5ec8001d,
	0x5ec9001d,0x5eca001d,0x5ecb001d,0x5ecc001d,0x5ecd001d,0x5ece001d,0x5ecf001d,0x5ed0001d,
	0x5ed1001d,0x5ed2001d,0x5ed3001d,0x5ed4001d,0x5ed5001d,0x5ed6001d,0x5ed7001d,0x5ed8001d,
	0x5ed9001d,0x5eda001d,0x5edb001d,0x5edc001d,0x5edd001d,0x5ede001d,0x5edf001d,0x5ee0001d,
	0x5ee1001d,0x5ee2001d,0x5ee3001d,0x5ee4001d,0x5ee5001d,0x5ee6001d,0x5ee7001d,0x5ee8001d,
	0x5ee9001d,0x5eea001d,0x5eeb001d,0x5eec001d,0x5eed001d,0x5eee001d,0x5eef001d,0x5ef0001d,
	0x5ef1001d,0x5ef2001d,0x5ef3001d,0x5ef4001d,0x5ef5001d,0x5ef6001d,0x5ef7001d,0x5ef8001d,
	0x5ef9001d,0x5efa001d,0x5efb001d,0x5efc001d,0x5efd001d,0x5efe001d,0x5eff001d,0x5f00001d,
	0x5f01001d,0x5f02001d,0x5f03001d,0x5f04001d,0x5f05001d,0x5f06001d,0x5f07001d,0x5f08001d,
	0x5f09001d,0x5f0a001d,0x5f0b001d,0x5f0c001d,0x5f0d001d,0x5f0e001d,0x5f0f001d,0x5f10001d,
	0x5f11001d,0x5f12001d,0x5f13001d,0x5f14001d,0x5f15001d,0x5f16001d,0x5f17001d,0x5f18001d,
	0x5f19001d,0x5f1a001d,0x5f1b001d,0x5f1c001d,0x5f1d001d,0x5f1e001d,0x5f1f001d,0x5f20001d,
	0x5f21001d,0x5f22001d,0x5f23001d,0x5f24001d,0x5f25001d,0x5f26001d,0x5f27001d,0x5f28001d,
	0x5f29001d,0x5f2a001d,0x5f2b001d,0x5f2c001d,0x5f2d001d,0x5f2e001d,0x5f2f001d,0x5f30001d,
	0x5f31001d,0x5f32001d,0x5f33001d,0x5f34001d,0x5f35001d,0x5f36001d,0x5f37001d,0x5f38001d,
	0x5f39001d,0x5f3a001d,0x5f3b001d,0x5f3c001d,0x5f3d001d,0x5f3e001d,0x5f3f001d,0x5f40001d,
	0x5f41001d,0x5f42001d,0x5f43001d,0x5f44001d,0x5f45001d,0x5f46001d,0x5f47001d,0x5f48001d,
	0x5f49001d,0x5f4a001d,0x5f4b001d,0x5f4c001d,0x5f4d001d,0x5f4e001d,0x5f4f001d,0x5f50001d,
	0x5f51001d,0x5f52001d,0x5f53001d,0x5f54001d,0x5f55001d,0x5f56001d,0x5f57001d,0x5f58001d,
	0x5f59001d,0x5f5a001d,0x5f5b001d,0x5f5c001d,0x5f5d001d,0x5f5e001d,0x5f5f001d,0x5f60001d,
	0x5f61001d,0x5f62001d,0x5f63001d,0x5f64001d,0x5f65001d,0x5f66001d,0x5f67001d,0x5f68001d,
	0x5f69001d,0x5f6a001d,0x5f6b001d,0x5f6c001d,0x5f6d001d,0x5f6e001d,0x5f6f001d,0x5f70001d,
	0x5f71001d,0x5f72001d,0x5f73001d,0x5f74001d,0x5f75001d,0x5f76001d,0x5f77001d,0x5f78001d,
	0x5f79001d,0x5f7a001d,0x5f7b001d,0x5f7c001d,0x5f7d001d,0x5f7e001d,0x5f7f001d,0x5f80001d,
	0x5f81001d,0x5f82001d,0x5f83001d,0x5f84001d,0x5f85001d,0x5f86001d,0x5f87001d,0x5f88001d,
	0x5f89001d,0x5f8a001d,0x5f8b001d,0x5f8c001d,0x5f8d001d,0x5f8e001d,0x5f8f001d,0x5f90001d,
	0x5f91001d,0x5f92001d,0x5f93001d,0x5f94001d,0x5f95001d,0x5f96001d,0x5f97001d,0x5f98001d,
	0x5f99001d,0x5f9a001d,0x5f9b001d,0x5f9c001d,0x5f9d001d,0x5f9e001d,0x5f9f001d,0x5fa0001d,
	0x5fa1001d,0x5fa2001d,0x5fa3001d,0x5fa4001d,0x5fa5001d,0x5fa6001d,0x5fa7001d,0x5fa8001d,
	0x5fa9001d,0x5faa001d,0x5fab001d,0x5fac001d,0x5fad001d,0x5fae001d,0x5faf001d,0x5fb0001d,
	0x5fb1001d,0x5fb2001d,0x5fb3001d,0x5fb4001d,0x5fb5001d,0x5fb6001d,0x5fb7001d,0x5fb8001d,
	0x5fb9001d,0x5fba001d,0x5fbb001d,0x5fbc001d,0x5fbd001d,0x5fbe001d,0x5fbf001d,0x5fc0001d,
	0x5fc1001d,0x5fc2001d,0x5fc3001d,0x5fc4001d,0x5fc5001d,0x5fc6001d,0x5fc7001d,0x5fc8001d,
	0x5fc9001d,0x5fca001d,0x5fcb001d,0x5fcc001d,0x5fcd001d,0x5fce001d,0x5fcf001d,0x5fd0001d,
	0x5fd1001d,0x5fd2001d,0x5fd3001d,0x5fd4001d,0x5fd5001d,0x5fd6001d,0x5fd7001d,0x5fd8001d,
	0x5fd9001d,0x5fda001d,0x5fdb001d,0x5fdc001d,0x5fdd001d,0x5fde001d,0x5fdf001d,0x5fe0001d,
	0x5fe1001d,0x5fe2001d,0x5fe3001d,0x5fe4001d,0x5fe5001d,0x5fe6001d,0x5fe7001d,0x5fe8001d,
	0x5fe9001d,0x5fea001d,0x5feb001d,0x5fec001d,0x5fed001d,0x5fee001d,0x5fef001d,0x5ff0001d,
	0x5ff1001d,0x5ff2001d,0x5ff3001d,0x5ff4001d,0x5ff5001d,0x5ff6001d,0x5ff7001d,0x5ff8001d,
	0x5ff9001d,0x5ffa001d,0x5ffb001d,0x5ffc001d,0x5ffd001d,0x5ffe001d,0x5fff001d,0x6000001d,
	0x6001001d,0x6002001d,0x6003001d,0x6004001d,0x6005001d,0x6006001d,0x6007001d,0x6008001d,
	0x6009001d,0x600a001d,0x600b001d,0x600c001d,0x600d001d,0x600e001d,0x600f001d,0x6010001d,
	0x6011001d,0x6012001d,0x6013001d,0x6014001d,0x6015001d,0x6016001d,0x6017001d,0x6018001d,
	0x6019001d,0x601a001d,0x601b001d,0x601c001d,0x601d001d,0x601e001d,0x601f001d,0x6020001d,
	0x6021001d,0x6022001d,0x6023001d,0x6024001d,0x6025001d,0x6026001d,0x6027001d,0x6028001d,
	0x6029001d,0x602a001d,0x602b001d,0x602c001d,0x602d001d,0x602e001d,0x602f001d,0x6030001d,
	0x6031001d,0x6032001d,0x6033001d,0x6034001d,0x6035001d,0x6036001d,0x6037001d,0x6038001d,
	0x6039001d,0x603a001d,0x603b001d,0x603c001d,0x603d001d,0x603e001d,0x603f001d,0x6040001d,
	0x6041001d,0x6042001d,0x6043001d,0x6044001d,0x6045001d,0x6046001d,0x6047001d,0x6048001d,
	0x6049001d,0x604a001d,0x604b001d,0x604c001d,0x604d001d,0x604e001d,0x604f001d,0x6050001d,
	0x6051001d,0x6052001d,0x6053001d,0x6054001d,0x6055001d,0x6056001d,0x6057001d,0x6058001d,
	0x6059001d,0x605a001d,0x605b001d,0x605c001d,0x605d001d,0x605e001d,0x605f001d,0x6060001d,
	0x6061001d,0x6062001d,0x6063001d,0x6064001d,0x6065001d,0x6066001d,0x6067001d,0x6068001d,
	0x6069001d,0x606a001d,0x606b001d,0x606c001d,0x606d001d,0x606e001d,0x606f001d,0x6070001d,
	0x6071001d,0x6072001d,0x6073001d,0x6074001d,0x6075001d,0x6076001d,0x6077001d,0x6078001d,
	0x6079001d,0x607a001d,0x607b001d,0x607c001d,0x607d001d,0x607e001d,0x607f001d,0x6080001d,
	0x6081001d,0x6082001d,0x6083001d,0x6084001d,0x6085001d,0x6086001d,0x6087001d,0x6088001d,
	0x6089001d,0x608a001d,0x608b001d,0x608c001d,0x608d001d,0x608e001d,0x608f001d,0x6090001d,
	0x6091001d,0x6092001d,0x6093001d,0x6094001d,0x6095001d,0x6096001d,0x6097001d,0x6098001d,
	0x6099001d,0x609a001d,0x609b001d,0x609c001d,0x609d001d,0x609e001d,0x609f001d,0x60a0001d,
	0x60a1001d,0x60a2001d,0x60a3001d,0x60a4001d,0x60a5001d,0x60a6001d,0x60a7001d,0x60a8001d,
	0x60a9001d,0x60aa001d,0x60ab001d,0x60ac001d,0x60ad001d,0x60ae001d,0x60af001d,0x60b0001d,
	0x60b1001d,0x60b2001d,0x60b3001d,0x60b4001d,0x60b5001d,0x60b6001d,0x60b7001d,0x60b8001d,
	0x60b9001d,0x60ba001d,0x60bb001d,0x60bc001d,0x60bd001d,0x60be001d,0x60bf001d,0x60c0001d,
	0x60c1001d,0x60c2001d,0x60c3001d,0x60c4001d,0x60c5001d,0x60c6001d,0x60c7001d,0x60c8001d,
	0x60c9001d,0x60ca001d,0x60cb001d,0x60cc001d,0x60cd001d,0x60ce001d,0x60cf001d,0x60d0001d,
	0x60d1001d,0x60d2001d,0x60d3001d,0x60d4001d,0x60d5001d,0x60d6001d,0x60d7001d,0x60d8001d,
	0x60d9001d,0x60da001d,0x60db001d,0x60dc001d,0x60dd001d,0x60de001d,0x60df001d,0x60e0001d,
	0x60e1001d,0x60e2001d,0x60e3001d,0x60e4001d,0x60e5001d,0x60e6001d,0x60e7001d,0x60e8001d,
	0x60e9001d,0x60ea001d,0x60eb001d,0x60ec001d,0x60ed001d,0x60ee001d,0x60ef001d,0x60f0001d,
	0x60f1001d,0x60f2001d,0x60f3001d,0x60f4001d,0x60f5001d,0x60f6001d,0x60f7001d,0x60f8001d,
	0x60f9001d,0x60fa001d,0x60fb001d,0x60fc001d,0x60fd001d,0x60fe001d,0x60ff001d,0x6100001d,
	0x6101001d,0x6102001d,0x6103001d,0x6104001d,0x6105001d,0x6106001d,0x6107001d,0x6108001d,
	0x6109001d,0x610a001d,0x610b001d,0x610c001d,0x610d001d,0x610e001d,0x610f001d,0x6110001d,
	0x6111001d,0x6112001d,0x6113001d,0x6114001d,0x6115001d,0x6116001d,0x6117001d,0x6118001d,
	0x6119001d,0x611a001d,0x611b001d,0x611c001d,0x611d001d,0x611e001d,0x611f001d,0x6120001d,
	0x6121001d,0x6122001d,0x6123001d,0x6124001d,0x6125001d,0x6126001d,0x6127001d,0x6128001d,
	0x6129001d,0x612a001d,0x612b001d,0x612c001d,0x612d001d,0x612e001d,0x612f001d,0x6130001d,
	0x6131001d,0x6132001d,0x6133001d,0x6134001d,0x6135001d,0x6136001d,0x6137001d,0x6138001d,
	0x6139001d,0x613a001d,0x613b001d,0x613c001d,0x613d001d,0x613e001d,0x613f001d,0x6140001d,
	0x6141001d,0x6142001d,0x6143001d,0x6144001d,0x6145001d,0x6146001d,0x6147001d,0x6148001d,
	0x6149001d,0x614a001d,0x614b001d,0x614c001d,0x614d001d,0x614e001d,0x614f001d,0x6150001d,
	0x6151001d,0x6152001d,0x6153001d,0x6154001d,0x6155001d,0x6156001d,0x6157001d,0x6158001d,
	0x6159001d,0x615a001d,0x615b001d,0x615c001d,0x615d001d,0x615e001d,0x615f001d,0x6160001d,
	0x6161001d,0x6162001d,0x6163001d,0x6164001d,0x6165001d,0x6166001d,0x6167001d,0x6168001d,
	0x6169001d,0x616a001d,0x616b001d,0x616c001d,0x616d001d,0x616e001d,0x616f001d,0x6170001d,
	0x6171001d,0x6172001d,0x6173001d,0x6174001d,0x6175001d,0x6176001d,0x6177001d,0x6178001d,
	0x6179001d,0x617a001d,0x617b001d,0x617c001d,0x617d001d,0x617e001d,0x617f001d,0x6180001d,
	0x6181001d,0x6182001d,0x6183001d,0x6184001d,0x6185001d,0x6186001d,0x6187001d,0x6188001d,
	0x6189001d,0x618a001d,0x618b001d,0x618c001d,0x618d001d,0x618e001d,0x618f001d,0x6190001d,
	0x6191001d,0x6192001d,0x6193001d,0x6194001d,0x6195001d,0x6196001d,0x6197001d,0x6198001d,
	0x6199001d,0x619a001d,0x619b001d,0x619c001d,0x619d001d,0x619e001d,0x619f001d,0x61a0001d,
	0x61a1001d,0x61a2001d,0x61a3001d,0x61a4001d,0x61a5001d,0x61a6001d,0x61a7001d,0x61a8001d,
	0x61a9001d,0x61aa001d,0x61ab001d,0x61ac001d,0x61ad001d,0x61ae001d,0x61af001d,0x61b0001d,
	0x61b1001d,0x61b2001d,0x61b3001d,0x61b4001d,0x61b5001d,0x61b6001d,0x61b7001d,0x61b8001d,
	0x61b9001d,0x61ba001d,0x61bb001d,0x61bc001d,0x61bd001d,0x61be001d,0x61bf001d,0x61c0001d,
	0x61c1001d,0x61c2001d,0x61c3001d,0x61c4001d,0x61c5001d,0x61c6001d,0x61c7001d,0x61c8001d,
	0x61c9001d,0x61ca001d,0x61cb001d,0x61cc001d,0x61cd001d,0x61ce001d,0x61cf001d,0x61d0001d,
	0x61d1001d,0x61d2001d,0x61d3001d,0x61d4001d,0x61d5001d,0x61d6001d,0x61d7001d,0x61d8001d,
	0x61d9001d,0x61da001d,0x61db001d,0x61dc001d,0x61dd001d,0x61de001d,0x61df001d,0x61e0001d,
	0x61e1001d,0x61e2001d,0x61e3001d,0x61e4001d,0x61e5001d,0x61e6001d,0x61e7001d,0x61e8001d,
	0x61e9001d,0x61ea001d,0x61eb001d,0x61ec001d,0x61ed001d,0x61ee001d,0x61ef001d,0x61f0001d,
	0x61f1001d,0x61f2001d,0x61f3001d,0x61f4001d,0x61f5001d,0x61f6001d,0x61f7001d,0x61f8001d,
	0x61f9001d,0x61fa001d,0x61fb001d,0x61fc001d,0x61fd001d,0x61fe001d,0x61ff001d,0x6200001d,
	0x6201001d,0x6202001d,0x6203001d,0x6204001d,0x6205001d,0x6206001d,0x6207001d,0x6208001d,
	0x6209001d,0x620a001d,0x620b001d,0x620c001d,0x620d001d,0x620e001d,0x620f001d,0x6210001d,
	0x6211001d,0x6212001d,0x6213001d,0x6214001d,0x6215001d,0x6216001d,0x6217001d,0x6218001d,
	0x6219001d,0x621a001d,0x621b001d,0x621c001d,0x621d001d,0x621e001d,0x621f001d,0x6220001d,
	0x6221001d,0x6222001d,0x6223001d,0x6224001d,0x6225001d,0x6226001d,0x6227001d,0x6228001d,
	0x6229001d,0x622a001d,0x622b001d,0x622c001d,0x622d001d,0x622e001d,0x622f001d,0x6230001d,
	0x6231001d,0x6232001d,0x6233001d,0x6234001d,0x6235001d,0x6236001d,0x6237001d,0x6238001d,
	0x6239001d,0x623a001d,0x623b001d,0x623c001d,0x623d001d,0x623e001d,0x623f001d,0x6240001d,
	0x6241001d,0x6242001d,0x6243001d,0x6244001d,0x6245001d,0x6246001d,0x6247001d,0x6248001d,
	0x6249001d,0x624a001d,0x624b001d,0x624c001d,0x624d001d,0x624e001d,0x624f001d,0x6250001d,
	0x6251001d,0x6252001d,0x6253001d,0x6254001d,0x6255001d,0x6256001d,0x6257001d,0x6258001d,
	0x6259001d,0x625a001d,0x625b001d,0x625c001d,0x625d001d,0x625e001d,0x625f001d,0x6260001d,
	0x6261001d,0x6262001d,0x6263001d,0x6264001d,0x6265001d,0x6266001d,0x6267001d,0x6268001d,
	0x6269001d,0x626a001d,0x626b001d,0x626c001d,0x626d001d,0x626e001d,0x626f001d,0x6270001d,
	0x6271001d,0x6272001d,0x6273001d,0x6274001d,0x6275001d,0x6276001d,0x6277001d,0x6278001d,
	0x6279001d,0x627a001d,0x627b001d,0x627c001d,0x627d001d,0x627e001d,0x627f001d,0x6280001d,
	0x6281001d,0x6282001d,0x6283001d,0x6284001d,0x6285001d,0x6286001d,0x6287001d,0x6288001d,
	0x6289001d,0x628a001d,0x628b001d,0x628c001d,0x628d001d,0x628e001d,0x628f001d,0x6290001d,
	0x6291001d,0x6292001d,0x6293001d,0x6294001d,0x6295001d,0x6296001d,0x6297001d,0x6298001d,
	0x6299001d,0x629a001d,0x629b001d,0x629c001d,0x629d001d,0x629e001d,0x629f001d,0x62a0001d,
	0x62a1001d,0x62a2001d,0x62a3001d,0x62a4001d,0x62a5001d,0x62a6001d,0x62a7001d,0x62a8001d,
	0x62a9001d,0x62aa001d,0x62ab001d,0x62ac001d,0x62ad001d,0x62ae001d,0x62af001d,0x62b0001d,
	0x62b1001d,0x62b2001d,0x62b3001d,0x62b4001d,0x62b5001d,0x62b6001d,0x62b7001d,0x62b8001d,
	0x62b9001d,0x62ba001d,0x62bb001d,0x62bc001d,0x62bd001d,0x62be001d,0x62bf001d,0x62c0001d,
	0x62c1001d,0x62c2001d,0x62c3001d,0x62c4001d,0x62c5001d,0x62c6001d,0x62c7001d,0x62c8001d,
	0x62c9001d,0x62ca001d,0x62cb001d,0x62cc001d,0x62cd001d,0x62ce001d,0x62cf001d,0x62d0001d,
	0x62d1001d,0x62d2001d,0x62d3001d,0x62d4001d,0x62d5001d,0x62d6001d,0x62d7001d,0x62d8001d,
	0x62d9001d,0x62da001d,0x62db001d,0x62dc001d,0x62dd001d,0x62de001d,0x62df001d,0x62e0001d,
	0x62e1001d,0x62e2001d,0x62e3001d,0x62e4001d,0x62e5001d,0x62e6001d,0x62e7001d,0x62e8001d,
	0x62e9001d,0x62ea001d,0x62eb001d,0x62ec001d,0x62ed001d,0x62ee001d,0x62ef001d,0x62f0001d,
	0x62f1001d,0x62f2001d,0x62f3001d,0x62f4001d,0x62f5001d,0x62f6001d,0x62f7001d,0x62f8001d,
	0x62f9001d,0x62fa001d,0x62fb001d,0x62fc001d,0x62fd001d,0x62fe001d,0x62ff001d,0x6300001d,
	0x6301001d,0x6302001d,0x6303001d,0x6304001d,0x6305001d,0x6306001d,0x6307001d,0x6308001d,
	0x6309001d,0x630a001d,0x630b001d,0x630c001d,0x630d001d,0x630e001d,0x630f001d,0x6310001d,
	0x6311001d,0x6312001d,0x6313001d,0x6314001d,0x6315001d,0x6316001d,0x6317001d,0x6318001d,
	0x6319001d,0x631a001d,0x631b001d,0x631c001d,0x631d001d,0x631e001d,0x631f001d,0x6320001d,
	0x6321001d,0x6322001d,0x6323001d,0x6324001d,0x6325001d,0x6326001d,0x6327001d,0x6328001d,
	0x6329001d,0x632a001d,0x632b001d,0x632c001d,0x632d001d,0x632e001d,0x632f001d,0x6330001d,
	0x6331001d,0x6332001d,0x6333001d,0x6334001d,0x6335001d,0x6336001d,0x6337001d,0x6338001d,
	0x6339001d,0x633a001d,0x633b001d,0x633c001d,0x633d001d,0x633e001d,0x633f001d,0x6340001d,
	0x6341001d,0x6342001d,0x6343001d,0x6344001d,0x6345001d,0x6346001d,0x6347001d,0x6348001d,
	0x6349001d,0x634a001d,0x634b001d,0x634c001d,0x634d001d,0x634e001d,0x634f001d,0x6350001d,
	0x6351001d,0x6352001d,0x6353001d,0x6354001d,0x6355001d,0x6356001d,0x6357001d,0x6358001d,
	0x6359001d,0x635a001d,0x635b001d,0x635c001d,0x635d001d,0x635e001d,0x635f001d,0x6360001d,
	0x6361001d,0x6362001d,0x6363001d,0x6364001d,0x6365001d,0x6366001d,0x6367001d,0x6368001d,
	0x6369001d,0x636a001d,0x636b001d,0x636c001d,0x636d001d,0x636e001d,0x636f001d,0x6370001d,
	0x6371001d,0x6372001d,0x6373001d,0x6374001d,0x6375001d,0x6376001d,0x6377001d,0x6378001d,
	0x6379001d,0x637a001d,0x637b001d,0x637c001d,0x637d001d,0x637e001d,0x637f001d,0x6380001d,
	0x6381001d,0x6382001d,0x6383001d,0x6384001d,0x6385001d,0x6386001d,0x6387001d,0x6388001d,
	0x6389001d,0x638a001d,0x638b001d,0x638c001d,0x638d001d,0x638e001d,0x638f001d,0x6390001d,
	0x6391001d,0x6392001d,0x6393001d,0x6394001d,0x6395001d,0x6396001d,0x6397001d,0x6398001d,
	0x6399001d,0x639a001d,0x639b001d,0x639c001d,0x639d001d,0x639e001d,0x639f001d,0x63a0001d,
	0x63a1001d,0x63a2001d,0x63a3001d,0x63a4001d,0x63a5001d,0x63a6001d,0x63a7001d,0x63a8001d,
	0x63a9001d,0x63aa001d,0x63ab001d,0x63ac001d,0x63ad001d,0x63ae001d,0x63af001d,0x63b0001d,
	0x63b1001d,0x63b2001d,0x63b3001d,0x63b4001d,0x63b5001d,0x63b6001d,0x63b7001d,0x63b8001d,
	0x63b9001d,0x63ba001d,0x63bb001d,0x63bc001d,0x63bd001d,0x63be001d,0x63bf001d,0x63c0001d,
	0x63c1001d,0x63c2001d,0x63c3001d,0x63c4001d,0x63c5001d,0x63c6001d,0x63c7001d,0x63c8001d,
	0x63c9001d,0x63ca001d,0x63cb001d,0x63cc001d,0x63cd001d,0x63ce001d,0x63cf001d,0x63d0001d,
	0x63d1001d,0x63d2001d,0x63d3001d,0x63d4001d,0x63d5001d,0x63d6001d,0x63d7001d,0x63d8001d,
	0x63d9001d,0x63da001d,0x63db001d,0x63dc001d,0x63dd001d,0x63de001d,0x63df001d,0x63e0001d,
	0x63e1001d,0x63e2001d,0x63e3001d,0x63e4001d,0x63e5001d,0x63e6001d,0x63e7001d,0x63e8001d,
	0x63e9001d,0x63ea001d,0x63eb001d,0x63ec001d,0x63ed001d,0x63ee001d,0x63ef001d,0x63f0001d,
	0x63f1001d,0x63f2001d,0x63f3001d,0x63f4001d,0x63f5001d,0x63f6001d,0x63f7001d,0x63f8001d,
	0x63f9001d,0x63fa001d,0x63fb001d,0x63fc001d,0x63fd001d,0x63fe001d,0x63ff001d,0x6400001d,
	0x6401001d,0x6402001d,0x6403001d,0x6404001d,0x6405001d,0x6406001d,0x6407001d,0x6408001d,
	0x6409001d,0x640a001d,0x640b001d,0x640c001d,0x640d001d,0x640e001d,0x640f001d,0x6410001d,
	0x6411001d,0x6412001d,0x6413001d,0x6414001d,0x6415001d,0x6416001d,0x6417001d,0x6418001d,
	0x6419001d,0x641a001d,0x641b001d,0x641c001d,0x641d001d,0x641e001d,0x641f001d,0x6420001d,
	0x6421001d,0x6422001d,0x6423001d,0x6424001d,0x6425001d,0x6426001d,0x6427001d,0x6428001d,
	0x6429001d,0x642a001d,0x642b001d,0x642c001d,0x642d001d,0x642e001d,0x642f001d,0x6430001d,
	0x6431001d,0x6432001d,0x6433001d,0x6434001d,0x6435001d,0x6436001d,0x6437001d,0x6438001d,
	0x6439001d,0x643a001d,0x643b001d,0x643c001d,0x643d001d,0x643e001d,0x643f001d,0x6440001d,
	0x6441001d,0x6442001d,0x6443001d,0x6444001d,0x6445001d,0x6446001d,0x6447001d,0x6448001d,
	0x6449001d,0x644a001d,0x644b001d,0x644c001d,0x644d001d,0x644e001d,0x644f001d,0x6450001d,
	0x6451001d,0x6452001d,0x6453001d,0x6454001d,0x6455001d,0x6456001d,0x6457001d,0x6458001d,
	0x6459001d,0x645a001d,0x645b001d,0x645c001d,0x645d001d,0x645e001d,0x645f001d,0x6460001d,
	0x6461001d,0x6462001d,0x6463001d,0x6464001d,0x6465001d,0x6466001d,0x6467001d,0x6468001d,
	0x6469001d,0x646a001d,0x646b001d,0x646c001d,0x646d001d,0x646e001d,0x646f001d,0x6470001d,
	0x6471001d,0x6472001d,0x6473001d,0x6474001d,0x6475001d,0x6476001d,0x6477001d,0x6478001d,
	0x6479001d,0x647a001d,0x647b001d,0x647c001d,0x647d001d,0x647e001d,0x647f001d,0x6480001d,
	0x6481001d,0x6482001d,0x6483001d,0x6484001d,0x6485001d,0x6486001d,0x6487001d,0x6488001d,
	0x6489001d,0x648a001d,0x648b001d,0x648c001d,0x648d001d,0x648e001d,0x648f001d,0x6490001d,
	0x6491001d,0x6492001d,0x6493001d,0x6494001d,0x6495001d,0x6496001d,0x6497001d,0x6498001d,
	0x6499001d,0x649a001d,0x649b001d,0x649c001d,0x649d001d,0x649e001d,0x649f001d,0x64a0001d,
	0x64a1001d,0x64a2001d,0x64a3001d,0x64a4001d,0x64a5001d,0x64a6001d,0x64a7001d,0x64a8001d,
	0x64a9001d,0x64aa001d,0x64ab001d,0x64ac001d,0x64ad001d,0x64ae001d,0x64af001d,0x64b0001d,
	0x64b1001d,0x64b2001d,0x64b3001d,0x64b4001d,0x64b5001d,0x64b6001d,0x64b7001d,0x64b8001d,
	0x64b9001d,0x64ba001d,0x64bb001d,0x64bc001d,0x64bd001d,0x64be001d,0x64bf001d,0x64c0001d,
	0x64c1001d,0x64c2001d,0x64c3001d,0x64c4001d,0x64c5001d,0x64c6001d,0x64c7001d,0x64c8001d,
	0x64c9001d,0x64ca001d,0x64cb001d,0x64cc001d,0x64cd001d,0x64ce001d,0x64cf001d,0x64d0001d,
	0x64d1001d,0x64d2001d,0x64d3001d,0x64d4001d,0x64d5001d,0x64d6001d,0x64d7001d,0x64d8001d,
	0x64d9001d,0x64da001d,0x64db001d,0x64dc001d,0x64dd001d,0x64de001d,0x64df001d,0x64e0001d,
	0x64e1001d,0x64e2001d,0x64e3001d,0x64e4001d,0x64e5001d,0x64e6001d,0x64e7001d,0x64e8001d,
	0x64e9001d,0x64ea001d,0x64eb001d,0x64ec001d,0x64ed001d,0x64ee001d,0x64ef001d,0x64f0001d,
	0x64f1001d,0x64f2001d,0x64f3001d,0x64f4001d,0x64f5001d,0x64f6001d,0x64f7001d,0x64f8001d,
	0x64f9001d,0x64fa001d,0x64fb001d,0x64fc001d,0x64fd001d,0x64fe001d,0x64ff001d,0x6500001d,
	0x6501001d,0x6502001d,0x6503001d,0x6504001d,0x6505001d,0x6506001d,0x6507001d,0x6508001d,
	0x6509001d,0x650a001d,0x650b001d,0x650c001d,0x650d001d,0x650e001d,0x650f001d,0x6510001d,
	0x6511001d,0x6512001d,0x6513001d,0x6514001d,0x6515001d,0x6516001d,0x6517001d,0x6518001d,
	0x6519001d,0x651a001d,0x651b001d,0x651c001d,0x651d001d,0x651e001d,0x651f001d,0x6520001d,
	0x6521001d,0x6522001d,0x6523001d,0x6524001d,0x6525001d,0x6526001d,0x6527001d,0x6528001d,
	0x6529001d,0x652a001d,0x652b001d,0x652c001d,0x652d001d,0x652e001d,0x652f001d,0x6530001d,
	0x6531001d,0x6532001d,0x6533001d,0x6534001d,0x6535001d,0x6536001d,0x6537001d,0x6538001d,
	0x6539001d,0x653a001d,0x653b001d,0x653c001d,0x653d001d,0x653e001d,0x653f001d,0x6540001d,
	0x6541001d,0x6542001d,0x6543001d,0x6544001d,0x6545001d,0x6546001d,0x6547001d,0x6548001d,
	0x6549001d,0x654a001d,0x654b001d,0x654c001d,0x654d001d,0x654e001d,0x654f001d,0x6550001d,
	0x6551001d,0x6552001d,0x6553001d,0x6554001d,0x6555001d,0x6556001d,0x6557001d,0x6558001d,
	0x6559001d,0x655a001d,0x655b001d,0x655c001d,0x655d001d,0x655e001d,0x655f001d,0x6560001d,
	0x6561001d,0x6562001d,0x6563001d,0x6564001d,0x6565001d,0x6566001d,0x6567001d,0x6568001d,
	0x6569001d,0x656a001d,0x656b001d,0x656c001d,0x656d001d,0x656e001d,0x656f001d,0x6570001d,
	0x6571001d,0x6572001d,0x6573001d,0x6574001d,0x6575001d,0x6576001d,0x6577001d,0x6578001d,
	0x6579001d,0x657a001d,0x657b001d,0x657c001d,0x657d001d,0x657e001d,0x657f001d,0x6580001d,
	0x6581001d,0x6582001d,0x6583001d,0x6584001d,0x6585001d,0x6586001d,0x6587001d,0x6588001d,
	0x6589001d,0x658a001d,0x658b001d,0x658c001d,0x658d001d,0x658e001d,0x658f001d,0x6590001d,
	0x6591001d,0x6592001d,0x6593001d,0x6594001d,0x6595001d,0x6596001d,0x6597001d,0x6598001d,
	0x6599001d,0x659a001d,0x659b001d,0x659c001d,0x659d001d,0x659e001d,0x659f001d,0x65a0001d,
	0x65a1001d,0x65a2001d,0x65a3001d,0x65a4001d,0x65a5001d,0x65a6001d,0x65a7001d,0x65a8001d,
	0x65a9001d,0x65aa001d,0x65ab001d,0x65ac001d,0x65ad001d,0x65ae001d,0x65af001d,0x65b0001d,
	0x65b1001d,0x65b2001d,0x65b3001d,0x65b4001d,0x65b5001d,0x65b6001d,0x65b7001d,0x65b8001d,
	0x65b9001d,0x65ba001d,0x65bb001d,0x65bc001d,0x65bd001d,0x65be001d,0x65bf001d,0x65c0001d,
	0x65c1001d,0x65c2001d,0x65c3001d,0x65c4001d,0x65c5001d,0x65c6001d,0x65c7001d,0x65c8001d,
	0x65c9001d,0x65ca001d,0x65cb001d,0x65cc001d,0x65cd001d,0x65ce001d,0x65cf001d,0x65d0001d,
	0x65d1001d,0x65d2001d,0x65d3001d,0x65d4001d,0x65d5001d,0x65d6001d,0x65d7001d,0x65d8001d,
	0x65d9001d,0x65da001d,0x65db001d,0x65dc001d,0x65dd001d,0x65de001d,0x65df001d,0x65e0001d,
	0x65e1001d,0x65e2001d,0x65e3001d,0x65e4001d,0x65e5001d,0x65e6001d,0x65e7001d,0x65e8001d,
	0x65e9001d,0x65ea001d,0x65eb001d,0x65ec001d,0x65ed001d,0x65ee001d,0x65ef001d,0x65f0001d,
	0x65f1001d,0x65f2001d,0x65f3001d,0x65f4001d,0x65f5001d,0x65f6001d,0x65f7001d,0x65f8001d,
	0x65f9001d,0x65fa001d,0x65fb001d,0x65fc001d,0x65fd001d,0x65fe001d,0x65ff001d,0x6600001d,
	0x6601001d,0x6602001d,0x6603001d,0x6604001d,0x6605001d,0x6606001d,0x6607001d,0x6608001d,
	0x6609001d,0x660a001d,0x660b001d,0x660c001d,0x660d001d,0x660e001d,0x660f001d,0x6610001d,
	0x6611001d,0x6612001d,0x6613001d,0x6614001d,0x6615001d,0x6616001d,0x6617001d,0x6618001d,
	0x6619001d,0x661a001d,0x661b001d,0x661c001d,0x661d001d,0x661e001d,0x661f001d,0x6620001d,
	0x6621001d,0x6622001d,0x6623001d,0x6624001d,0x6625001d,0x6626001d,0x6627001d,0x6628001d,
	0x6629001d,0x662a001d,0x662b001d,0x662c001d,0x662d001d,0x662e001d,0x662f001d,0x6630001d,
	0x6631001d,0x6632001d,0x6633001d,0x6634001d,0x6635001d,0x6636001d,0x6637001d,0x6638001d,
	0x6639001d,0x663a001d,0x663b001d,0x663c001d,0x663d001d,0x663e001d,0x663f001d,0x6640001d,
	0x6641001d,0x6642001d,0x6643001d,0x6644001d,0x6645001d,0x6646001d,0x6647001d,0x6648001d,
	0x6649001d,0x664a001d,0x664b001d,0x664c001d,0x664d001d,0x664e001d,0x664f001d,0x6650001d,
	0x6651001d,0x6652001d,0x6653001d,0x6654001d,0x6655001d,0x6656001d,0x6657001d,0x6658001d,
	0x6659001d,0x665a001d,0x665b001d,0x665c001d,0x665d001d,0x665e001d,0x665f001d,0x6660001d,
	0x6661001d,0x6662001d,0x6663001d,0x6664001d,0x6665001d,0x6666001d,0x6667001d,0x6668001d,
	0x6669001d,0x666a001d,0x666b001d,0x666c001d,0x666d001d,0x666e001d,0x666f001d,0x6670001d,
	0x6671001d,0x6672001d,0x6673001d,0x6674001d,0x6675001d,0x6676001d,0x6677001d,0x6678001d,
	0x6679001d,0x667a001d,0x667b001d,0x667c001d,0x667d001d,0x667e001d,0x667f001d,0x6680001d,
	0x6681001d,0x6682001d,0x6683001d,0x6684001d,0x6685001d,0x6686001d,0x6687001d,0x6688001d,
	0x6689001d,0x668a001d,0x668b001d,0x668c001d,0x668d001d,0x668e001d,0x668f001d,0x6690001d,
	0x6691001d,0x6692001d,0x6693001d,0x6694001d,0x6695001d,0x6696001d,0x6697001d,0x6698001d,
	0x6699001d,0x669a001d,0x669b001d,0x669c001d,0x669d001d,0x669e001d,0x669f001d,0x66a0001d,
	0x66a1001d,0x66a2001d,0x66a3001d,0x66a4001d,0x66a5001d,0x66a6001d,0x66a7001d,0x66a8001d,
	0x66a9001d,0x66aa001d,0x66ab001d,0x66ac001d,0x66ad001d,0x66ae001d,0x66af001d,0x66b0001d,
	0x66b1001d,0x66b2001d,0x66b3001d,0x66b4001d,0x66b5001d,0x66b6001d,0x66b7001d,0x66b8001d,
	0x66b9001d,0x66ba001d,0x66bb001d,0x66bc001d,0x66bd001d,0x66be001d,0x66bf001d,0x66c0001d,
	0x66c1001d,0x66c2001d,0x66c3001d,0x66c4001d,0x66c5001d,0x66c6001d,0x66c7001d,0x66c8001d,
	0x66c9001d,0x66ca001d,0x66cb001d,0x66cc001d,0x66cd001d,0x66ce001d,0x66cf001d,0x66d0001d,
	0x66d1001d,0x66d2001d,0x66d3001d,0x66d4001d,0x66d5001d,0x66d6001d,0x66d7001d,0x66d8001d,
	0x66d9001d,0x66da001d,0x66db001d,0x66dc001d,0x66dd001d,0x66de001d,0x66df001d,0x66e0001d,
	0x66e1001d,0x66e2001d,0x66e3001d,0x66e4001d,0x66e5001d,0x66e6001d,0x66e7001d,0x66e8001d,
	0x66e9001d,0x66ea001d,0x66eb001d,0x66ec001d,0x66ed001d,0x66ee001d,0x66ef001d,0x66f0001d,
	0x66f1001d,0x66f2001d,0x66f3001d,0x66f4001d,0x66f5001d,0x66f6001d,0x66f7001d,0x66f8001d,
	0x66f9001d,0x66fa001d,0x66fb001d,0x66fc001d,0x66fd001d,0x66fe001d,0x66ff001d,0x6700001d,
	0x6701001d,0x6702001d,0x6703001d,0x6704001d,0x6705001d,0x6706001d,0x6707001d,0x6708001d,
	0x6709001d,0x670a001d,0x670b001d,0x670c001d,0x670d001d,0x670e001d,0x670f001d,0x6710001d,
	0x6711001d,0x6712001d,0x6713001d,0x6714001d,0x6715001d,0x6716001d,0x6717001d,0x6718001d,
	0x6719001d,0x671a001d,0x671b001d,0x671c001d,0x671d001d,0x671e001d,0x671f001d,0x6720001d,
	0x6721001d,0x6722001d,0x6723001d,0x6724001d,0x6725001d,0x6726001d,0x6727001d,0x6728001d,
	0x6729001d,0x672a001d,0x672b001d,0x672c001d,0x672d001d,0x672e001d,0x672f001d,0x6730001d,
	0x6731001d,0x6732001d,0x6733001d,0x6734001d,0x6735001d,0x6736001d,0x6737001d,0x6738001d,
	0x6739001d,0x673a001d,0x673b001d,0x673c001d,0x673d001d,0x673e001d,0x673f001d,0x6740001d,
	0x6741001d,0x6742001d,0x6743001d,0x6744001d,0x6745001d,0x6746001d,0x6747001d,0x6748001d,
	0x6749001d,0x674a001d,0x674b001d,0x674c001d,0x674d001d,0x674e001d,0x674f001d,0x6750001d,
	0x6751001d,0x6752001d,0x6753001d,0x6754001d,0x6755001d,0x6756001d,0x6757001d,0x6758001d,
	0x6759001d,0x675a001d,0x675b001d,0x675c001d,0x675d001d,0x675e001d,0x675f001d,0x6760001d,
	0x6761001d,0x6762001d,0x6763001d,0x6764001d,0x6765001d,0x6766001d,0x6767001d,0x6768001d,
	0x6769001d,0x676a001d,0x676b001d,0x676c001d,0x676d001d,0x676e001d,0x676f001d,0x6770001d,
	0x6771001d,0x6772001d,0x6773001d,0x6774001d,0x6775001d,0x6776001d,0x6777001d,0x6778001d,
	0x6779001d,0x677a001d,0x677b001d,0x677c001d,0x677d001d,0x677e001d,0x677f001d,0x6780001d,
	0x6781001d,0x6782001d,0x6783001d,0x6784001d,0x6785001d,0x6786001d,0x6787001d,0x6788001d,
	0x6789001d,0x678a001d,0x678b001d,0x678c001d,0x678d001d,0x678e001d,0x678f001d,0x6790001d,
	0x6791001d,0x6792001d,0x6793001d,0x6794001d,0x6795001d,0x6796001d,0x6797001d,0x6798001d,
	0x6799001d,0x679a001d,0x679b001d,0x679c001d,0x679d001d,0x679e001d,0x679f001d,0x67a0001d,
	0x67a1001d,0x67a2001d,0x67a3001d,0x67a4001d,0x67a5001d,0x67a6001d,0x67a7001d,0x67a8001d,
	0x67a9001d,0x67aa001d,0x67ab001d,0x67ac001d,0x67ad001d,0x67ae001d,0x67af001d,0x67b0001d,
	0x67b1001d,0x67b2001d,0x67b3001d,0x67b4001d,0x67b5001d,0x67b6001d,0x67b7001d,0x67b8001d,
	0x67b9001d,0x67ba001d,0x67bb001d,0x67bc001d,0x67bd001d,0x67be001d,0x67bf001d,0x67c0001d,
	0x67c1001d,0x67c2001d,0x67c3001d,0x67c4001d,0x67c5001d,0x67c6001d,0x67c7001d,0x67c8001d,
	0x67c9001d,0x67ca001d,0x67cb001d,0x67cc001d,0x67cd001d,0x67ce001d,0x67cf001d,0x67d0001d,
	0x67d1001d,0x67d2001d,0x67d3001d,0x67d4001d,0x67d5001d,0x67d6001d,0x67d7001d,0x67d8001d,
	0x67d9001d,0x67da001d,0x67db001d,0x67dc001d,0x67dd001d,0x67de001d,0x67df001d,0x67e0001d,
	0x67e1001d,0x67e2001d,0x67e3001d,0x67e4001d,0x67e5001d,0x67e6001d,0x67e7001d,0x67e8001d,
	0x67e9001d,0x67ea001d,0x67eb001d,0x67ec001d,0x67ed001d,0x67ee001d,0x67ef001d,0x67f0001d,
	0x67f1001d,0x67f2001d,0x67f3001d,0x67f4001d,0x67f5001d,0x67f6001d,0x67f7001d,0x67f8001d,
	0x67f9001d,0x67fa001d,0x67fb001d,0x67fc001d,0x67fd001d,0x67fe001d,0x67ff001d,0x6800001d,
	0x6801001d,0x6802001d,0x6803001d,0x6804001d,0x6805001d,0x6806001d,0x6807001d,0x6808001d,
	0x6809001d,0x680a001d,0x680b001d,0x680c001d,0x680d001d,0x680e001d,0x680f001d,0x6810001d,
	0x6811001d,0x6812001d,0x6813001d,0x6814001d,0x6815001d,0x6816001d,0x6817001d,0x6818001d,
	0x6819001d,0x681a001d,0x681b001d,0x681c001d,0x681d001d,0x681e001d,0x681f001d,0x6820001d,
	0x6821001d,0x6822001d,0x6823001d,0x6824001d,0x6825001d,0x6826001d,0x6827001d,0x6828001d,
	0x6829001d,0x682a001d,0x682b001d,0x682c001d,0x682d001d,0x682e001d,0x682f001d,0x6830001d,
	0x6831001d,0x6832001d,0x6833001d,0x6834001d,0x6835001d,0x6836001d,0x6837001d,0x6838001d,
	0x6839001d,0x683a001d,0x683b001d,0x683c001d,0x683d001d,0x683e001d,0x683f001d,0x6840001d,
	0x6841001d,0x6842001d,0x6843001d,0x6844001d,0x6845001d,0x6846001d,0x6847001d,0x6848001d,
	0x6849001d,0x684a001d,0x684b001d,0x684c001d,0x684d001d,0x684e001d,0x684f001d,0x6850001d,
	0x6851001d,0x6852001d,0x6853001d,0x6854001d,0x6855001d,0x6856001d,0x6857001d,0x6858001d,
	0x6859001d,0x685a001d,0x685b001d,0x685c001d,0x685d001d,0x685e001d,0x685f001d,0x6860001d,
	0x6861001d,0x6862001d,0x6863001d,0x6864001d,0x6865001d,0x6866001d,0x6867001d,0x6868001d,
	0x6869001d,0x686a001d,0x686b001d,0x21e010f,0x234010f,0x269010f,0x2c4010d,0x26a010f,
	0x268010f,0x22d010f,0x23e010f,0x23f010f,0x263010f,0x369010f,0x214010f,0x20c010f,
	0x226010f,0x265010f,0x6c5010d,0x6c6010d,0x6c7010d,0x6c8010d,0x6c9010d,0x6ca010d,
	0x6cb010d,0x6cc010d,0x6cd010d,0x6ce010d,0x21c010f,0x21a010f,0x36d010f,0x36e010f,
	0x36f010f,0x221010f,0x262010f,0x6cf0125,0x6e30125,0x6f70125,0x7030125,0x71f0125,
	0x74b0125,0x7530125,0x7730125,0x78d0125,0x7a10125,0x7b10125,0x7bd0125,0x7e50125,
	0x7ed0125,0x8050125,0x81d0125,0x8290125,0x8350125,0x85d0125,0x8750125,0x88d0125,
	0x8a50125,0x8b10125,0x8b90125,0x8bd0125,0x8c90125,0x240010f,0x241010f,0x2091d0f,
	0x209020f,0x209160f,0x6cf010d,0x6e3010d,0x6f7010d,0x703010d,0x71f010d,0x74b010d,
	0x753010d,0x773010d,0x78d010d,0x7a1010d,0x7b1010d,0x7bd010d,0x7e5010d,0x7ed010d,
	0x805010d,0x81d010d,0x829010d,0x835010d,0x85d010d,0x875010d,0x88d010d,0x8a5010d,
	0x8b1010d,0x8b9010d,0x8bd010d,0x8c9010d,0x242010f,0x371010f,0x243010f,0x374010f,
	0x228010b,0x219010b,0x22e010b,0x22f010b,0x235010b,
	};

static const TUint32 TheChineseIndex[] = 
	{
	0x20181aca,0x20191acb,0x201c1acc,0x30011ac9,0x30021ac8,0x4e0016ba,0x4e0103eb,0x4e030f2d,
	0x4e0713de,0x4e0818d0,0x4e0910e0,0x4e0a113a,0x4e0b14db,0x4e0c0f3c,0x4e0d0176,0x4e0e17d4,
	0x4e100575,0x4e110284,0x4e1319d8,0x4e140fd3,0x4e150ea7,0x4e1611b0,0x4e181014,0x4e190143,
	0x4e1a16ad,0x4e1b02ea,0x4e1c03ff,0x4e1d122e,0x4e1e0232,0x4e2203fd,0x4e240b87,0x4e25163c,
	0x4e2710e8,0x4e28067b,0x4e2a05cd,0x4e2b160f,0x4e2c0e65,0x4e2d197e,0x4e3004fe,0x4e3202af,
	0x4e340bb1,0x4e3619bb,0x4e3813c9,0x4e390348,0x4e3a13fb,0x4e3b19bc,0x4e3d0b3f,0x4e3e098c,
	0x4e3f0ee9,0x4e430dab,0x4e450968,0x4e47139f,0x4e480ccf,0x4e4916ea,0x4e4b1930,0x4e4c144e,
	0x4e4d189f,0x4e4e071f,0x4e4f049b,0x4e500af8,0x4e520ef6,0x4e530e6e,0x4e540fbe,0x4e560642,
	0x4e580239,0x4e5916df,0x4e5c0d41,0x4e5d0967,0x4e5e0f5b,0x4e5f16aa,0x4e6014b3,0x4e61150d,
	0x4e6611dd,0x4e6907db,0x4e700c92,0x4e710c49,0x4e7310bb,0x4e7e0f8f,0x4e860afd,0x4e8817b4,
	0x4e89191c,0x4e8b11b5,0x4e8c0498,0x4e8d029b,0x4e8e17b3,0x4e8f0a7e,0x4e911836,0x4e92073d,
	0x4e930f3d,0x4e941460,0x4e950941,0x4e9805d6,0x4e9a1623,0x4e9b1547,0x4e9f0801,0x4ea01377,
	0x4ea113e1,0x4ea20a08,0x4ea408ba,0x4ea5069c,0x4ea616f1,0x4ea701e1,0x4ea806f7,0x4ea90d8c,
	0x4eab151d,0x4eac0932,0x4ead1355,0x4eae0b89,0x4eb20fdd,0x4eb3015b,0x4eb5155e,0x4eba1086,
	0x4ebb1087,0x4ebf16eb,0x4ec0116f,0x4ec11088,0x4ec20af7,0x4ec303ec,0x4ec41883,0x4ec5091b,
	0x4ec60f14,0x4ec70278,0x4ec918cd,0x4eca0910,0x4ecb0904,0x4ecd1098,0x4ece02e9,0x4ed10c4e,
	0x4ed30198,0x4ed41a0c,0x4ed511b1,0x4ed612ae,0x4ed718d1,0x4ed80554,0x4ed914df,0x4edd1363,
	0x4ede108f,0x4edf0f78,0x4ee105bd,0x4ee30337,0x4ee40bdc,0x4ee516e1,0x4ee810d4,0x4eea16c7,
	0x4eeb0d91,0x4eec0cee,0x4ef0167d,0x4ef2198b,0x4ef30ec3,0x4ef51462,0x4ef6088e,0x4ef7085b,
	0x4efb1090,0x4efd04f6,0x4eff04c8,0x4f010f5c,0x4f090a09,0x4f0a16bc,0x4f0d1463,0x4f0e081d,
	0x4f0f0520,0x4f10049c,0x4f11159b,0x4f17198c,0x4f181784,0x4f1907c9,0x4f1a07a6,0x4f1b17d5,
	0x4f1e10e3,0x4f1f140b,0x4f2002a8,0x4f221617,0x4f241131,0x4f2501eb,0x4f260c4f,0x4f270199,
	0x4f2a140c,0x4f2b19c3,0x4f2f0156,0x4f30060d,0x4f320de1,0x4f340078,0x4f360bc6,0x4f381164,
	0x4f3a1241,0x4f3c1242,0x4f3d083c,0x4f4303c0,0x4f460358,0x4f4d141d,0x4f4e0390,0x4f4f19c4,
	0x4f501a60,0x4f5117a5,0x4f531325,0x4f5506dc,0x4f5713a5,0x4f581155,0x4f5917b5,0x4f5a16f4,
	0x4f5b0513,0x4f5c1a61,0x4f5d05f9,0x4f5e0e16,0x4f5f1365,0x4f600de2,0x4f63176b,0x4f6413be,
	0x4f650f7d,0x4f6709e6,0x4f690e8c,0x4f6c0aee,0x4f6f1677,0x4f700062,0x4f73083f,0x4f740497,
	0x4f760802,0x4f7b133d,0x4f7c08cd,0x4f7e16fa,0x4f7f11a8,0x4f8309fd,0x4f841942,0x4f88025b,
	0x4f890a5e,0x4f8b0b46,0x4f8d11b6,0x4f8f19a6,0x4f9117a6,0x4f940d85,0x4f970409,0x4f9b05e9,
	0x4f9d16bf,0x4fa014cf,0x4fa30c72,0x4fa508ce,0x4fa618fe,0x4fa701a8,0x4fa80fbf,0x4fa90a65,
	0x4faa01ca,0x4fac0e21,0x4fae1469,0x4faf0710,0x4fb50fde,0x4fbf0115,0x4fc302f4,0x4fc4046c,
	0x4fc51020,0x4fca09db,0x4fce1a4c,0x4fcf0fcb,0x4fd00b4b,0x4fd1177d,0x4fd7126e,0x4fd8052b,
	0x4fda0b2f,0x4fdc0ef7,0x4fdd0096,0x4fde17bb,0x4fdf0f5a,0x4fe1157b,0x4fe317da,0x4fe60279,
	0x4fe8164d,0x4fe90b63,0x4fea0b4c,0x4fed0879,0x4fee159c,0x4fef0549,0x4ff1099b,0x4ff30e56,
	0x4ff80512,0x4ffa0020,0x4ffe00d7,0x500c0649,0x500d00b1,0x500f11e4,0x50120374,0x501409c2,
	0x501812f7,0x5019071c,0x501a16e7,0x501c1328,0x501f090b,0x50210202,0x50250a41,0x502609b2,
	0x5028099c,0x50290f9d,0x502a0ddc,0x502c19f9,0x502d143f,0x502e0c60,0x503a18ab,0x503c1944,
	0x503e0ff6,0x5043164f,0x5047085a,0x5048082c,0x504c10d1,0x504e13f1,0x504f0ed1,0x5055154f,
	0x505a1a6a,0x505c1358,0x50650895,0x506c1a37,0x50760e46,0x50771376,0x507b0c08,0x507e04f9,
	0x507f01f6,0x50800a8f,0x5085055e,0x50880b5c,0x508d0085,0x50a30336,0x50a512f9,0x50a70132,
	0x50a80296,0x50a90e32,0x50ac0304,0x50b20040,0x50ba0269,0x50bb110a,0x50cf1527,0x50d614a4,
	0x50da0b92,0x50e60977,0x50e710fd,0x50ec08c6,0x50ed08a1,0x50ee136d,0x50f3127c,0x50f508aa,
	0x50fb0ece,0x51060947,0x510715d3,0x510b0351,0x511210b2,0x51210b0b,0x513f048c,0x51401470,
	0x5141183d,0x5143180b,0x51441594,0x5145026b,0x514618e0,0x514814e0,0x51490657,0x514b0a2e,
	0x514d0d26,0x51510442,0x51541389,0x51551243,0x5156164b,0x515a0365,0x515c0413,0x5162093e,
	0x516510bd,0x5168104e,0x516b0045,0x516c05e6,0x516d0bf4,0x516e1485,0x51700ac1,0x517105f6,
	0x51730646,0x5174157d,0x51750142,0x51760f43,0x51770998,0x517803bb,0x51791a0e,0x517b167e,
	0x517c0868,0x517d11d8,0x51800838,0x518101e6,0x5182095a,0x51850dd3,0x51880593,0x51891074,
	0x518c01a7,0x518d1858,0x51920cc6,0x51950d2a,0x51960d16,0x519710a8,0x51991557,0x519b09d3,
	0x519c0e20,0x51a00648,0x51a21989,0x51a41807,0x51a50d5b,0x51ab0140,0x51ac0400,0x51af050b,
	0x51b00141,0x51b1073f,0x51b2026c,0x51b309bc,0x51b50a78,0x51b616ab,0x51b70b14,0x51bb0408,
	0x51bc14f7,0x51bd0ba4,0x51c0094a,0x51c40f31,0x51c619f6,0x51c7124f,0x51c90b7f,0x51cb03d1,
	0x51cc0bce,0x51cf087e,0x51d102ed,0x51db0bbd,0x51dd0e14,0x51e007f8,0x51e104a9,0x51e40510,
	0x51eb0521,0x51ed0efa,0x51ef09ec,0x51f0077e,0x51f3038b,0x51f50a00,0x51f61593,0x51f8137c,
	0x51f9002e,0x51fa0287,0x51fb07d8,0x51fc0367,0x51fd06a8,0x51ff186b,0x5200036d,0x520103cf,
	0x5202036e,0x5203108d,0x520604ea,0x52070fd1,0x520816ed,0x520a09f6,0x520d028a,0x520e1432,
	0x52111583,0x5212074b,0x5216182a,0x52170ba2,0x52180be3,0x52191878,0x521a0594,0x521b02b6,
	0x521d0288,0x52201114,0x52240e67,0x52280e79,0x52290b40,0x522b012e,0x522d0943,0x522e0638,
	0x52300378,0x52330a50,0x5236195e,0x5237120a,0x52381061,0x52391101,0x523a02df,0x523b0a2f,
	0x523d0671,0x523f0672,0x524009ed,0x52410463,0x52420824,0x52431327,0x524a15e5,0x524c0aaf,
	0x524d0f89,0x5250063c,0x52510891,0x52541319,0x52560f11,0x525c13c5,0x525e07e4,0x5261164a,
	0x52650150,0x5267099d,0x5269118c,0x526a087f,0x526f055d,0x527205ba,0x527d0edb,0x527f08d9,
	0x52810fb8,0x528209c8,0x52880eae,0x529007c3,0x52931718,0x529b0b2a,0x529d1060,0x529e0076,
	0x529f05e7,0x52a0083d,0x52a11472,0x52a20c94,0x52a30ba3,0x52a80407,0x52a919c5,0x52aa0e2a,
	0x52ab08f2,0x52ac1039,0x52ad114a,0x52b10b41,0x52b20925,0x52b30ae7,0x52be06dd,0x52bf11b7,
	0x52c3015a,0x52c7177e,0x52c90d28,0x52cb15f2,0x52d00cfc,0x52d20afb,0x52d615c1,0x52d809f7,
	0x52df0d98,0x52e40fe6,0x52f01553,0x52f9008b,0x52fa1145,0x52fe05f8,0x52ff1471,0x53001837,
	0x5305008c,0x530602e2,0x53081595,0x530d0f1a,0x530f0e7f,0x53100535,0x531500d1,0x53160753,
	0x531700aa,0x531911ce,0x531a04bc,0x531d184c,0x532008b3,0x53210a6e,0x532314ce,0x5326066b,
	0x532a04db,0x532e0a91,0x53390ec1,0x533a102b,0x533b16be,0x533e010d,0x533f0de7,0x53411199,
	0x53430f77,0x534510d7,0x5347117e,0x53481461,0x534907a4,0x534a0077,0x534e074d,0x534f154b,
	0x535100a4,0x53521a46,0x535319fd,0x53550349,0x53560c97,0x53570db6,0x535a015f,0x535c0171,
	0x535e0110,0x535f0172,0x536018b6,0x536109e5,0x53620c18,0x5363179b,0x53640c24,0x5366063e,
	0x53671447,0x536908ee,0x536b141b,0x536e1932,0x536f0cc0,0x53701740,0x537113ef,0x537307ff,
	0x53741065,0x53750c48,0x537709b1,0x5378155b,0x537a091c,0x537f0ff7,0x538201fb,0x53840475,
	0x53851350,0x53860b3b,0x53890b3c,0x538b1610,0x538c1659,0x538d1158,0x539501a9,0x53980b17,
	0x539a0719,0x539d031f,0x539f1811,0x53a21511,0x53a31650,0x53a509c7,0x53a6110f,0x53a8028c,
	0x53a90973,0x53ae1237,0x53b6122c,0x53bb1048,0x53bf1500,0x53c110e1,0x53c2018d,0x53c817a2,
	0x53c901b2,0x53ca07fa,0x53cb1799,0x53cc1216,0x53cd04b3,0x53d1049a,0x53d411e1,0x53d61044,
	0x53d711d6,0x53d80116,0x53d915be,0x53db0e69,0x53df1265,0x53e003e5,0x53e30a4a,0x53e4061e,
	0x53e50993,0x53e60be0,0x53e8036f,0x53e90a4b,0x53ea193f,0x53eb08dd,0x53ec18df,0x53ed0047,
	0x53ee03ed,0x53ef0a2b,0x53f012bf,0x53f10261,0x53f211a5,0x53f317a3,0x53f50f09,0x53f616ae,
	0x53f706cf,0x53f8122f,0x53f912e2,0x53fb0af9,0x53fc03d0,0x53fd07d9,0x540115b4,0x54030246,
	0x540405ce,0x54061687,0x540806db,0x540907fb,0x540a03d6,0x540c1364,0x540d0d57,0x540e0718,
	0x540f0b3e,0x54101387,0x54111523,0x5412189d,0x541314dc,0x54150c71,0x5416160e,0x54170c85,
	0x541b09d4,0x541d0bc1,0x541e1398,0x541f172d,0x542004e1,0x542100d3,0x54230ff0,0x54260515,
	0x54270049,0x54280447,0x542904eb,0x542b06a6,0x542c1352,0x542d0a3d,0x542e121f,0x542f0f60,
	0x54311935,0x5432173a,0x54341459,0x5435020e,0x54381488,0x543902b8,0x543b1433,0x543c0717,
	0x543e145a,0x54401611,0x54430476,0x54460333,0x54480234,0x544a05ae,0x544b0517,0x54500daa,
	0x54520543,0x545316f5,0x54540334,0x54550e45,0x54560b42,0x545700bd,0x5458180c,0x545913c1,
	0x545b0fa2,0x545c1452,0x54620dd1,0x54640bdd,0x54661787,0x54681992,0x5471061b,0x54721a0b,
	0x5473141e,0x547506d7,0x54760dc3,0x547714cb,0x54780e83,0x547b1166,0x547c0721,0x547d0d62,
	0x5480098a,0x5482184d,0x54840457,0x54860e7a,0x548b189e,0x548c06de,0x548e096f,0x548f177b,
	0x54900558,0x5492199a,0x549409e4,0x5495060e,0x549609e2,0x54990bf7,0x549a0401,0x549b0e0f,
	0x549d1231,0x54a30658,0x54a418a1,0x54a616cf,0x54a70ba1,0x54a81a0f,0x54a90d42,0x54aa0d05,
	0x54ab1954,0x54ac169a,0x54ad07e3,0x54af09e8,0x54b1185c,0x54b30a2a,0x54b40793,0x54b814ef,
	0x54bb159d,0x54bd162b,0x54bf16c0,0x54c00004,0x54c10ef1,0x54c2116c,0x54c40700,0x54c60458,
	0x54c713b7,0x54c80694,0x54c91853,0x54cc0e5a,0x54cd151e,0x54ce0003,0x54cf05d5,0x54d00a70,
	0x54d11620,0x54d20324,0x54d3152c,0x54d400e1,0x54d51828,0x54d7074e,0x54d90a67,0x54da045f,
	0x54dc0826,0x54dd0e22,0x54de0d82,0x54df1769,0x54e505b6,0x54e60e3f,0x54e70247,0x54e8114d,
	0x54e90b62,0x54ea0da2,0x54ed0a52,0x54ee1542,0x54f218eb,0x54f31890,0x54fa0174,0x54fc06f8,
	0x54fd05de,0x54ff05cb,0x5501165c,0x5506129e,0x550702c4,0x55090005,0x550f148f,0x551012e9,
	0x55111a68,0x55140c82,0x551b0c8d,0x55200af2,0x552212a8,0x55231873,0x5524076d,0x552707e5,
	0x552a050f,0x552c073b,0x552e11d9,0x552f1405,0x5530120b,0x55310204,0x55330b57,0x5537176a,
	0x553c110c,0x553e13b5,0x553f0725,0x5541198e,0x55430a3b,0x55441a05,0x55461133,0x55490ace,
	0x554a0001,0x55500309,0x55551309,0x5556035a,0x555c02cc,0x556104d0,0x55640eba,0x55651109,
	0x55660ab4,0x5567187d,0x556a0e4c,0x556c10f8,0x556d19dc,0x556e0e05,0x5575016c,0x557603f9,
	0x55770ad8,0x55781546,0x557b0268,0x557c131e,0x557e0964,0x558009e3,0x55811778,0x55821424,
	0x55830db8,0x55841127,0x55870aae,0x558808ea,0x55890711,0x558a06af,0x558b03e2,0x558f0e34,
	0x5591172b,0x55940e3e,0x559802ae,0x559907b2,0x559c14be,0x559d06d8,0x559f0a92,0x55a715ce,
	0x55b10b1d,0x55b31891,0x55b50d30,0x55b70e92,0x55b90a86,0x55bb17f6,0x55bd0c09,0x55be0a59,
	0x55c4110b,0x55c515ab,0x55c91278,0x55cc0014,0x55cd129d,0x55d10a28,0x55d20327,0x55d310e9,
	0x55d4021d,0x55d6125d,0x55dc11c9,0x55dd05c5,0x55df08eb,0x55e1143a,0x55e3124b,0x55e4024c,
	0x55e506c8,0x55e612ac,0x55e80695,0x55ea0fe7,0x55eb0e06,0x55ec06d9,0x55ef0d9f,0x55f203b5,
	0x55f3000c,0x55f51362,0x55f70031,0x55fd1269,0x55fe1266,0x56000395,0x56010f38,0x560801a1,
	0x5609084a,0x560c0edf,0x560e056a,0x560f062a,0x561815b1,0x561b0c8f,0x561e0b10,0x561f041f,
	0x562300c8,0x56241747,0x56270d20,0x562c1a5d,0x562d0e99,0x563119c0,0x5632020c,0x56341a53,
	0x56361239,0x56390b94,0x563b14a8,0x563f06f2,0x564c01af,0x564d08e3,0x564e16a5,0x56540385,
	0x56570f19,0x565809b9,0x56590fe9,0x565c0c16,0x56620e3d,0x56640931,0x56680f70,0x56690486,
	0x566a1875,0x566b16c5,0x566c11cc,0x567115e8,0x5676056d,0x567b10dd,0x567c0eaf,0x568510b3,
	0x568606c4,0x568e06ca,0x568f132f,0x5693017f,0x56a3153a,0x56af07d4,0x56b7107a,0x56bc08cb,
	0x56ca0dbe,0x56d40dbd,0x56d713fa,0x56da101b,0x56db123e,0x56dd0876,0x56de079c,0x56df157a,
	0x56e01721,0x56e10db4,0x56e2138d,0x56e4044e,0x56eb0729,0x56ed180d,0x56f00aa4,0x56f102e1,
	0x56f413fe,0x56f50c50,0x56f90bc8,0x56fa062d,0x56fd068a,0x56fe137f,0x56ff17a7,0x57030f23,
	0x570417dd,0x57061812,0x5708104d,0x570917de,0x570a0ff8,0x571c0768,0x571f1386,0x57231189,
	0x57281859,0x572913fd,0x572a05b3,0x572c144f,0x572d065f,0x572e0ec4,0x572f16c8,0x573003a9,
	0x57331914,0x57390a76,0x573a01fa,0x573b0f40,0x573e07dc,0x57401950,0x57420071,0x574709d5,
	0x574a04bf,0x574c00c4,0x574d12ce,0x574e09fc,0x574f075c,0x57501a62,0x57510a3e,0x57570a63,
	0x575a0863,0x575b12d4,0x575c0b43,0x575d0058,0x575e146e,0x575f04f0,0x576019ee,0x57610f03,
	0x57640a9a,0x576612de,0x576813a7,0x5769057f,0x576a0efb,0x576b03c3,0x576d0dd9,0x576f0eab,
	0x5773003e,0x57760d94,0x57770a17,0x577b03a3,0x577c0216,0x578202ba,0x57830aaa,0x57840c04,
	0x57850c05,0x57860c1b,0x578b1588,0x578c040a,0x57920b08,0x57930572,0x579b0460,0x57a0172e,
	0x57a1049d,0x57a20607,0x57a3180f,0x57a403df,0x57a60a39,0x57a71137,0x57a9047a,0x57ab03c5,
	0x57ad1626,0x57ae0a5d,0x57b209ee,0x57b40dc9,0x57b81821,0x57c205df,0x57c30006,0x57cb0c90,
	0x57ce0238,0x57cf1638,0x57d20ba6,0x57d40f24,0x57d5023a,0x57d811a3,0x57d915f3,0x57da0683,
	0x57dd0df7,0x57df17f2,0x57e0017c,0x57e40ebb,0x57ed0342,0x57ef0021,0x57f41945,0x57f8170a,
	0x57f90e87,0x57fa07ea,0x57fd10f4,0x58000a53,0x580212ea,0x5806043f,0x58070919,0x580b0e9b,
	0x580d138a,0x58110f9e,0x58150464,0x5819172c,0x581e03e3,0x5820071d,0x58210098,0x58240392,
	0x582a09f9,0x58301662,0x5835042b,0x58440b11,0x584c12b2,0x584d023e,0x58511279,0x585412b4,
	0x585812ec,0x585e10db,0x586505c6,0x586b1336,0x586c1817,0x587e11f2,0x58800257,0x58810ca3,
	0x58830956,0x58851207,0x58891771,0x58921135,0x58930d99,0x58990fad,0x589a0b84,0x589e1889,
	0x589f15b3,0x58a80d7c,0x58a90449,0x58bc07f4,0x58c100f7,0x58c51773,0x58d106f0,0x58d506cb,
	0x58e4107b,0x58eb11ad,0x58ec1089,0x58ee19e6,0x58f01180,0x58f30a29,0x58f6072d,0x58f916c2,
	0x5902194d,0x5904029a,0x590700ae,0x590d055b,0x590f14dd,0x59140a8d,0x59151484,0x591613c3,
	0x5919126f,0x591a0456,0x591c16b2,0x591f0608,0x59241734,0x592507cb,0x59270332,0x59291330,
	0x592a12c7,0x592b0516,0x592d1686,0x592e166c,0x592f06bd,0x5931118f,0x59341378,0x593716c9,
	0x59380a5c,0x5939083e,0x593a045b,0x593c0a74,0x59410b64,0x5942076b,0x5944164c,0x59470f44,
	0x59480daf,0x59490511,0x594b04f7,0x594e0a83,0x594f1a41,0x59510f6c,0x595400be,0x59551701,
	0x595608af,0x5957130e,0x595819e5,0x595a1490,0x596003ca,0x5962114f,0x59650041,0x59730e39,
	0x59740e27,0x59760dac,0x59780861,0x597912ad,0x597d06cd,0x59811224,0x598210af,0x598304ce,
	0x598413ea,0x598619e1,0x59870555,0x59880c83,0x598a1092,0x598d163d,0x5992042f,0x5993081f,
	0x59961688,0x59970926,0x59990d3d,0x599e0e18,0x59a300d4,0x59a417b6,0x59a513b0,0x59a804c4,
	0x59a91464,0x59aa17e8,0x59ab0660,0x59ae0dd7,0x59af1995,0x59b2032a,0x59b90ce5,0x59bb0f2f,
	0x59be0fd5,0x59c60d8e,0x59ca1a25,0x59cb11a9,0x59d00902,0x59d1060f,0x59d21244,0x59d3158e,
	0x59d4140f,0x59d71117,0x59d80eeb,0x59da168e,0x59dc08a5,0x59dd11e3,0x59e308bc,0x59e50aef,
	0x59e816d0,0x59ec07e6,0x59f901c5,0x59fb1723,0x59ff1a10,0x5a0113f0,0x5a0313bc,0x5a040c07,
	0x5a051627,0x5a061081,0x5a0708bd,0x5a080c3f,0x5a090ef5,0x5a0c0b30,0x5a11129f,0x5a131413,
	0x5a180df8,0x5a1c0da6,0x5a1f09aa,0x5a201169,0x5a2303ac,0x5a25046d,0x5a290d29,0x5a3117bf,
	0x5a3213ba,0x5a3414f1,0x5a361045,0x5a3c01ed,0x5a40046a,0x5a460f06,0x5a4913d4,0x5a4a0128,
	0x5a5508f8,0x5a5a07ba,0x5a6200e8,0x5a670951,0x5a6a0ac5,0x5a741745,0x5a7501d5,0x5a761174,
	0x5a771359,0x5a7a147c,0x5a7f15c5,0x5a920cd7,0x5a9a0ce8,0x5a9b1822,0x5aaa003c,0x5ab20ecd,
	0x5ab314b7,0x5ab51768,0x5ab8024d,0x5abe0609,0x5ac1085e,0x5ac210f3,0x5ac907f7,0x5acc14f6,
	0x5ad20015,0x5ad40eee,0x5ad60ee1,0x5ad80aff,0x5adc18c6,0x5ae00b22,0x5ae1039f,0x5ae31637,
	0x5ae601f9,0x5ae90dd4,0x5aeb0d67,0x5af10fae,0x5b0914a9,0x5b1600f8,0x5b17112b,0x5b320dfd,
	0x5b34175d,0x5b370d65,0x5b401218,0x5b501a24,0x5b5108ef,0x5b5309bb,0x5b540a44,0x5b551841,
	0x5b571a2c,0x5b580313,0x5b591295,0x5b5a0522,0x5b5b00bc,0x5b5c1a0d,0x5b5d1541,0x5b5f0d03,
	0x5b62008d,0x5b630825,0x5b640610,0x5b650e28,0x5b6615ea,0x5b690696,0x5b6a0c40,0x5b6c0dc2,
	0x5b7011f0,0x5b7101d7,0x5b731a16,0x5b75051d,0x5b7a10b4,0x5b7d0e0b,0x5b800d22,0x5b810e0e,
	0x5b8312af,0x5b840668,0x5b8518a9,0x5b8717d6,0x5b8811d2,0x5b890019,0x5b8b1259,0x5b8c13cc,
	0x5b8f0706,0x5b930d19,0x5b950368,0x5b971a30,0x5b980656,0x5b99199b,0x5b9a03f8,0x5b9b13d0,
	0x5b9c16cc,0x5b9d0094,0x5b9e119e,0x5ba00274,0x5ba11171,0x5ba20a30,0x5ba315cc,0x5ba411bb,
	0x5ba517a8,0x5ba6076c,0x5baa1506,0x5bab05eb,0x5bb01855,0x5bb3069e,0x5bb4165d,0x5bb5152f,
	0x5bb60844,0x5bb80224,0x5bb910a0,0x5bbd0a6b,0x5bbe0130,0x5bbf1275,0x5bc2082d,0x5bc4082e,
	0x5bc51730,0x5bc60d1d,0x5bc70a4d,0x5bcc055f,0x5bd00ce9,0x5bd206ac,0x5bd317f7,0x5bdd0fef,
	0x5bde0d78,0x5bdf01bd,0x5be1063d,0x5be41480,0x5be50b93,0x5be818ad,0x5bee0b95,0x5bf00765,
	0x5bf80315,0x5bf90441,0x5bfa123f,0x5bfb15f9,0x5bfc0372,0x5bff11d5,0x5c010502,0x5c04115b,
	0x5c0608a6,0x5c091422,0x5c0a1a58,0x5c0f153e,0x5c111149,0x5c140490,0x5c15056e,0x5c160862,
	0x5c18021e,0x5c1a113b,0x5c1c056c,0x5c1d01f5,0x5c22178a,0x5c24178b,0x5c250b9e,0x5c27168c,
	0x5c2c056f,0x5c310975,0x5c340586,0x5c38118e,0x5c391738,0x5c3a025a,0x5c3b0a0e,0x5c3c0dd8,
	0x5c3d0924,0x5c3e13f9,0x5c3f0dfe,0x5c400987,0x5c410ecb,0x5c4201b0,0x5c450979,0x5c481030,
	0x5c491326,0x5c4a0907,0x5c4b1454,0x5c4e11ab,0x5c4f0efd,0x5c5007e7,0x5c51155c,0x5c5518b8,
	0x5c590469,0x5c5e11fb,0x5c601384,0x5c610c76,0x5c6314c0,0x5c650c7a,0x5c6609a6,0x5c6e0214,
	0x5c6f139a,0x5c711112,0x5c7916f2,0x5c7a0f5d,0x5c7f17d7,0x5c81128c,0x5c820f5e,0x5c881618,
	0x5c8c07fc,0x5c8d0f7e,0x5c900f41,0x5c9101ad,0x5c9401c3,0x5c96102d,0x5c97059a,0x5c981501,
	0x5c99003f,0x5c9a0ac2,0x5c9b0373,0x5c9c004a,0x5ca20a2c,0x5ca305ff,0x5ca91640,0x5cab15a6,
	0x5cac0854,0x5cad0bde,0x5cb10338,0x5cb3182b,0x5cb50742,0x5cb70d48,0x5cb80025,0x5cbd0402,
	0x5cbf0a7f,0x5cc10cc1,0x5cc416fb,0x5ccb15fd,0x5cd2040b,0x5cd91965,0x5ce114d1,0x5ce40fbd,
	0x5ce5191f,0x5ce60c41,0x5ce8046e,0x5cea17ee,0x5ced0fcd,0x5cf00505,0x5cfb09dd,0x5d020ae9,
	0x5d030ab6,0x5d060a42,0x5d070273,0x5d0e0f4a,0x5d140303,0x5d16161c,0x5d1b09c3,0x5d1e0685,
	0x5d24153c,0x5d26162f,0x5d271250,0x5d2900c6,0x5d2d18ba,0x5d2e0630,0x5d3413ee,0x5d3d1856,
	0x5d3e169d,0x5d4707f9,0x5d4a118d,0x5d4b0cd8,0x5d4c0f9f,0x5d5810a1,0x5d5b17c7,0x5d5d0c0f,
	0x5d691253,0x5d6b1a17,0x5d6c1409,0x5d6f031a,0x5d740817,0x5d8218d7,0x5d990bb5,0x5d9d038c,
	0x5db716da,0x5dc503b9,0x5dcd13f8,0x5ddb02a4,0x5ddd02a5,0x5dde198f,0x5de115fa,0x5de2020a,
	0x5de505e4,0x5de61a5f,0x5de70fc9,0x5de80994,0x5de905f2,0x5deb1453,0x5dee01c6,0x5def1025,
	0x5df10811,0x5df216e0,0x5df3123d,0x5df40046,0x5df71524,0x5dfd160c,0x5dfe090f,0x5e0100db,
	0x5e0211b2,0x5e030177,0x5e051210,0x5e0604a4,0x5e081190,0x5e0c1489,0x5e0f13ff,0x5e1018d2,
	0x5e1112f6,0x5e140e8d,0x5e150e53,0x5e16134e,0x5e180b66,0x5e19195f,0x5e1a1998,0x5e1b0158,
	0x5e1c1960,0x5e1d03ab,0x5e26033c,0x5e27190c,0x5e2d14b4,0x5e2e007e,0x5e31027a,0x5e371406,
	0x5e3801f7,0x5e3b187e,0x5e3c068b,0x5e3d0cca,0x5e420d1e,0x5e441448,0x5e45053c,0x5e4c0791,
	0x5e540ca4,0x5e550d9a,0x5e5b18d8,0x5e5e0540,0x5e6104a6,0x5e6202b4,0x5e72057b,0x5e730ef8,
	0x5e740ded,0x5e76014a,0x5e78158f,0x5e7a1685,0x5e7b076a,0x5e7c17a4,0x5e7d1788,0x5e7f065b,
	0x5e800ec2,0x5e8419e2,0x5e861007,0x5e8700df,0x5e8a02b3,0x5e8b066a,0x5e8f15bd,0x5e900c19,
	0x5e911465,0x5e930a57,0x5e941743,0x5e9503a4,0x5e960e7b,0x5e9703c4,0x5e990d3e,0x5e9a05da,
	0x5e9c0546,0x5e9e0e71,0x5e9f04e2,0x5ea0151a,0x5ea5159e,0x5ea60432,0x5ea71a69,0x5ead1356,
	0x5eb300a9,0x5eb5001c,0x5eb61204,0x5eb70a04,0x5eb8176f,0x5eb913b1,0x5ebe17df,0x5ec90b6c,
	0x5eca0adb,0x5ed10920,0x5ed20032,0x5ed30aa9,0x5ed60b9c,0x5edb01dc,0x5ee81563,0x5eea0bbe,
	0x5ef41737,0x5ef6163a,0x5ef71354,0x5efa088f,0x5efe05f1,0x5eff0df5,0x5f0009e9,0x5f010111,
	0x5f0216f3,0x5f030f69,0x5f040e25,0x5f081702,0x5f0a00f3,0x5f0b16ec,0x5f0f11b4,0x5f1111c6,
	0x5f1305e5,0x5f151739,0x5f17051f,0x5f180704,0x5f1b0251,0x5f1f03aa,0x5f2018c3,0x5f250d07,
	0x5f2614ed,0x5f27072a,0x5f290e2b,0x5f2a094b,0x5f2d0d13,0x5f2f13c4,0x5f3110d2,0x5f39035b,
	0x5f3a0fac,0x5f3c00eb,0x5f40060a,0x5f5015ed,0x5f52065e,0x5f530362,0x5f550c2d,0x5f561390,
	0x5f5707af,0x5f581972,0x5f5d16db,0x5f611113,0x5f621586,0x5f641366,0x5f66165a,0x5f690188,
	0x5f6a011c,0x5f6c0131,0x5f6d0e9c,0x5f7018c7,0x5f711764,0x5f730260,0x5f770e70,0x5f7916f6,
	0x5f7b0215,0x5f7c00d5,0x5f8013e4,0x5f81191d,0x5f8202f2,0x5f84094c,0x5f85033d,0x5f871609,
	0x5f8806f4,0x5f891679,0x5f8a0758,0x5f8b0c7d,0x5f8c071a,0x5f9015b5,0x5f921380,0x5f950aba,
	0x5f97037f,0x5f980e57,0x5f9914bc,0x5f9c01f8,0x5fa117f8,0x5fa80781,0x5faa1602,0x5fad1693,
	0x5fae13f5,0x5fb51926,0x5fb70381,0x5fbc08db,0x5fbd079a,0x5fc3156d,0x5fc4156c,0x5fc500dc,
	0x5fc616ee,0x5fc90370,0x5fcc0820,0x5fcd108a,0x5fcf01e8,0x5fd012dd,0x5fd1130f,0x5fd21310,
	0x5fd60314,0x5fd7195b,0x5fd813eb,0x5fd90cac,0x5fdd1338,0x5fe0197f,0x5fe1026d,0x5fe41466,
	0x5fe71785,0x5fea124d,0x5feb0a64,0x5fed0112,0x5fee195c,0x5ff10220,0x5ff50df6,0x5ff80e1a,
	0x5ffb156e,0x5ffd0722,0x5ffe09f5,0x5fff04f8,0x60000757,0x600112c9,0x60021254,0x60031467,
	0x60040e49,0x60050200,0x600602b7,0x600a0206,0x600d1a64,0x600e1886,0x600f1681,0x60120e2d,
	0x6014191e,0x60150e54,0x60160179,0x60190743,0x601b032b,0x601c0b67,0x601d1232,0x6020033e,
	0x602116cd,0x60250803,0x60260e95,0x60271590,0x6028181f,0x60290dda,0x602a0645,0x602b0525,
	0x602f0fd6,0x6035029c,0x603b1a36,0x603c0443,0x603f16fc,0x60410dd5,0x604215fe,0x604311bc,
	0x604b0b79,0x604d078e,0x60500a45,0x605206f9,0x60551203,0x60591682,0x605a07ac,0x605d084f,
	0x60620794,0x60631a22,0x606415bf,0x60670e3b,0x606806f6,0x60690489,0x606a0a31,0x606b040c,
	0x606c1333,0x606d05ec,0x606f1491,0x60700f74,0x60730a3a,0x6076047b,0x60781374,0x6079162c,
	0x607a09ef,0x607b01aa,0x607c0dca,0x607d1844,0x607f1780,0x60830aa1,0x60840fc8,0x60891494,
	0x608c1329,0x608d06b3,0x60921706,0x609407a1,0x609600b2,0x609a1255,0x609b104c,0x609d0a80,
	0x609f1479,0x60a01789,0x60a30771,0x60a6182c,0x60a80e0d,0x60ab1066,0x60ac15d6,0x60ad0f81,
	0x60af0d53,0x60b104dd,0x60b200a6,0x60b4030a,0x60b8082f,0x60bb1592,0x60bc0379,0x60c50ffc,
	0x60c6027b,0x60ca0937,0x60cb13d5,0x60d107d1,0x60d5132c,0x60d813e7,0x60da0726,0x60dc1495,
	0x60dd01fd,0x60df1407,0x60e007b3,0x60e603c8,0x60e7099e,0x60e80193,0x60e90242,0x60eb00b4,
	0x60ec0fd9,0x60ed0192,0x60ee035c,0x60ef0650,0x60f00466,0x60f31521,0x60f419f0,0x60f60782,
	0x60f91084,0x60fa157f,0x61000fca,0x6101027e,0x61060f84,0x610817fc,0x610917c8,0x610d0d55,
	0x610e00ec,0x610f170e,0x61150480,0x611a17cc,0x611f058b,0x61201847,0x61230b15,0x612404fa,
	0x61260a93,0x61270a94,0x612b127a,0x613f1825,0x614802d7,0x614a0f99,0x614c077b,0x614e117b,
	0x6151115e,0x61550d9c,0x615d1313,0x61620ca5,0x616707b5,0x616809f1,0x61701428,0x61751772,
	0x61770a05,0x618b012b,0x618e188a,0x61940fc3,0x619d0445,0x61a70270,0x61a806a3,0x61a90f71,
	0x61ac0948,0x61b702a0,0x61be06b9,0x61c20406,0x61c81564,0x61ca0043,0x61cb0cce,0x61d10cf1,
	0x61d20ad5,0x61d40bbf,0x61e60e37,0x61f50d01,0x61ff1720,0x6206059e,0x620805b2,0x620a1473,
	0x620b0860,0x620c15ac,0x620d11fd,0x620e109a,0x620f14c3,0x62100233,0x62111444,0x62120905,
	0x62150fa4,0x621607cd,0x62170fa5,0x621818bd,0x621a0f34,0x621b0850,0x621f0816,0x622109fa,
	0x62220806,0x62240579,0x62250389,0x622a08fc,0x622c0888,0x622e0c37,0x623302cb,0x62340345,
	0x6237073e,0x623d0744,0x623e0b47,0x623f04c5,0x624012a7,0x6241010b,0x6243095b,0x62471126,
	0x62480747,0x624904d3,0x624b11d0,0x624c11d1,0x624d0183,0x624e1896,0x62510f17,0x62520048,
	0x62530330,0x62541097,0x625813a0,0x625b0a07,0x62630a4c,0x62660f7a,0x62671941,0x62690aa5,
	0x626a0cec,0x626b10f2,0x626c1672,0x626d0e1b,0x626e0079,0x626f0213,0x62701082,0x62730068,
	0x62760523,0x62790ea8,0x627c0477,0x627e18dd,0x627f0235,0x62800821,0x62840205,0x628909be,
	0x628a0055,0x629116f7,0x629211df,0x629319d5,0x62951379,0x62960417,0x62970a0a,0x629818e9,
	0x629a0544,0x629b0e77,0x629f138e,0x62a00a47,0x62a10c4d,0x62a20fb2,0x62a40740,0x62a5009b,
	0x62a80e96,0x62ab0eac,0x62ac12c1,0x62b1009c,0x62b503a5,0x62b90d70,0x62bb021a,0x62bc1612,
	0x62bd0276,0x62bf0d50,0x62c20526,0x62c419bd,0x62c5034a,0x62c601c7,0x62c70d8f,0x62c80deb,
	0x62c90aab,0x62ca0547,0x62cc007a,0x62cd0e55,0x62ce0bae,0x62d00644,0x62d20996,0x62d313b3,
	0x62d40050,0x62d613a1,0x62d70e1f,0x62d8097a,0x62d919f8,0x62da0e66,0x62db18db,0x62dc005f,
	0x62df0de3,0x62e20c06,0x62e30877,0x62e5176c,0x62e60ac3,0x62e70e10,0x62e8014d,0x62e91879,
	0x62ec0aa6,0x62ed11bd,0x62ee08f4,0x62ef1927,0x62f105f4,0x62f31053,0x62f41213,0x62f6184e,
	0x62f70a10,0x62fc0eec,0x62fd19d7,0x62fe119f,0x62ff0da0,0x63010256,0x63020640,0x63071955,
	0x63080fd8,0x63090026,0x630e0a5f,0x6311133e,0x631613b8,0x631a1968,0x631b0c42,0x631d143e,
	0x631e12b8,0x631f154e,0x63200dc4,0x63210364,0x632208cf,0x63231929,0x63240813,0x63250795,
	0x63280007,0x632a0e31,0x632b0320,0x632f1917,0x633212a0,0x63391707,0x633a135d,0x633d13d1,
	0x6342146a,0x634309de,0x63451371,0x63460aa2,0x634919fa,0x634b0c7b,0x634c004d,0x634d06b4,
	0x634e113e,0x634f0e00,0x635009ab,0x63550175,0x635e0ae6,0x635f1299,0x6361087c,0x6362076e,
	0x63630375,0x63670ea5,0x63690ba8,0x636d0064,0x636e099f,0x63710009,0x637602bc,0x637708f9,
	0x637a0da9,0x637b0df1,0x638014e6,0x638203b6,0x6387045a,0x638811da,0x638903d9,0x638a0f13,
	0x638c18cf,0x638e0815,0x638f1301,0x63900f72,0x63920e58,0x639616b5,0x639809c4,0x63a00c4a,
	0x63a212e4,0x63a30217,0x63a508e8,0x63a70a46,0x63a81391,0x63a91651,0x63aa0321,0x63ac097f,
	0x63ad133c,0x63ae0f90,0x63b0005e,0x63b30c26,0x63b40643,0x63b7196e,0x63b80354,0x63ba01d3,
	0x63bc0651,0x63be1823,0x63c417c9,0x63c60a87,0x63c910aa,0x63cd1a42,0x63ce15cf,0x63cf0d32,
	0x63d0131f,0x63d201b4,0x63d616c3,0x63de0023,0x63e0162a,0x63e11449,0x63e301cd,0x63e909ea,
	0x63ea0965,0x63ed08ec,0x63f21153,0x63f41814,0x63f616a8,0x63f81892,0x63fd0ad0,0x63ff0ff2,
	0x640001d4,0x640105bb,0x64020c10,0x640508d7,0x640b01c9,0x640c18bb,0x640f0162,0x6410029e,
	0x64130316,0x641410ed,0x641b086f,0x641c125e,0x641e05a8,0x64201229,0x642110ea,0x64260e35,
	0x642a12ed,0x642c006d,0x642d0326,0x64340f87,0x643a1552,0x643d01ba,0x643f05c7,0x6441048b,
	0x6444115f,0x644511eb,0x64460065,0x64471694,0x6448013b,0x644a12d0,0x6452014c,0x6454120e,
	0x645818a8,0x645e0c6b,0x64670305,0x64690d6c,0x646d194b,0x64780d64,0x64790d69,0x647a18ef,
	0x64820ba0,0x64841748,0x648509ba,0x64870ee7,0x64910230,0x649210d5,0x6495123a,0x649606b8,
	0x64991a5c,0x649e19e8,0x64a40218,0x64a90b8d,0x64ac0fcf,0x64ad0154,0x64ae0318,0x64b019de,
	0x64b50df3,0x64b71554,0x64b80c17,0x64ba02fd,0x64bc06ba,0x64c0058e,0x64c20b05,0x64c5112c,
	0x64cd019e,0x64ce0fff,0x64d00778,0x64d20fea,0x64d70ec6,0x64d8016a,0x64de126a,0x64e21a08,
	0x64e4158c,0x64e60180,0x65000e5f,0x650907c5,0x6512185e,0x6518107c,0x65251a52,0x652b09d2,
	0x652e0dc1,0x652f1931,0x65340f15,0x65350f16,0x653611cf,0x65381786,0x65390574,0x653b05e8,
	0x653e04cc,0x653f192e,0x6545062e,0x65481543,0x65490d14,0x654c039a,0x654f0d54,0x65510974,
	0x65550267,0x65560030,0x655908e0,0x655b0b72,0x655d00e9,0x655e01fe,0x6562058a,0x656310e6,
	0x65660448,0x656b08da,0x656c0953,0x65701205,0x65720fb9,0x65741928,0x6577051e,0x6587142c,
	0x658b18a7,0x658c0133,0x659004d7,0x6591006c,0x65930acb,0x65970416,0x65990b9f,0x659b072e,
	0x659c1550,0x659f1905,0x65a1144c,0x65a40911,0x65a50262,0x65a70548,0x65a918b7,0x65ab1a00,
	0x65ad0439,0x65af1234,0x65b01574,0x65b904bd,0x65bc17b1,0x65bd1193,0x65c10e73,0x65c318b1,
	0x65c40cba,0x65c50c73,0x65c60e8e,0x65cb15d7,0x65cc0938,0x65ce0de4,0x65cf1a47,0x65d20be9,
	0x65d616e9,0x65d70f54,0x65e01457,0x65e20827,0x65e51099,0x65e60357,0x65e7096d,0x65e8194f,
	0x65e9186c,0x65ec15fb,0x65ed15bc,0x65ee0569,0x65ef0aad,0x65f0058f,0x65f106b2,0x65f6119c,
	0x65f70a79,0x65fa13ec,0x6600183a,0x6602002c,0x66031884,0x66060a9b,0x660a06d0,0x660c01ec,
	0x660e0d58,0x660f07b8,0x661316fd,0x6614148a,0x66151571,0x661912d5,0x661d185d,0x661f157e,
	0x66201766,0x662502c0,0x66270ce6,0x66281a5e,0x662d18dc,0x662f11be,0x663117ec,0x66340cc3,
	0x66350de5,0x663601fc,0x663c199d,0x663e14f8,0x66410209,0x6643078f,0x664b092a,0x664c1138,
	0x664f165e,0x66521111,0x6653153f,0x665416b3,0x66551845,0x66560796,0x665706a9,0x665a13d2,
	0x665f118a,0x6661016f,0x6664147a,0x666607b0,0x66680225,0x666e0f26,0x666f0946,0x6670149b,
	0x66740ffd,0x6676093a,0x6677066f,0x667a1973,0x667e0b8c,0x66821860,0x668415d1,0x668714d6,
	0x668c0a89,0x669111f4,0x66960e2e,0x66970029,0x669d0d5e,0x66a70017,0x66a80832,0x66ae0d9d,
	0x66b400a0,0x66b914eb,0x66be1399,0x66d911fa,0x66db15f7,0x66dc16a1,0x66dd00a2,0x66e614b1,
	0x66e90dc0,0x66f01826,0x66f2102c,0x66f316af,0x66f405d9,0x66f706e0,0x66f901a0,0x66fc0ca2,
	0x66fe1888,0x66ff132d,0x67001a54,0x67081829,0x6709179a,0x670a10c4,0x670b0e9a,0x670d0527,
	0x6710103a,0x67141226,0x67151918,0x67170ae1,0x671b13ed,0x671d020b,0x671f0f36,0x67260cf8,
	0x67280d90,0x672a141c,0x672b0d71,0x672c00c1,0x672d1897,0x672f11fc,0x673119a5,0x67340f22,
	0x6735045e,0x673a07dd,0x673d15a4,0x674010fe,0x6742184f,0x6743104f,0x6746057d,0x674801b3,
	0x67491115,0x674c1475,0x674e0b2d,0x674f158d,0x67500184,0x67510311,0x67531144,0x675618d3,
	0x675c0430,0x675e0f61,0x675f11fe,0x6760059c,0x67611340,0x67650ab5,0x67681675,0x67690c8b,
	0x676a0d35,0x676d06be,0x676f00a5,0x677008f3,0x677205a7,0x67731699,0x67750294,0x67770e4e,
	0x677c19c7,0x677e124e,0x677f0072,0x67810800,0x67840604,0x67870eb5,0x678913e5,0x678b04c1,
	0x6790148b,0x6795190e,0x67970bb0,0x679810c9,0x679a0cd2,0x679c068e,0x679d1936,0x679e02e4,
	0x67a211e2,0x67a3186d,0x67a50b48,0x67a70878,0x67a80236,0x67aa0fa6,0x67ab0501,0x67ad152b,
	0x67af0a51,0x67b00efe,0x67b31940,0x67b5152d,0x67b6085d,0x67b70841,0x67b80602,0x67c10468,
	0x67c30bcb,0x67c40146,0x67cf0063,0x67d00d89,0x67d10582,0x67d20f30,0x67d31076,0x67d410a9,
	0x67d818f7,0x67d914d2,0x67da17a1,0x67dc0673,0x67dd13b4,0x67de1a65,0x67e00e12,0x67e203a6,
	0x67e501b7,0x67e90971,0x67ec087a,0x67ef0a19,0x67f00db0,0x67f119cb,0x67f30bef,0x67f401cb,
	0x67fd022e,0x67ff11bf,0x6800193a,0x680518a2,0x6807011d,0x680818be,0x68091966,0x680a0bfa,
	0x680b040d,0x680c0c1e,0x680e0b4d,0x680f0ac4,0x68111201,0x68131214,0x68160f32,0x68170b52,
	0x681d063b,0x68211544,0x682915b8,0x682a19ab,0x68320a11,0x68330af0,0x68371683,0x683806e2,
	0x683905d3,0x683c05c0,0x683d1854,0x683e0c43,0x684008f7,0x684106fa,0x68420676,0x68431307,
	0x68440659,0x68451403,0x68460a7c,0x68480027,0x6849001a,0x684a09b3,0x684c19fb,0x684e1969,
	0x68501368,0x685110e7,0x68530762,0x68540901,0x68550972,0x68601614,0x68611080,0x68621901,
	0x6863036b,0x68640f33,0x68650fc1,0x68660756,0x68670679,0x686808b0,0x686919e3,0x686b12a1,
	0x68740536,0x68761372,0x687709c5,0x68810b80,0x6883135e,0x68850cd6,0x6886007f,0x688f0631,
	0x68931a29,0x689705e2,0x68a2113f,0x68a60d04,0x68a7145c,0x68a80b18,0x68ad12a2,0x68af131a,
	0x68b0155d,0x68b311e6,0x68b504bb,0x68c00880,0x68c20bd1,0x68c90d25,0x68cb0f4f,0x68cd0682,
	0x68d20086,0x68d51a32,0x68d80807,0x68da0e9d,0x68e012eb,0x68e303b0,0x68ee10fc,0x68f002bd,
	0x68f10b12,0x68f50a1f,0x68f918e4,0x68fa064a,0x68fc04f2,0x6901068f,0x690516e8,0x690b0b81,
	0x690d1947,0x690e19ec,0x69100980,0x691208c2,0x691f0425,0x69200fa0,0x69240c5a,0x692d13b2,
	0x693016a4,0x6934043b,0x6939117c,0x693d02ac,0x693f02c1,0x69421894,0x69541548,0x6957089a,
	0x695a0298,0x695d0b7c,0x695e0b13,0x69600db9,0x69630cdb,0x696615e2,0x696b080a,0x696e0297,
	0x697102ee,0x697709f3,0x69781018,0x69791758,0x697c0c0b,0x69800ef2,0x6982057a,0x69840ad2,
	0x698617cd,0x6987022b,0x69880c70,0x6989098f,0x698d1561,0x69940add,0x699510a4,0x69980990,
	0x699b1908,0x699c0083,0x69a704de,0x69a818a6,0x69ab129c,0x69ad1562,0x69b10306,0x69b40beb,
	0x69b7106c,0x69bb12bb,0x69c105aa,0x69ca122b,0x69cc02be,0x69ce01bc,0x69d0075a,0x69d405a2,
	0x69db09fb,0x69df0136,0x69e019b1,0x69ed0f64,0x69f20735,0x69fd01a3,0x69ff0922,0x6a0a04ad,
	0x6a170289,0x6a1812f0,0x6a1f18ca,0x6a210d6a,0x6a2814ab,0x6a2a06fc,0x6a2f0fb0,0x6a31174b,
	0x6a350fc5,0x6a3d1a5a,0x6a3e1832,0x6a44058d,0x6a470fbb,0x6a5013ae,0x6a580989,0x6a590241,
	0x6a5b09cc,0x6a611528,0x6a6519b3,0x6a710291,0x6a790c28,0x6a7c181b,0x6a8012dc,0x6a8414b9,
	0x6a8e0feb,0x6a901649,0x6a910b01,0x6a97016b,0x6aa01000,0x6aa90bc0,0x6aab01bf,0x6aac0cf9,
	0x6b200f9a,0x6b2102de,0x6b22075d,0x6b231572,0x6b2417b7,0x6b270e41,0x6b3217f3,0x6b371496,
	0x6b390f3b,0x6b3a0f37,0x6b3e0a6d,0x6b43110d,0x6b461575,0x6b471549,0x6b490fa1,0x6b4c05bc,
	0x6b591162,0x6b62194e,0x6b63192a,0x6b6402dd,0x6b650178,0x6b661468,0x6b670f45,0x6b6a13c2,
	0x6b790335,0x6b7b123c,0x6b7c0864,0x6b810d72,0x6b8202f3,0x6b83166e,0x6b841339,0x6b86033f,
	0x6b871132,0x6b89160b,0x6b8a11e5,0x6b8b0190,0x6b8d0ee3,0x6b921840,0x6b930b7a,0x6b961948,
	0x6b9a034f,0x6b9b0808,0x6ba1013c,0x6baa1719,0x6bb311de,0x6bb40e42,0x6bb50438,0x6bb71728,
	0x6bbf03cb,0x6bc107a2,0x6bc2061c,0x6bc51715,0x6bcb1458,0x6bcd0d8b,0x6bcf0ce1,0x6bd20422,
	0x6bd31800,0x6bd400d2,0x6bd500dd,0x6bd600e2,0x6bd70eb6,0x6bd900e5,0x6bdb0cb6,0x6be118b0,
	0x6bea0d8a,0x6beb06c7,0x6bef12e1,0x6bf3030d,0x6bf510e2,0x6bf911ec,0x6bfd089b,0x6c0501ff,
	0x6c060f29,0x6c070c2a,0x6c0d1041,0x6c0f11ae,0x6c100394,0x6c110d47,0x6c130cb1,0x6c140f65,
	0x6c150ee6,0x6c160dae,0x6c180371,0x6c1914e2,0x6c1a02a6,0x6c1b04ee,0x6c1f052c,0x6c210403,
	0x6c220ff4,0x6c241729,0x6c26069f,0x6c27167f,0x6c28001b,0x6c291629,0x6c2a0a33,0x6c2e0360,
	0x6c2f0c81,0x6c300ffe,0x6c321835,0x6c34121c,0x6c35121b,0x6c381779,0x6c3d139e,0x6c401351,
	0x6c411933,0x6c42101d,0x6c4602fc,0x6c4707a5,0x6c4906b0,0x6c4a01c2,0x6c501486,0x6c540f67,
	0x6c551124,0x6c5706b1,0x6c5b1607,0x6c5c1240,0x6c5d10ba,0x6c5e05f3,0x6c5f08a4,0x6c600252,
	0x6c611450,0x6c6412e6,0x6c680d18,0x6c69061f,0x6c6a13e0,0x6c7012c8,0x6c7207fd,0x6c740113,
	0x6c761437,0x6c791597,0x6c7d0f6a,0x6c7e04f1,0x6c810ff1,0x6c8216ca,0x6c831445,0x6c85180e,
	0x6c8606c2,0x6c881170,0x6c890221,0x6c8c044f,0x6c8f0f2e,0x6c900d93,0x6c9312b7,0x6c940d27,
	0x6c9910ff,0x6c9b0e8b,0x6c9f05fa,0x6ca10cd1,0x6ca30500,0x6ca40e4a,0x6ca50b44,0x6ca60c51,
	0x6ca7019a,0x6ca91400,0x6caa0741,0x6cab0d73,0x6cad11ff,0x6cae098b,0x6cb113a8,0x6cb213a3,
	0x6cb306df,0x6cb804e3,0x6cb9178f,0x6cbb1961,0x6cbc18de,0x6cbd0611,0x6cbe18af,0x6cbf1641,
	0x6cc41558,0x6cc5101f,0x6cc91051,0x6cca0159,0x6ccc0d1a,0x6cd00afa,0x6cd30708,0x6cd40580,
	0x6cd504a1,0x6cd60cc2,0x6cd71246,0x6cdb04b6,0x6cde0e17,0x6ce00bc9,0x6ce10e81,0x6ce2014e,
	0x6ce30f6b,0x6ce50ddb,0x6ce819c8,0x6cea0b0d,0x6ceb15dc,0x6cee0e68,0x6cef0d51,0x6cf012cc,
	0x6cf1166d,0x6cf3177c,0x6cf500ca,0x6cf615eb,0x6cf70bf8,0x6cf80c1c,0x6cfa0c64,0x6cfb1559,
	0x6cfc0f04,0x6cfd187a,0x6cfe0933,0x6d0108f5,0x6d04079d,0x6d071724,0x6d0b167a,0x6d0c0ba5,
	0x6d0e0828,0x6d1210d6,0x6d1714ba,0x6d1919a9,0x6d1a08b5,0x6d1b0c65,0x6d1e040e,0x6d250914,
	0x6d271412,0x6d2a0709,0x6d2b15c0,0x6d2e1305,0x6d310493,0x6d321993,0x6d3310be,0x6d3515ff,
	0x6d390761,0x6d3b07c6,0x6d3c13b9,0x6d3d0f75,0x6d3e0e5b,0x6d410be5,0x6d430842,0x6d450f94,
	0x6d4608a8,0x6d4708be,0x6d4818ff,0x6d4a1a01,0x6d4b01ab,0x6d4d07a8,0x6d4e0829,0x6d4f0be4,
	0x6d5107bc,0x6d52073a,0x6d530e23,0x6d541600,0x6d5918f8,0x6d5a09df,0x6d5c0080,0x6d5e1a02,
	0x6d601492,0x6d63076f,0x6d660f25,0x6d6906d1,0x6d6a0ae4,0x6d6e0531,0x6d6f145d,0x6d7417ef,
	0x6d770699,0x6d78092b,0x6d7c0ce3,0x6d821381,0x6d850e02,0x6d881530,0x6d89115c,0x6d8c177f,
	0x6d8e14f0,0x6d911272,0x6d9309ac,0x6d9401ae,0x6d95132a,0x6d9b12ff,0x6d9d0af3,0x6d9e0ab7,
	0x6d9f0b68,0x6da01404,0x6da11440,0x6da30770,0x6da4039b,0x6da610cf,0x6da70896,0x6da818ce,
	0x6da910f7,0x6daa0537,0x6dab064c,0x6dae1215,0x6daf161d,0x6db216b6,0x6db506aa,0x6db806e5,
	0x6dbf19fc,0x6dc003c9,0x6dc41a13,0x6dc51497,0x6dc6153d,0x6dc70f4b,0x6dcb0bb2,0x6dcc12f8,
	0x6dd111e7,0x6dd60dce,0x6dd8130a,0x6dd902eb,0x6ddd04d9,0x6dde1251,0x6de00ecc,0x6de1035d,
	0x6de417af,0x6de60591,0x6deb1731,0x6dec030b,0x6dee0759,0x6df1116b,0x6df302c6,0x6df707c0,
	0x6df91630,0x6dfb1331,0x6dfc0d38,0x6e050ff9,0x6e0a180a,0x6e0c0c30,0x6e0d1a2e,0x6e0e0424,
	0x6e100898,0x6e111184,0x6e1417c3,0x6e161175,0x6e17117a,0x6e1a19be,0x6e1d17b2,0x6e20103c,
	0x6e210433,0x6e231893,0x6e240160,0x6e25144a,0x6e29142a,0x6e2b155f,0x6e2d1425,0x6e2f059b,
	0x6e3215e1,0x6e340a2d,0x6e381795,0x6e3a0d39,0x6e430e5c,0x6e440cd9,0x6e4d138c,0x6e4e0d2b,
	0x6e530e94,0x6e54086c,0x6e56072f,0x6e581512,0x6e5b18c1,0x6e5f0783,0x6e6b08d8,0x6e6e1634,
	0x6e7e13c6,0x6e7f1195,0x6e830a95,0x6e85089c,0x6e8615c6,0x6e890578,0x6e8f12ee,0x6e901818,
	0x6e980a36,0x6e9c0be1,0x6e9f0d5d,0x6ea2170f,0x6ea50f27,0x6ea70b16,0x6eaa14a1,0x6eaf127b,
	0x6eb10fe8,0x6eb2125f,0x6eb415aa,0x6eb610a2,0x6eb707c1,0x6eba0de8,0x6ebb12b3,0x6ebd10bf,
	0x6ec1028d,0x6ec20e6f,0x6ec703b7,0x6ecb1a18,0x6ecf054e,0x6ed10751,0x6ed31a2b,0x6ed41302,
	0x6ed51317,0x6ed700ee,0x6eda067f,0x6ede1974,0x6edf1666,0x6ee01160,0x6ee10ca0,0x6ee21759,
	0x6ee40c7c,0x6ee50ad7,0x6ee60c46,0x6ee80134,0x6ee912d1,0x6ef40393,0x6ef90727,0x6f020edc,
	0x6f060f39,0x6f090c36,0x6f0f0c13,0x6f130b1f,0x6f141656,0x6f1501a2,0x6f200d79,0x6f240ad3,
	0x6f2915d8,0x6f2a16c4,0x6f2b0ca6,0x6f2d0cb3,0x6f2f0c6c,0x6f311208,0x6f3318c8,0x6f360776,
	0x6f3e1684,0x6f46175b,0x6f471536,0x6f4b0b7d,0x6f4d140a,0x6f580e5e,0x6f5c0f92,0x6f5e0c39,
	0x6f620786,0x6f660b8e,0x6f6d12db,0x6f6e020d,0x6f72114e,0x6f7419b2,0x6f78111e,0x6f7a01dd,
	0x6f7c136e,0x6f840240,0x6f880219,0x6f89058c,0x6f8c123b,0x6f8d1209,0x6f8e0ea1,0x6f9c0ac9,
	0x6fa1186f,0x6fa70b35,0x6fb30042,0x6fb601e0,0x6fb912d3,0x6fc007f5,0x6fc20b6e,0x6fc91287,
	0x6fd10abe,0x6fd20138,0x6fde00fc,0x6fe006cc,0x6fe110b5,0x6fee0f20,0x6fef1a09,0x70110f2c,
	0x701a06bc,0x701b175f,0x70231569,0x703504fd,0x70391834,0x704c0653,0x704f06d5,0x705e005d,
	0x706b07c8,0x706c07c7,0x706d0d43,0x706f0383,0x70700792,0x70750bc7,0x70761871,0x70780969,
	0x707c19fe,0x707e1851,0x707f0195,0x70801676,0x70850674,0x70890c1d,0x708a02b9,0x708e1642,
	0x7092020f,0x70941062,0x70950a0c,0x70960450,0x70991962,0x709c1410,0x709d0fb5,0x70ab15dd,
	0x70ac0999,0x70ad12e3,0x70ae0e7d,0x70af095d,0x70b112c3,0x70b30147,0x70b719cc,0x70b818a3,
	0x70b903bc,0x70bb11a0,0x70bc0b78,0x70bd0265,0x70c00723,0x70c11225,0x70c20ad6,0x70c31353,
	0x70c80ba7,0x70ca167b,0x70d80702,0x70d90af4,0x70db19b6,0x70df162d,0x70e40a12,0x70e604ac,
	0x70e71140,0x70e816b4,0x70e907ad,0x70eb12fd,0x70ec092c,0x70ed1085,0x70ef1498,0x70f713cf,
	0x70f90e98,0x70fd0506,0x71091631,0x710a06b5,0x7110147b,0x711306ab,0x71150772,0x71160cf0,
	0x7118037a,0x711900b5,0x711a04f3,0x712608c3,0x712f19f7,0x71301663,0x71311664,0x71361071,
	0x7145043c,0x714a15d2,0x714c0785,0x714e0870,0x715c17fd,0x715e1108,0x71640cdc,0x716615c8,
	0x716718e5,0x716813f6,0x716e19bf,0x71720090,0x71730732,0x71780106,0x717a1395,0x717d111d,
	0x718414a5,0x718a159a,0x718f15f4,0x719410a5,0x71980be2,0x719914a6,0x719f11f3,0x71a01716,
	0x71a8184a,0x71ac002f,0x71b30ca9,0x71b51136,0x71b914ac,0x71c31073,0x71ce0b98,0x71d404af,
	0x71d5166a,0x71e01803,0x71e51876,0x71e71292,0x71ee1568,0x71f914ff,0x720600a1,0x721d09d1,
	0x72280302,0x722a19d6,0x722c0e4f,0x72301810,0x72310011,0x723509cd,0x72360552,0x723716a6,
	0x72380059,0x723903dc,0x723b168b,0x723d1219,0x723f0e60,0x72470ed9,0x72480073,0x724c0e59,
	0x724d0426,0x725203e6,0x7256179f,0x72591616,0x725b0e19,0x725d0ef3,0x725f0d84,0x72610d8d,
	0x72620ae8,0x72660cb8,0x72670d95,0x72691477,0x726e0892,0x726f0623,0x72721181,0x72750f80,
	0x72791311,0x727a1493,0x727e146b,0x727f0632,0x7280149c,0x72810b1c,0x728407eb,0x728a0427,
	0x728b09a1,0x728d086d,0x728f0ed2,0x72920a14,0x729f08b8,0x72ac105d,0x72ad105c,0x72af04b5,
	0x72b0101c,0x72b40024,0x72b619e7,0x72b7065c,0x72b80c87,0x72b9178d,0x72c1183e,0x72c20a72,
	0x72c30e1c,0x72c40397,0x72c800ac,0x72cd0e7c,0x72ce14d0,0x72d0072b,0x72d204e4,0x72d70600,
	0x72d9097b,0x72de0e11,0x72e006f5,0x72e108d0,0x72e8109c,0x72e911d7,0x72ec0429,0x72ed14d3,
	0x72ee1194,0x72ef0a68,0x72f01920,0x72f117ed,0x72f21296,0x72f317c0,0x72f400e6,0x72f709b4,
	0x72f80b19,0x72fa172f,0x72fb1280,0x72fc0ada,0x73010b53,0x730314fa,0x730a0dde,0x730e0ba9,
	0x73130689,0x73150d0a,0x731601ee,0x731716dc,0x731b0cfd,0x731c0182,0x731d02f5,0x731e1150,
	0x73210c56,0x73220730,0x73251416,0x73291580,0x732a19ae,0x732b0cb5,0x732c1426,0x732e150a,
	0x73310dc7,0x73340712,0x73371797,0x73380cda,0x733901bb,0x733e0752,0x733f1819,0x734d0957,
	0x735018c9,0x73520033,0x735709ca,0x73600b96,0x736c1565,0x736d12b5,0x736f15f5,0x737e075e,
	0x738415d4,0x73870c7f,0x738917e4,0x738b13e2,0x738e03ee,0x739107de,0x7396096a,0x739b0c88,
	0x739f0d49,0x73a2013a,0x73a913cd,0x73ab0cd3,0x73ae1411,0x73af075f,0x73b01503,0x73b20bcc,
	0x73b30340,0x73b703c6,0x73ba14bb,0x73bb014f,0x73c00f0d,0x73c20a1a,0x73c80843,0x73c90d4b,
	0x73ca111a,0x73cd1900,0x73cf09bf,0x73d004a3,0x73d10bfb,0x73d905f5,0x73de0c69,0x73e019ac,
	0x73e50495,0x73e71690,0x73e906fb,0x73ed0069,0x73f20797,0x74031023,0x74050adc,0x74060b32,
	0x74090be7,0x740a161a,0x740f0b73,0x741012aa,0x741a0981,0x741b021c,0x74221a06,0x7425073c,
	0x74260f50,0x74280a9c,0x742a0f51,0x742c13d9,0x742e02ec,0x74301654,0x74330bb3,0x74340fe4,
	0x74350ebc,0x74360e51,0x743c1012,0x74410ccb,0x745514d7,0x74571824,0x74590dcc,0x745a0733,
	0x745b1746,0x745c17ce,0x745e10cc,0x745f10fa,0x746d12ef,0x74700666,0x74761696,0x74770018,
	0x747e0923,0x74800307,0x748102e7,0x74830b23,0x748715d9,0x748b18cb,0x748e174c,0x74900c3a,
	0x749c0787,0x749e0f1f,0x74a700ff,0x74a80197,0x74a9103f,0x74ba1438,0x74d21863,0x74dc0637,
	0x74de03e0,0x74e00748,0x74e20ee0,0x74e3007c,0x74e41078,0x74e613bd,0x74ee143c,0x74ef0e43,
	0x74f40bcd,0x74f60eff,0x74f702d6,0x74ff017d,0x75041906,0x750d0cf6,0x750f00cc,0x7511188e,
	0x75130ecf,0x7518057c,0x75190339,0x751a1178,0x751c1335,0x751f117f,0x75251183,0x75281783,
	0x7529120f,0x752b0545,0x752c177a,0x752d00c9,0x752f0e15,0x75301332,0x7531178c,0x75320855,
	0x75331163,0x753503bf,0x75370db5,0x753803c1,0x753a03f4,0x753b0754,0x753e1852,0x754000e0,
	0x75450201,0x754804ba,0x754b1334,0x754c0908,0x754e105e,0x754f141f,0x75540e6b,0x75590be6,
	0x755a00c3,0x755b1910,0x755c02a3,0x75650c4b,0x75660f4c,0x756a04a5,0x75721152,0x7574027d,
	0x757807ee,0x757913db,0x757f07f1,0x7583138f,0x758608ad,0x758b0ec8,0x758f11e9,0x759116d9,
	0x75920dcf,0x759403ef,0x759608e6,0x75970b90,0x759905b5,0x759a0970,0x759d1125,0x759f0e2f,
	0x75a00b49,0x75a11678,0x75a31790,0x75a4004c,0x75a50909,0x75ab1703,0x75ac0b4e,0x75ae02b1,
	0x75af0503,0x75b019ce,0x75b10e82,0x75b20eb7,0x75b30584,0x75b40a1d,0x75b502d1,0x75b80353,
	0x75b91911,0x75bc1314,0x75bd097e,0x75be0805,0x75c20845,0x75c315d5,0x75c418a4,0x75c5014b,
	0x75c7192f,0x75c8176d,0x75c9094f,0x75ca1055,0x75cd16d5,0x75d21680,0x75d4196f,0x75d506f3,
	0x75d61621,0x75d8041d,0x75db1375,0x75de0ec5,0x75e20b5d,0x75e31975,0x75e4031b,0x75e6147d,
	0x75e71105,0x75e80aea,0x75ea0774,0x75eb14f4,0x75f012d8,0x75f104e7,0x75f4024e,0x75f900ef,
	0x75fc0634,0x75ff1417,0x760017b0,0x7601030e,0x760319b9,0x76050356,0x760a0713,0x760c0ab1,
	0x761017e0,0x76150859,0x76171713,0x76180c14,0x761910f5,0x761b026a,0x761f142b,0x7620080d,
	0x7622006e,0x76240bec,0x762501cf,0x762611dc,0x7629032d,0x762a012d,0x762b12d2,0x762d0122,
	0x76300c62,0x76330277,0x763418d9,0x763518ae,0x76381064,0x763c0d7d,0x763e173e,0x763f1765,
	0x7640078a,0x76430c01,0x764c000b,0x764d006f,0x7654171e,0x76560ec7,0x765c03cd,0x765e0abf,
	0x766315db,0x766b03ba,0x766f1042,0x7678066d,0x767b0384,0x767d0060,0x767e0061,0x76821872,
	0x76840382,0x768608e7,0x7687077d,0x76880663,0x768b059f,0x768e08d3,0x7691000a,0x769306d3,
	0x769613da,0x769914a2,0x76a40f08,0x76ae0eb3,0x76b119a0,0x76b209d7,0x76b40312,0x76bf0d4e,
	0x76c217b8,0x76c51981,0x76c60e93,0x76c81752,0x76ca1708,0x76cd06e3,0x76ce002d,0x76cf18b9,
	0x76d01644,0x76d10869,0x76d206e6,0x76d40a81,0x76d60577,0x76d7037b,0x76d80e61,0x76db118b,
	0x76df0cf5,0x76e50652,0x76ee0d92,0x76ef03f0,0x76f115ad,0x76f20cae,0x76f41943,0x76f8150f,
	0x76f9044c,0x76fc0e6a,0x76fe0451,0x77011186,0x77040d2e,0x77070d36,0x7708034b,0x77090cd4,
	0x770b0a01,0x770d0a49,0x771916d3,0x771a1187,0x771f1902,0x77200d23,0x77221808,0x77261a2f,
	0x7728189b,0x772915df,0x772d067a,0x772f0d06,0x7735024a,0x77360a7d,0x773709b7,0x77380d86,
	0x773a1348,0x773c1652,0x774018fb,0x77411922,0x774312a3,0x774703b1,0x77500abc,0x77510882,
	0x775a161e,0x775b093c,0x7761121e,0x77621286,0x77630420,0x77650101,0x77660d9b,0x77680de9,
	0x776b08fb,0x776c0189,0x7779042d,0x777d0a8b,0x777e05a3,0x777f10cd,0x77800ccc,0x77840d33,
	0x77850285,0x778c0a24,0x778d1267,0x778e14cd,0x77910d5f,0x77920c9c,0x779f0ee4,0x77a00231,
	0x77a20cf7,0x77a50ee8,0x77a70fc6,0x77a919c2,0x77aa038d,0x77ac1222,0x77b00a03,0x77b3136f,
	0x77b50bb9,0x77bb18b5,0x77bd062c,0x77bf1038,0x77cd09d0,0x77d702a2,0x77db0cb7,0x77dc0915,
	0x77e211a6,0x77e316e3,0x77e51937,0x77e71172,0x77e9098d,0x77eb08d4,0x77ec031c,0x77ed0437,
	0x77ee000d,0x77f3119b,0x77f607e1,0x77f80587,0x77fd148c,0x77fe04aa,0x77ff0a7a,0x78000369,
	0x78010c89,0x78021102,0x7809074c,0x780c0f6d,0x780d09fe,0x78111628,0x78120ead,0x78141643,
	0x781619d9,0x78170212,0x78180452,0x781a165b,0x781c0504,0x781d04a2,0x781f189c,0x782313aa,
	0x782503a7,0x782618ac,0x78271903,0x78290532,0x782c0b38,0x782d0103,0x78300e97,0x78340f0e,
	0x7837116a,0x78381850,0x78390012,0x783a0b54,0x783b0bfd,0x783c1369,0x783e0b55,0x78400295,
	0x78450665,0x78470dc5,0x784c05d0,0x784e1589,0x78500411,0x78521499,0x78551228,0x785614d4,
	0x78570fb6,0x785d1534,0x786a144b,0x786b0be8,0x786c1767,0x786d0cb0,0x786e1068,0x78770883,
	0x787c0e9e,0x788703fb,0x788903d3,0x788c0c34,0x788d0016,0x788e1290,0x789100a7,0x78930444,
	0x789713dc,0x789803bd,0x789a00b7,0x789b0f6f,0x789c0227,0x789f03e7,0x78a119a4,0x78a308fd,
	0x78a5010e,0x78a700f4,0x78b00ea6,0x78b10889,0x78b203b4,0x78b312e5,0x78b401be,0x78b915e3,
	0x78be0df4,0x78c102d9,0x78c50089,0x78c910eb,0x78ca0b09,0x78cb0317,0x78d00e62,0x78d418f0,
	0x78d50a25,0x78d90680,0x78e80d6d,0x78ec1009,0x78f2103e,0x78f4038e,0x78f70bba,0x78fa078b,
	0x790108c9,0x7905044a,0x791308ac,0x791e0cfa,0x79240181,0x79340167,0x793a11b3,0x793b11af,
	0x793c0b2c,0x793e115a,0x79401245,0x79410f3e,0x794614e3,0x79480f46,0x79491953,0x7953052d,
	0x79561a4d,0x7957193b,0x795a1a66,0x795b1031,0x795c0745,0x795d19cd,0x795e116e,0x795f128d,
	0x796002d3,0x79620d08,0x7965151b,0x7967133f,0x79680ee5,0x796d0830,0x796f1904,0x79770376,
	0x797807d0,0x797a0f52,0x79800149,0x7981091a,0x79840c33,0x798501d8,0x798a14ca,0x798f053d,
	0x799a1a07,0x79a714c2,0x79b31077,0x79b917db,0x79ba17bc,0x79bb0b1a,0x79bd0fe5,0x79be06da,
	0x79c015a5,0x79c11230,0x79c3137d,0x79c60588,0x79c90145,0x79cb1016,0x79cd1988,0x79d10a1b,
	0x79d20d37,0x79d500d6,0x79d80d1c,0x79df1a43,0x79e30d76,0x79e40245,0x79e60fe3,0x79e7166f,
	0x79e9196a,0x79eb11ef,0x79ed1a26,0x79ef07e8,0x79f0022d,0x79f808e9,0x79fb16d6,0x79fd07b1,
	0x7a00149d,0x7a020ade,0x7a03051b,0x7a060c74,0x7a0b023c,0x7a0d1141,0x7a0e121d,0x7a14108c,
	0x7a170067,0x7a1a1978,0x7a1e0a21,0x7a20027f,0x7a23126d,0x7a331435,0x7a370836,0x7a391913,
	0x7a3b037d,0x7a3c085f,0x7a3d07f2,0x7a3f05ab,0x7a460d9e,0x7a5110fb,0x7a571293,0x7a701079,
	0x7a7415e9,0x7a760960,0x7a77100e,0x7a78148d,0x7a79100f,0x7a7a0a40,0x7a7f02a7,0x7a8019f4,
	0x7a81137e,0x7a830fd7,0x7a8418aa,0x7a86010c,0x7a88169b,0x7a8d0fce,0x7a911691,0x7a921970,
	0x7a951347,0x7a9608e1,0x7a9702b2,0x7a98095e,0x7a9c0300,0x7a9d1442,0x7a9f0a54,0x7aa00a22,
	0x7aa50a82,0x7aa6041e,0x7aa8173f,0x7aac17d1,0x7aad09a4,0x7ab317e1,0x7abf0c02,0x7acb0b3d,
	0x7ad61202,0x7ad918bf,0x7ade0950,0x7adf0952,0x7ae018c4,0x7ae309e1,0x7ae5136b,0x7ae61257,
	0x7aed08fe,0x7aef0436,0x7af919b4,0x7afa19b5,0x7afd17bd,0x7aff0583,0x7b03042a,0x7b0407e9,
	0x7b06004e,0x7b080804,0x7b0a18e3,0x7b0b129a,0x7b0f0746,0x7b111545,0x7b1400d8,0x7b15087d,
	0x7b191182,0x7b1b039d,0x7b1e024b,0x7b200b58,0x7b241342,0x7b251249,0x7b260538,0x7b2800c5,
	0x7b2a0331,0x7b2b1a28,0x7b2c03ae,0x7b2e187f,0x7b310603,0x7b330846,0x7b380f0b,0x7b3a086a,
	0x7b3c0bfe,0x7b3e0104,0x7b4514fc,0x7b471011,0x7b490388,0x7b4b0917,0x7b4c1057,0x7b4f04a0,
	0x7b500a71,0x7b5119d1,0x7b521373,0x7b54032c,0x7b5601ac,0x7b580a4e,0x7b5a00ed,0x7b5b1110,
	0x7b5d1924,0x7b6009d9,0x7b620e52,0x7b6e11ca,0x7b711540,0x7b721142,0x7b751646,0x7b770a6a,
	0x7b790280,0x7b7b059d,0x7b7e0f85,0x7b800886,0x7b8500f5,0x7b8d061a,0x7b901008,0x7b940163,
	0x7b9507f0,0x7b971283,0x7b9c0a43,0x7b9d0f91,0x7ba1064e,0x7ba213dd,0x7ba61881,0x7ba70fda,
	0x7ba813b6,0x7ba90c5c,0x7baa0350,0x7bab1537,0x7bac10d3,0x7bad08a2,0x7bb11515,0x7bb41909,
	0x7bb819d3,0x7bc10788,0x7bc619df,0x7bc70ed3,0x7bcc0714,0x7bd10a98,0x7bd30c11,0x7bd905a5,
	0x7bda04e0,0x7bdd05fd,0x7be10301,0x7be50b61,0x7be600f9,0x7bea0259,0x7bee0acc,0x7bf10b26,
	0x7bf70ea2,0x7bfc0415,0x7bfe0d45,0x7c0702f9,0x7c0b0670,0x7c0c127f,0x7c0f0c3b,0x7c16043e,
	0x7c1f03ce,0x7c260386,0x7c27078c,0x7c2a185b,0x7c380169,0x7c3f017e,0x7c4019a3,0x7c410ac0,
	0x7c4d080f,0x7c730d12,0x7c740398,0x7c7b0b0e,0x7c7c14e4,0x7c7d1a23,0x7c8904f5,0x7c91004f,
	0x7c920b59,0x7c950f0f,0x7c9702f1,0x7c9818b2,0x7c9c1349,0x7c9d0b5a,0x7c9e149e,0x7c9f1276,
	0x7ca21a19,0x7ca41830,0x7ca51994,0x7caa04fb,0x7cae0b82,0x7cb10b83,0x7cb20196,0x7cb3093d,
	0x7cb9030f,0x7cbc0bb4,0x7cbd1a39,0x7cbe093f,0x7cc110e4,0x7cc510ab,0x7cc70715,0x7cc815b9,
	0x7cca0728,0x7ccc185a,0x7ccd02dc,0x7cd505a6,0x7cd612f2,0x7cd7102a,0x7cd9019f,0x7cdc0d0d,
	0x7cdf186a,0x7ce00a06,0x7ce808b9,0x7cef0e38,0x7cf80d17,0x7cfb14c4,0x7d0a1434,0x7d201273,
	0x7d2212a9,0x7d27091d,0x7d2b1a2a,0x7d2f0b04,0x7d6e15c7,0x7d771949,0x7da60f55,0x7dae1006,
	0x7e3b0d0e,0x7e4104b0,0x7e471697,0x7e821a51,0x7e9b037e,0x7e9f122d,0x7ea0095f,0x7ea117ad,
	0x7ea20705,0x7ea31999,0x7ea414e1,0x7ea505b4,0x7ea61827,0x7ea707fe,0x7ea813ca,0x7ea90a77,
	0x7eaa081e,0x7eab1091,0x7eac140d,0x7ead1838,0x7eaf02c3,0x7eb00ea9,0x7eb11100,0x7eb20595,
	0x7eb30da4,0x7eb51a38,0x7eb60c52,0x7eb704ec,0x7eb81951,0x7eb9142d,0x7eba04ca,0x7ebd0e1d,
	0x7ebe11e0,0x7ebf1504,0x7ec00590,0x7ec1155a,0x7ec20528,0x7ec30b77,0x7ec41a4b,0x7ec51167,
	0x7ec614c6,0x7ec71938,0x7ec81980,0x7ec9199c,0x7eca007b,0x7ecb0529,0x7ecc029d,0x7ecd114c,
	0x7ece16fe,0x7ecf0934,0x7ed0033a,0x7ed10082,0x7ed2109d,0x7ed308f6,0x7ed40a58,0x7ed51083,
	0x7ed706bf,0x7ed807a9,0x7ed905d2,0x7eda15de,0x7edb08b6,0x7edc0c66,0x7edd09c0,0x7ede08d1,
	0x7edf1370,0x7ee005e0,0x7ee11531,0x7ee209b5,0x7ee315a7,0x7ee51288,0x7ee61300,0x7ee7082a,
	0x7ee8131d,0x7ee9081a,0x7eea15c2,0x7eeb0bd2,0x7eed15c3,0x7eee0f63,0x7eef04d1,0x7ef002ce,
	0x7ef1113c,0x7ef2067d,0x7ef31185,0x7ef41408,0x7ef50d24,0x7ef611db,0x7ef700c7,0x7ef8027c,
	0x7efa0bf0,0x7efb105f,0x7efc1a31,0x7efd18c0,0x7efe13d6,0x7eff0c80,0x7f0019ef,0x7f011a14,
	0x7f020a35,0x7f031513,0x7f04086e,0x7f050d2c,0x7f060ad1,0x7f071320,0x7f080d3a,0x7f0907ec,
	0x7f0b07b4,0x7f0c1235,0x7f0d0461,0x7f0e043a,0x7f0f0117,0x7f1105fc,0x7f1219f1,0x7f130769,
	0x7f1403b2,0x7f150c77,0x7f160105,0x7f170d4c,0x7f181815,0x7f19092e,0x7f1a0561,0x7f1b10c0,
	0x7f1c1912,0x7f1d050d,0x7f1f05a9,0x7f2001da,0x7f210b20,0x7f221710,0x7f230871,0x7f240135,
	0x7f250ee2,0x7f260ca7,0x7f270b00,0x7f281749,0x7f2912a6,0x7f2a0d3f,0x7f2b10ef,0x7f2c1555,
	0x7f2d0b97,0x7f2e112a,0x7f2f188b,0x7f3008ab,0x7f310f98,0x7f320fbc,0x7f330766,0x7f3408dc,
	0x7f351a50,0x7f360514,0x7f380597,0x7f3a1063,0x7f42174a,0x7f44100a,0x7f4514de,0x7f500655,
	0x7f5113e3,0x7f5413e6,0x7f5506ae,0x7f570c55,0x7f58052e,0x7f5a049e,0x7f5f0625,0x7f610599,
	0x7f62005a,0x7f681655,0x7f6918e6,0x7f6a1a55,0x7f6e1979,0x7f710ad4,0x7f7211f6,0x7f740ebe,
	0x7f790b27,0x7f7e188c,0x7f8107f6,0x7f8a1673,0x7f8c0fa3,0x7f8e0ce2,0x7f9405a0,0x7f9a0bd3,
	0x7f9d0391,0x7f9e159f,0x7f9f0fb3,0x7fa11509,0x7fa4106f,0x7fa712a4,0x7faf0900,0x7fb012e7,
	0x7fb214ad,0x7fb80b03,0x7fb905dd,0x7fbc01ea,0x7fbd17d8,0x7fbf1704,0x7fc11439,0x7fc50266,
	0x7fca170b,0x7fcc170c,0x7fce0bd4,0x7fd4151c,0x7fd5149f,0x7fd80fc7,0x7fdf03a0,0x7fe00310,
	0x7fe104df,0x7fe519d4,0x7fe6088a,0x7fe90ed4,0x7fee06eb,0x7ff006bb,0x7ff10035,0x7ff3171b,
	0x7ffb04a7,0x7ffc171c,0x800016a2,0x80010aed,0x80030a0f,0x80040cc8,0x800518f2,0x80060f47,
	0x800b03e4,0x800c048d,0x800d120c,0x80100db1,0x80120b06,0x80141a27,0x801505db,0x80160210,
	0x801706d2,0x8018183c,0x80190e50,0x801c124a,0x802007c2,0x80220af5,0x802512fa,0x80260e47,
	0x80270c0c,0x80280e26,0x802908b2,0x802a0e75,0x80310d81,0x80330491,0x803503f2,0x803616a7,
	0x80370325,0x80381256,0x803b025d,0x803d034c,0x803f05e1,0x80420e03,0x8043034e,0x80460bd5,
	0x804a0b91,0x804b0bff,0x804c1946,0x804d0e13,0x80520686,0x80540b6a,0x80580ef4,0x805a09a5,
	0x80690a99,0x806a02e8,0x80710036,0x807f17e6,0x808017e3,0x80831271,0x80841711,0x8086124c,
	0x808718e7,0x808910ae,0x808b0b0c,0x808c07df,0x80930779,0x8096153b,0x80981997,0x809a0431,
	0x809b0596,0x809c109b,0x809d057e,0x809f1446,0x80a001f3,0x80a10622,0x80a21939,0x80a40518,
	0x80a504d8,0x80a90866,0x80aa04c6,0x80ab19f3,0x80ad0da5,0x80ae002b,0x80af0a38,0x80b105ea,
	0x80b217ea,0x80b4168d,0x80b70f95,0x80ba04e5,0x80bc0944,0x80bd12ca,0x80be1177,0x80bf1987,
	0x80c018d4,0x80c1154d,0x80c21179,0x80c31420,0x80c4199e,0x80c60352,0x80cc00af,0x80cd0639,
	0x80ce12be,0x80d60e76,0x80d7190b,0x80d91a67,0x80da0e84,0x80db0856,0x80dc1188,0x80dd193c,
	0x80de008f,0x80e1072c,0x80e41742,0x80e515ae,0x80e70bfc,0x80e8040f,0x80e909e7,0x80ea0c1f,
	0x80eb094e,0x80ec0e2c,0x80ed162e,0x80ef0a60,0x80f016d4,0x80f1065a,0x80f2069a,0x80f305b7,
	0x80f40410,0x80f608c1,0x80f81598,0x80fa0028,0x80fc0ed6,0x80fd0dd6,0x8102193d,0x81060308,
	0x81090c98,0x810a0814,0x810d0a69,0x810e10d9,0x810f1867,0x81100f48,0x81110dcb,0x81120d15,
	0x81130e24,0x81140c45,0x81160155,0x811813d7,0x811a08d5,0x811e031e,0x812c0e78,0x812f054b,
	0x813113a2,0x81320dff,0x81360c57,0x81380b74,0x813e0ebd,0x8146133a,0x8148093b,0x814a0ab0,
	0x814b16b8,0x814c1635,0x8150054f,0x8151054d,0x815304da,0x81540fa8,0x815513df,0x81591a33,
	0x815a03fa,0x816002ef,0x81651581,0x81671206,0x81690dbb,0x816d0483,0x816e10dc,0x81701689,
	0x8171089d,0x817417ca,0x81790562,0x817a150b,0x817b0dea,0x817c0d2d,0x817d13c0,0x817e1315,
	0x817f1393,0x81800084,0x81820c78,0x818805c8,0x818a0164,0x818f05a4,0x8191013d,0x81980121,
	0x819b12f1,0x819c0d6b,0x819d14aa,0x81a3197b,0x81a60bc4,0x81a80ea3,0x81aa01d1,0x81b3112d,
	0x81ba174e,0x81bb111f,0x81c0139d,0x81c10b6f,0x81c200fd,0x81c31775,0x81c6171d,0x81ca10f0,
	0x81cc062b,0x81e3021f,0x81e71865,0x81ea1a2d,0x81ec0e04,0x81ed0286,0x81f3195a,0x81f4196b,
	0x81fb190a,0x81fc096e,0x81fe17b9,0x8200169c,0x820117be,0x8202026f,0x820414c8,0x82050976,
	0x820617d2,0x820c1154,0x820d1157,0x821011c2,0x821211ea,0x8214133b,0x821b02ad,0x821c1221,
	0x821e146d,0x821f1990,0x822102a9,0x8222111b,0x822316e5,0x82280075,0x822a06c0,0x822b04cb,
	0x822c006a,0x822d00d9,0x822f1983,0x82300897,0x8231019c,0x823319b8,0x82341880,0x82350465,
	0x8236015e,0x823714f2,0x823805cc,0x823902aa,0x823b0c21,0x823e14a0,0x82441143,0x82471360,
	0x82491418,0x824b0cff,0x824f11d4,0x82581263,0x825a01a4,0x825f0271,0x82680cfb,0x826e05d7,
	0x826f0b7e,0x82700867,0x827210f6,0x8273165f,0x82740539,0x8279003d,0x827a16ef,0x827d101a,
	0x827e0010,0x827f0dad,0x828208f0,0x828413cb,0x82880d40,0x828a0f7b,0x828b17e7,0x828d1146,
	0x828e1596,0x828f042e,0x82910f5f,0x82920cad,0x8297150e,0x82980eb4,0x82990524,0x829c145b,
	0x829d1934,0x829f1116,0x82a10f9b,0x82a40a48,0x82a50906,0x82a60c1a,0x82a807e0,0x82a90fe1,
	0x82aa0f42,0x82ab163e,0x82ac04ed,0x82ad004b,0x82ae10c8,0x82af156f,0x82b00822,0x82b1074a,
	0x82b304c0,0x82b41476,0x82b71952,0x82b81839,0x82b90fe2,0x82bd1619,0x82be04e9,0x82c102e3,
	0x82c40114,0x82c7140e,0x82c80b45,0x82ca0478,0x82cb1502,0x82cc01f4,0x82cd019b,0x82ce19c6,
	0x82cf126b,0x82d1181e,0x82d21075,0x82d30bca,0x82d412c2,0x82d51147,0x82d70d31,0x82d81002,
	0x82db0a18,0x82dc0d96,0x82de008e,0x82df0601,0x82e00d4a,0x82e116e4,0x82e30997,0x82e40eea,
	0x82e510d0,0x82e60a56,0x82eb1120,0x82ef00c2,0x82f11760,0x82f4097c,0x82f70581,0x82f90efc,
	0x82fb052a,0x830119ff,0x83020cc5,0x830304b8,0x83040fd2,0x83050cb9,0x83060cbf,0x83070051,
	0x830802d4,0x83090d74,0x830c0255,0x830e0935,0x830f0bf9,0x83110dfb,0x83141751,0x83151010,
	0x83170d5a,0x831a1741,0x831b05d8,0x831c0f9c,0x8327087b,0x832802d5,0x832b0caf,0x832c01b8,
	0x832d08bf,0x832f052f,0x833119aa,0x833308a7,0x8334079e,0x83351725,0x833601b9,0x8338109e,
	0x833910b0,0x833a026e,0x833c1367,0x83401601,0x83431052,0x83460936,0x83471591,0x834901a6,
	0x834f108b,0x83500893,0x835116d1,0x8352077a,0x83540b4f,0x835a084e,0x835b107e,0x835c00e3,
	0x835e0fc0,0x835f07aa,0x8360083b,0x8361036a,0x8363109f,0x836407b9,0x8365158a,0x83660c67,
	0x83671753,0x83680f8a,0x83690929,0x836a1297,0x836b1726,0x836c0c93,0x836d070a,0x836e199f,
	0x836f169e,0x837706e4,0x837800cf,0x837b039c,0x837c1382,0x837d1285,0x83850b56,0x83860f1b,
	0x83890b39,0x838e1103,0x8392098e,0x83930cd5,0x8398116d,0x839b1357,0x839c1791,0x839e13d3,
	0x83a0179d,0x83a80ae2,0x83a90533,0x83aa046f,0x83ab0d77,0x83b009ff,0x83b10ab8,0x83b20b69,
	0x83b311ac,0x83b41441,0x83b614e5,0x83b707cf,0x83b81792,0x83b91754,0x83ba1744,0x83bc02c5,
	0x83bd0cb2,0x83c013d8,0x83c10939,0x83c5086b,0x83c70614,0x83ca0988,0x83cc09d8,0x83cf06e7,
	0x83d4053a,0x83d601ef,0x83d81252,0x83dc018b,0x83dd0052,0x83df138b,0x83e00153,0x83e106b6,
	0x83e5149a,0x83e90f1c,0x83ea036c,0x83f00615,0x83f10bd6,0x83f204d2,0x83f81632,0x83f91a44,
	0x83fd11e8,0x84010f4d,0x8403030c,0x8404130b,0x840600ea,0x840b0f35,0x840c0cf4,0x840d0f00,
	0x840e1415,0x840f035e,0x84110763,0x84180db2,0x841c134c,0x841d0c58,0x84241755,0x84251756,
	0x84261757,0x84271533,0x842810da,0x843115d0,0x843817c4,0x843c0481,0x843d0c6a,0x84460099,
	0x84510507,0x845719cf,0x84591514,0x845a1176,0x845b05c2,0x845c0f73,0x84610f1d,0x84630405,
	0x84690e4d,0x846b0731,0x846c1868,0x846d0848,0x847102e5,0x847313f4,0x84750a88,0x8476135a,
	0x847814bf,0x847a0f6e,0x848203b3,0x848701e5,0x848809f2,0x84890a96,0x848b08b1,0x848c0c0a,
	0x848e0e5d,0x84970ae5,0x84990cf2,0x849c1282,0x84a10088,0x84af0a62,0x84b20f1e,0x84b4122a,
	0x84b81925,0x84b90872,0x84ba080b,0x84bd048a,0x84bf06c3,0x84c11907,0x84c415c9,0x84c910a3,
	0x84ca143b,0x84cd1196,0x84d010c1,0x84d112a5,0x84d300b8,0x84d600f0,0x84dd0ac7,0x84df0831,
	0x84e00b21,0x84e317fe,0x84e5175a,0x84e60d7a,0x84ec0e9f,0x84f014c1,0x84fc0b9b,0x84ff15ca,
	0x850c127d,0x85110d44,0x85130ca8,0x851718f9,0x851a1427,0x851f02f7,0x8521018c,0x852b0dec,
	0x852c11ee,0x85370faf,0x85380414,0x85390b76,0x853a0bc3,0x853b0a4f,0x853c000e,0x853d00f6,
	0x854304ae,0x8548160d,0x854908c8,0x854a10c7,0x8556103d,0x855907b6,0x855e1a56,0x856410c6,
	0x856809cb,0x85720f57,0x8574184b,0x8579143d,0x857a080e,0x857b070e,0x857e0b0a,0x85840166,
	0x858506c5,0x858713f7,0x858f171a,0x859b15e7,0x859c00fa,0x85a41566,0x85a80703,0x85aa1576,
	0x85ae1268,0x85af11f9,0x85b015f6,0x85b710b6,0x85b912c6,0x85c105ad,0x85c9090e,0x85cf019d,
	0x85d00d3b,0x85d314fe,0x85d50e48,0x85dc0b28,0x85e41318,0x85e904a8,0x85fb1870,0x85ff07d5,
	0x860506fe,0x86110d6e,0x86160e0c,0x86271040,0x862904b2,0x863818c2,0x863c0d11,0x864d0720,
	0x864e0739,0x864f0c25,0x86500e30,0x86510c7e,0x86540f8c,0x865a15b0,0x865e17cf,0x8662068c,
	0x866b0272,0x866c101e,0x866e0812,0x86711191,0x8679070b,0x867a07a0,0x867b0cf3,0x867c05cf,
	0x867d1284,0x867e14cc,0x867f01ce,0x868011a1,0x868116e6,0x86820c8a,0x868a142f,0x868b10ca,
	0x868c0081,0x868d0eb8,0x8693173c,0x86950191,0x869c161b,0x869d06c6,0x86a305ed,0x86a4186e,
	0x86a7090c,0x86a80534,0x86a90248,0x86aa041a,0x86ac14fb,0x86af1017,0x86b01794,0x86b118a5,
	0x86b417aa,0x86b50a16,0x86b606a1,0x86ba1070,0x86c019d0,0x86c40616,0x86c61032,0x86c71156,
	0x86c90bd7,0x86ca0627,0x86cb035f,0x86ce0b5b,0x86cf022f,0x86d01034,0x86d10d83,0x86d4079f,
	0x86d8167c,0x86d913bb,0x86db19b0,0x86de0aa7,0x86df08c4,0x86e405c3,0x86e91013,0x86ed1976,
	0x86ee0c9a,0x86f018ed,0x86f10852,0x86f20dc8,0x86f31236,0x86f40f53,0x86f8152a,0x86f91781,
	0x86fe0472,0x870011f8,0x87020509,0x8703117d,0x870718ea,0x8708145e,0x8709053e,0x870a0b3a,
	0x870d028f,0x87121647,0x8713135b,0x87151396,0x87171443,0x8718193e,0x871a04d4,0x871c0d21,
	0x871e0f56,0x87210ab2,0x87220d00,0x87230fa9,0x872514a7,0x87291344,0x872e1801,0x87310ebf,
	0x87341714,0x87371058,0x873b0ffa,0x873e0690,0x873f13c7,0x8747175c,0x87480688,0x874901db,
	0x874c0a26,0x874e154a,0x875317d3,0x87570789,0x87590107,0x87600541,0x87631798,0x87641028,
	0x87650cbd,0x876e0565,0x87700a8c,0x87740736,0x877603e8,0x877b0dbc,0x877c0c0d,0x877d02c2,
	0x877e10a6,0x87820ae0,0x87830e74,0x878514ae,0x8788181c,0x878b1264,0x878d10a7,0x87930fec,
	0x879712f3,0x879f0d60,0x87a80ca1,0x87ab11cd,0x87ac01a5,0x87ad024f,0x87af0037,0x87b312f4,
	0x87b50ede,0x87ba0c5f,0x87bd1986,0x87c01211,0x87c60c8e,0x87ca0cbe,0x87cb14af,0x87d118cc,
	0x87d20cb4,0x87d31529,0x87db0ea4,0x87e00e64,0x87e5077c,0x87ea07b7,0x87ee112f,0x87f9156a,
	0x87fe01de,0x88030c63,0x880a0b71,0x88130d02,0x881510b8,0x881607d6,0x881b0d46,0x88210b2b,
	0x882202c9,0x883209af,0x88390435,0x883c1043,0x884015f0,0x88440e3c,0x8845157c,0x884c1584,
	0x884d164e,0x885414f3,0x885708ed,0x8859161f,0x886106fd,0x88621047,0x886316bd,0x886416bb,
	0x88650173,0x88680127,0x886901c1,0x886b1118,0x886c0228,0x886e067c,0x8870120d,0x88720da7,
	0x88771984,0x887d1096,0x887e0fe0,0x887f0916,0x88811813,0x88820ce7,0x8884003b,0x88850dfc,
	0x88880847,0x888b0343,0x888d0e7e,0x889212df,0x889615a8,0x889c13bf,0x88a20e6c,0x88a40cc9,
	0x88ab00b3,0x88ad14b5,0x88b1053b,0x88b7084c,0x88bc05b8,0x88c10186,0x88c20baa,0x88c519e4,
	0x88c60363,0x88c90a3c,0x88ce023d,0x88d20f12,0x88d41712,0x88d517f9,0x88d81027,0x88d9106e,
	0x88df1106,0x88e20b6b,0x88e30b75,0x88e40a5a,0x88e50884,0x88e800f1,0x88f00459,0x88f10129,
	0x88f3113d,0x88f40e8a,0x88f80c61,0x88f90691,0x88fc132e,0x88fe0983,0x89020641,0x890a010f,
	0x891006ed,0x89120093,0x8913009a,0x891900b9,0x891a0299,0x891b0c79,0x89210328,0x892510c2,
	0x892a1397,0x892b025f,0x89300f88,0x89340aca,0x893618f5,0x89410fb4,0x89441516,0x895e0100,
	0x895f0918,0x896610b7,0x897b0e6d,0x897f1487,0x8981169f,0x89830fed,0x89860567,0x89c1088d,
	0x89c20647,0x89c40662,0x89c50d1b,0x89c611b8,0x89c701d2,0x89c80acf,0x89c909c1,0x89ca082b,
	0x89cb14b6,0x89cc039e,0x89ce17d0,0x89cf060c,0x89d00930,0x89d1104a,0x89d208cc,0x89d609c6,
	0x89da0617,0x89dc1a1b,0x89de1134,0x89e30903,0x89e505f0,0x89e6029f,0x89eb127e,0x89ef197c,
	0x89f30738,0x8a00163f,0x8a070701,0x8a3e1a21,0x8a480b5e,0x8a7918b3,0x8a8917ff,0x8a8a1316,
	0x8a9311cb,0x8b07088b,0x8b261005,0x8b660949,0x8b6c0ed0,0x8ba01639,0x8ba1081b,0x8ba203f7,
	0x8ba30553,0x8ba4108e,0x8ba507d7,0x8ba608f1,0x8ba7070f,0x8ba8130d,0x8ba9107d,0x8baa1123,
	0x8bab0f66,0x8bad1605,0x8bae16f0,0x8baf1606,0x8bb0081c,0x8bb208ae,0x8bb307a7,0x8bb40e40,
	0x8bb50995,0x8bb61624,0x8bb70dd0,0x8bb815b6,0x8bb9046b,0x8bba0c54,0x8bbc1258,0x8bbd050e,
	0x8bbe1159,0x8bbf04c9,0x8bc009bd,0x8bc1192b,0x8bc20620,0x8bc306d6,0x8bc40ef9,0x8bc51a49,
	0x8bc6119d,0x8bc818a0,0x8bc91270,0x8bca190d,0x8bcb03a1,0x8bcc1991,0x8bcd02d2,0x8bce102e,
	0x8bcf18e1,0x8bd116f8,0x8bd216cb,0x8bd30a6f,0x8bd40b07,0x8bd511b9,0x8bd6063f,0x8bd71192,
	0x8bd80810,0x8bd907a3,0x8bda0237,0x8bdb19a7,0x8bdc1168,0x8bdd0755,0x8bde0359,0x8bdf0605,
	0x8be01050,0x8be1066c,0x8be215fc,0x8be316ff,0x8be4192c,0x8be50570,0x8be61519,0x8be701c4,
	0x8be807bf,0x8be915b7,0x8beb090a,0x8bec1455,0x8bed17dc,0x8bee0fcc,0x8bef1478,0x8bf005af,
	0x8bf117a9,0x8bf207ab,0x8bf30a73,0x8bf41223,0x8bf5125a,0x8bf60488,0x8bf71004,0x8bf819ad,
	0x8bf91a3c,0x8bfa0e33,0x8bfb0423,0x8bfc1a03,0x8bfd04dc,0x8bfe0a32,0x8bff1414,0x8c0017c1,
	0x8c01121a,0x8c021173,0x8c0303d8,0x8c0401e2,0x8c050b8a,0x8c0619f5,0x8c07128e,0x8c0812d6,
	0x8c0a1709,0x8c0b0d87,0x8c0c0226,0x8c0d03e1,0x8c0e0790,0x8c0f0899,0x8c101551,0x8c1115f1,
	0x8c1216b7,0x8c131423,0x8c14047d,0x8c1517f4,0x8c1615cd,0x8c1701d6,0x8c181a15,0x8c19001d,
	0x8c1a1661,0x8c1b03af,0x8c1c0d0b,0x8c1d0ed8,0x8c1f0d66,0x8c200366,0x8c211277,0x8c221560,
	0x8c231692,0x8c240087,0x8c2511c7,0x8c260f83,0x8c270d1f,0x8c28091e,0x8c290c9f,0x8c2a18ee,
	0x8c2b0887,0x8c2c0d63,0x8c2d12da,0x8c2e1887,0x8c2f0fc2,0x8c300ac8,0x8c310f28,0x8c3209c9,
	0x8c331668,0x8c340f97,0x8c3518b4,0x8c36022c,0x8c370621,0x8c4107c4,0x8c46041b,0x8c4708a9,
	0x8c49025e,0x8c4c13c8,0x8c5511a7,0x8c5a139c,0x8c611526,0x8c620775,0x8c6a06c9,0x8c6b1802,
	0x8c730139,0x8c78195d,0x8c79009d,0x8c7a01cc,0x8c8203d2,0x8c8515a1,0x8c8906e9,0x8c8a0d7b,
	0x8c8c0ccd,0x8c940eca,0x8c980d80,0x8d1d00ab,0x8d1e18fc,0x8d1f0556,0x8d2105f7,0x8d220185,
	0x8d23187b,0x8d2414ee,0x8d250066,0x8d2618d5,0x8d2707ce,0x8d281963,0x8d2904b9,0x8d2a12cf,
	0x8d2b0eed,0x8d2c010a,0x8d2d0606,0x8d2e19c9,0x8d2f064f,0x8d300499,0x8d310894,0x8d3200bf,
	0x8d3311c0,0x8d34134b,0x8d350675,0x8d360a7b,0x8d370341,0x8d380cc7,0x8d3904e6,0x8d3a06ec,
	0x8d3b16d2,0x8d3c1885,0x8d3d196c,0x8d3e0857,0x8d3f07ae,0x8d401a11,0x8d410bc2,0x8d420c2e,
	0x8d431864,0x8d441a12,0x8d450573,0x8d46092d,0x8d471024,0x8d481919,0x8d490abb,0x8d4a1151,
	0x8d4b0560,0x8d4c042c,0x8d4d07ed,0x8d4e11f1,0x8d4f1139,0x8d5002e0,0x8d5305dc,0x8d540e88,
	0x8d550355,0x8d560abd,0x8d5819f2,0x8d590564,0x8d5a19dd,0x8d5b10df,0x8d5c1882,0x8d5d166b,
	0x8d5e1861,0x8d60188f,0x8d61112e,0x8d62175e,0x8d630592,0x8d640263,0x8d66115d,0x8d670dba,
	0x8d6b06ee,0x8d6d18f4,0x8d701a40,0x8d730962,0x8d74055c,0x8d7518e2,0x8d760589,0x8d770f62,
	0x8d81022a,0x8d840fd4,0x8d850208,0x8d8a1831,0x8d8b1035,0x8d911a1c,0x8d940bab,0x8d9f12fe,
	0x8da3104b,0x8db1185f,0x8db31a45,0x8db40e4b,0x8db5009e,0x8db8044d,0x8dba0519,0x8dbc0881,
	0x8dbe1957,0x8dbf12b0,0x8dc3182f,0x8dc40fa7,0x8dc612c4,0x8dcb0053,0x8dcc03dd,0x8dce13ac,
	0x8dcf0849,0x8dd10e80,0x8dd6194a,0x8dd7051c,0x8dda111c,0x8ddb0168,0x8ddd09a0,0x8dde0b5f,
	0x8ddf05d4,0x8de314fd,0x8de408c5,0x8de80a61,0x8dea0677,0x8deb100b,0x8dec0a90,0x8def0c35,
	0x8df3134a,0x8df5089e,0x8df70fb7,0x8df800f2,0x8df914e7,0x8dfa0467,0x8dfb07ef,0x8dfd0833,
	0x8e0515ec,0x8e090b85,0x8e0a1782,0x8e0c0282,0x8e0f12bc,0x8e1402ca,0x8e1d075b,0x8e1e09a7,
	0x8e1f0258,0x8e22131c,0x8e230165,0x8e29018a,0x8e2a1a34,0x8e2c197d,0x8e2e03be,0x8e2f194c,
	0x8e31045d,0x8e35198a,0x8e3901d0,0x8e3a08a3,0x8e3d0992,0x8e4003e9,0x8e410ed7,0x8e4210ac,
	0x8e441323,0x8e47088c,0x8e480377,0x8e490319,0x8e4a1483,0x8e4b12bd,0x8e510e0a,0x8e520e63,
	0x8e5902fa,0x8e6600cd,0x8e69012f,0x8e6c0387,0x8e6d01b1,0x8e6f04b1,0x8e700293,0x8e72044b,
	0x8e7402fb,0x8e7609cf,0x8e7c0f2b,0x8e7f02ff,0x8e811877,0x8e8519ba,0x8e870292,0x8e8f0bc5,
	0x8e900bac,0x8e9401df,0x8e9c1a4e,0x8e9e156b,0x8eab1165,0x8eac05ee,0x8eaf1033,0x8eb20462,
	0x8eba12fb,0x8ece1421,0x8f660211,0x8f671898,0x8f680669,0x8f6915cb,0x8f6b1093,0x8f6c19db,
	0x8f6d0479,0x8f6e0c53,0x8f6f10c5,0x8f7006ff,0x8f710612,0x8f720a1c,0x8f730c3e,0x8f741996,
	0x8f751956,0x8f761705,0x8f770724,0x8f78190f,0x8f790b50,0x8f7a168f,0x8f7b0ff5,0x8f7c11c3,
	0x8f7d1857,0x8f7e196d,0x8f7f08de,0x8f811054,0x8f820c2f,0x8f8308df,0x8f8418ec,0x8f85054c,
	0x8f860b8b,0x8f870df2,0x8f8800b6,0x8f890798,0x8f8a067e,0x8f8b13e8,0x8f8d02cf,0x8f8e1a1a,
	0x8f8f02f0,0x8f90053f,0x8f91080c,0x8f9311ed,0x8f940e90,0x8f95181a,0x8f9614d8,0x8f9718bc,
	0x8f980c38,0x8f9918f1,0x8f9a0bb7,0x8f9b1570,0x8f9c0618,0x8f9e02d8,0x8f9f0ec9,0x8fa30ab3,
	0x8fa80119,0x8fa9011a,0x8fab011b,0x8fb00222,0x8fb110bc,0x8fb602cd,0x8fb90102,0x8fbd0b8f,
	0x8fbe0329,0x8fc10f7c,0x8fc217ae,0x8fc40f68,0x8fc51608,0x8fc70692,0x8fc80c95,0x8fce1750,
	0x8fd01842,0x8fd10927,0x8fd31625,0x8fd404b4,0x8fd5146f,0x8fd80698,0x8fd918f6,0x8fdb0928,
	0x8fdc181d,0x8fdd1401,0x8fde0b65,0x8fdf0254,0x8fe21341,0x8fe416dd,0x8fe5095c,0x8fe60840,
	0x8fe8033b,0x8fe90492,0x8fea0399,0x8feb0f0c,0x8fed03de,0x8fee187c,0x8ff01200,0x8ff3094d,
	0x8ff70d09,0x8ff800cb,0x8ff90819,0x8ffd19ea,0x90001394,0x9001125b,0x900211c1,0x90031306,
	0x90040e72,0x9005071b,0x90060de6,0x900915da,0x900a160a,0x900b016d,0x900d1532,0x900f137b,
	0x901019b7,0x90111022,0x901203ad,0x90141383,0x9016132b,0x9017041c,0x901a1361,0x901b065d,
	0x901d11c4,0x901e0243,0x901f1274,0x90201874,0x9021106d,0x9022050c,0x90260b31,0x902d0773,
	0x902e0344,0x902f0c31,0x90350a84,0x903613f2,0x9038170d,0x903b0c59,0x903c00ce,0x903e17cb,
	0x90410455,0x9042128f,0x904402ab,0x904717fa,0x904d0118,0x904f0482,0x905014d5,0x90510784,
	0x90521026,0x9053037c,0x905716d7,0x9058060b,0x905b0bf2,0x906212ba,0x90630f96,0x90651695,
	0x90680034,0x906d1869,0x906e18e8,0x90740bb6,0x90751a59,0x907d09a8,0x907f00fb,0x9080168a,
	0x90821567,0x90831294,0x90880d3c,0x908b0aac,0x909116f9,0x9093038a,0x9095176e,0x909706a5,
	0x90990cab,0x909b100d,0x909d0a75,0x90a104be,0x90a21585,0x90a30da3,0x90a6007d,0x90aa154c,
	0x90ac1451,0x90ae178e,0x90af06a7,0x90b012c0,0x90b11015,0x90b30eaa,0x90b40144,0x90b5114b,
	0x90b600ad,0x90b803a2,0x90b91a3a,0x90ba16b1,0x90bb0baf,0x90be19a8,0x90c117eb,0x90c40fdc,
	0x90c51964,0x90c70760,0x90ca08bb,0x90ce0ad9,0x90cf084d,0x90d00a66,0x90d1192d,0x90d31843,
	0x90d7148e,0x90db0530,0x90dc05b0,0x90dd06ce,0x90e109dc,0x90e21761,0x90e60b51,0x90e7183b,
	0x90e8017b,0x90eb0eb9,0x90ed0684,0x90ef12d7,0x90f4021b,0x90f8034d,0x90fd0412,0x90fe1653,
	0x9102047e,0x910409b8,0x911900da,0x911e1733,0x91221636,0x912318c5,0x912f1129,0x91310f07,
	0x91391a3e,0x91430bdb,0x9146050a,0x9149179c,0x914a03f3,0x914b1021,0x914c1a04,0x914d0e8f,
	0x914e19a1,0x914f16de,0x91500585,0x9152096c,0x915715c4,0x915a04ef,0x915d1846,0x915e12cd,
	0x916113ad,0x916202f6,0x916306a2,0x91640619,0x9165126c,0x91690d61,0x916a0af6,0x916c0281,
	0x916e136c,0x916f1959,0x917014e8,0x917108b7,0x9172023f,0x91741385,0x917508e2,0x91760cdd,
	0x91770a5b,0x91781281,0x91790b0f,0x917d1667,0x917e1197,0x917f0df9,0x91850e85,0x918702c8,
	0x91891a57,0x918b02f8,0x918c0a9f,0x918d1324,0x91900737,0x919115ba,0x9192158b,0x919a0d0c,
	0x919b1059,0x91a2069b,0x91a312f5,0x91aa0aec,0x91ad0170,0x91ae08e4,0x91af14b0,0x91b40b36,
	0x91b509a9,0x91ba15f8,0x91c70187,0x91c917ab,0x91ca11c8,0x91cc0b2e,0x91cd198d,0x91ce16ac,
	0x91cf0b86,0x91d10913,0x91dc054a,0x9274089f,0x928e100c,0x92ae0c47,0x92c81482,0x933e1862,
	0x936a0d88,0x938f0bee,0x93ca0044,0x93d60039,0x943e00bb,0x946b1578,0x94850912,0x9486056b,
	0x948716e2,0x948818fd,0x948903f1,0x948a18da,0x948b0f02,0x948c0b9a,0x948d1388,0x948e0f7f,
	0x948f02b0,0x94901119,0x949204ab,0x949303d7,0x94940ced,0x94950e3a,0x949701c8,0x94990576,
	0x949a017a,0x949b12cb,0x949c099a,0x949d0453,0x949e0207,0x949f1982,0x94a00da8,0x94a100b0,
	0x94a20598,0x94a30074,0x94a40f8b,0x94a516a3,0x94a60fdf,0x94a709d6,0x94a81456,0x94a905fb,
	0x94aa0a0d,0x94ab04c2,0x94ac07ca,0x94ad0418,0x94ae0e1e,0x94af0056,0x94b017f0,0x94b10f8d,
	0x94b21921,0x94b30f8e,0x94b40626,0x94b50151,0x94b60a1e,0x94b70f0a,0x94b8016e,0x94b9015c,
	0x94ba182d,0x94bb1a4f,0x94bc0d97,0x94bd12e0,0x94be0858,0x94bf03c7,0x94c01793,0x94c1134d,
	0x94c2015d,0x94c30bcf,0x94c41227,0x94c50f82,0x94c60cc4,0x94c811c5,0x94c915e0,0x94ca12b1,
	0x94cb00e7,0x94cc0ddd,0x94cd0eb2,0x94ce045c,0x94d00a13,0x94d10af1,0x94d20496,0x94d5179e,
	0x94d6023b,0x94d70851,0x94d816a9,0x94d90dc6,0x94db0361,0x94dc136a,0x94dd0c75,0x94de03da,
	0x94df172a,0x94e009f0,0x94e1189a,0x94e219af,0x94e314bd,0x94e4135f,0x94e503fe,0x94e70750,
	0x94e81056,0x94e91104,0x94ea0693,0x94eb03db,0x94ec05d1,0x94ed0d5c,0x94ee1923,0x94ef10f9,
	0x94f008d6,0x94f116c1,0x94f201e3,0x94f30275,0x94f412fc,0x94f50022,0x94f61732,0x94f710b1,
	0x94f819d2,0x94f90aeb,0x94fa0f18,0x94fc0ab9,0x94fd1312,0x94fe0b7b,0x94ff0a3f,0x95001535,
	0x950112ab,0x95020b33,0x9503188d,0x9504028e,0x95050687,0x950605b1,0x95070470,0x950815a9,
	0x95090322,0x950a0c4c,0x950b0508,0x950c1573,0x950d0bf1,0x950e09eb,0x950f0885,0x951010cb,
	0x9511131b,0x95120adf,0x95130fee,0x95140982,0x95150002,0x95160faa,0x951718f3,0x95180e36,
	0x95190323,0x951a0cbb,0x951b00c0,0x951d0380,0x951e0a37,0x951f0a9d,0x952114a3,0x95220635,
	0x95230c5b,0x952402bf,0x952519ed,0x9526091f,0x952814e9,0x952909b0,0x952a07cc,0x952b0e89,
	0x952c12d9,0x952d03fc,0x952e08a0,0x952f09a3,0x95300cfe,0x95311a1d,0x95320fdb,0x953409f4,
	0x95350fab,0x95361238,0x95370484,0x953801b6,0x95390fba,0x953a1985,0x953b043d,0x953c1262,
	0x953e0764,0x953f0008,0x95400434,0x95410ce4,0x95420c15,0x954404e8,0x95450cde,0x95460d7e,
	0x9547191a,0x954905c9,0x954a0e07,0x954c09ae,0x954d0e08,0x954e0da1,0x954f0bed,0x955005ac,
	0x9551008a,0x95521717,0x9553084b,0x95540137,0x95560123,0x955712e8,0x95580caa,0x95590c5e,
	0x955b1774,0x955c0959,0x955d0396,0x955e1a48,0x955f15e4,0x95611579,0x956209ce,0x95630b9d,
	0x95640f21,0x95650c29,0x95660446,0x95670acd,0x95680f2a,0x956902fe,0x956a0fb1,0x956b038f,
	0x956c07d3,0x956d0b02,0x956f1a0a,0x95700b70,0x9571171f,0x957201c0,0x95730126,0x95761518,
	0x957f01f2,0x95e80ceb,0x95e91212,0x95ea1121,0x95eb163b,0x95ed00de,0x95ee1436,0x95ef02b5,
	0x95f010ce,0x95f11402,0x95f214ec,0x95f30707,0x95f40865,0x95f50d4f,0x95f60a0b,0x95f70cef,
	0x95f81899,0x95f90dcd,0x95fa0664,0x95fb142e,0x95fc12b9,0x95fd0d52,0x95fe0c6f,0x9600049f,
	0x960105be,0x960206e1,0x96030aa3,0x96040963,0x9605182e,0x96060ae3,0x960817f5,0x96091633,
	0x960a01f0,0x960b14c7,0x960c1430,0x960d07bb,0x960e1645,0x960f047f,0x961001e4,0x96110ac6,
	0x96121049,0x96140aa8,0x96151069,0x961606ea,0x96171337,0x9619106a,0x961a0a02,0x961c0559,
	0x961d0551,0x961f0440,0x96210f79,0x96221474,0x962a0070,0x962e10c3,0x96310942,0x963204c3,
	0x96331674,0x96341722,0x96351915,0x963608e5,0x963b1a4a,0x963c1a63,0x963d03c2,0x963f0000,
	0x964013a6,0x964200a3,0x96440557,0x96450823,0x96460c2c,0x96470c03,0x96480223,0x96491587,
	0x964b0c12,0x964c0d75,0x964d08b4,0x96501505,0x96540571,0x96551122,0x965b00e4,0x965f1967,
	0x96610419,0x96621820,0x9664028b,0x96670e01,0x9668183f,0x966914f9,0x966a0e86,0x966c1a3d,
	0x967202bb,0x96740eb1,0x96750bd0,0x96761308,0x96771507,0x968517c5,0x96860c00,0x968813f3,
	0x968b1289,0x968d077f,0x968f128a,0x9690173d,0x969405c4,0x96970a8e,0x96980013,0x969914c9,
	0x969c18d6,0x96a71291,0x96b014b8,0x96b3079b,0x96b60b4a,0x96b919e9,0x96bc129b,0x96bd09b6,
	0x96be0db7,0x96c01067,0x96c11665,0x96c41599,0x96c51622,0x96c60809,0x96c70633,0x96c9197a,
	0x96cc02da,0x96cd1770,0x96ce0984,0x96cf0290,0x96d20c6d,0x96d503d4,0x96e00283,0x96e817d9,
	0x96e917c6,0x96ea15ee,0x96ef1431,0x96f30b60,0x96f60bd8,0x96f70afe,0x96f90092,0x96fe147f,
	0x970015b2,0x97010834,0x97041538,0x9706135c,0x9707191b,0x97080e91,0x97090ce0,0x970d07d2,
	0x970e110e,0x970f04d5,0x97130ddf,0x97160bb8,0x971c1217,0x971e14d9,0x972a1736,0x972d000f,
	0x9730150c,0x97320c2b,0x9738005c,0x97390eb0,0x973e0c91,0x97520ff3,0x97530954,0x97560955,
	0x97590958,0x975b03cc,0x975e04cf,0x97600a15,0x97610d10,0x97620d2f,0x976516b9,0x976905bf,
	0x9773092f,0x977415e6,0x97760057,0x977c032e,0x97851671,0x978b1556,0x978d001f,0x9791032f,
	0x97920fc4,0x97940c9d,0x97980fd0,0x97a00985,0x97a310ad,0x97ab0986,0x97ad0109,0x97af0875,
	0x97b205fe,0x97b400ba,0x97e613fc,0x97e71094,0x97e906ad,0x97ea1419,0x97eb1848,0x97ec1303,
	0x97ed096b,0x97f31727,0x97f51849,0x97f61148,0x987516b0,0x987603f5,0x98771003,0x987806a0,
	0x98791525,0x987a1220,0x987b15af,0x987c15bb,0x987d13ce,0x987e062f,0x987f0454,0x98800f49,
	0x9881006b,0x9882125c,0x988306c1,0x988417f1,0x98850c22,0x98860bdf,0x98870f05,0x98880945,
	0x988908fa,0x988a0853,0x988c06e8,0x988d1762,0x988f0a20,0x989016d8,0x98910eef,0x98931392,
	0x989406b7,0x98961763,0x98970a23,0x98981322,0x989a0474,0x989b19da,0x989c1648,0x989d0473,
	0x989e0e09,0x989f0c99,0x98a003b8,0x98a110ec,0x98a206d4,0x98a401e9,0x98a510b9,0x98a60ef0,
	0x98a7105b,0x98ce04ff,0x98d1011e,0x98d210d8,0x98d309a2,0x98d51261,0x98d80edd,0x98d90124,
	0x98da0125,0x98de04cd,0x98df11a2,0x98e71298,0x98e81520,0x990d1669,0x9910018f,0x992e134f,
	0x99541777,0x99551304,0x9963119a,0x996507da,0x99671582,0x9968139b,0x996914c5,0x996a1095,
	0x996b17e9,0x996c0264,0x996d04b7,0x996e173b,0x996f0890,0x997011ba,0x99710095,0x99721247,
	0x997416ce,0x99750494,0x9976107f,0x9977151f,0x997a08d2,0x997c0148,0x997d0152,0x997f047c,
	0x998017c2,0x99810dd2,0x998407bd,0x99851508,0x9986064d,0x998701b5,0x99880a97,0x998a1260,
	0x998b01d9,0x998d0d68,0x998f0bf3,0x999015a2,0x99910921,0x99920c9b,0x999310e5,0x999419e0,
	0x99950dbf,0x999611d3,0x99970a85,0x9998068d,0x99991510,0x99a50568,0x99a81577,0x9a6c0c86,
	0x9a6d17e5,0x9a6e13a4,0x9a6f1604,0x9a700253,0x9a71102f,0x9a730157,0x9a740c6e,0x9a751866,
	0x9a7611aa,0x9a771248,0x9a78055a,0x9a79097d,0x9a7a1a3b,0x9a7b19ca,0x9a7c13a9,0x9a7d0e29,
	0x9a7e085c,0x9a7f1700,0x9a800347,0x9a81152e,0x9a820c8c,0x9a8408c0,0x9a85074f,0x9a860c68,
	0x9a87069d,0x9a880ed5,0x9a8a0b1b,0x9a8b0244,0x9a8c1660,0x9a8f09e0,0x9a900f4e,0x9a910f3a,
	0x9a920a34,0x9a9319eb,0x9a96018e,0x9a970eda,0x9a981977,0x9a9a10ee,0x9a9b147e,0x9a9c003a,
	0x9a9d0bea,0x9a9e0f86,0x9a9f1128,0x9aa00120,0x9aa10c5d,0x9aa202e6,0x9aa301e7,0x9aa419a2,
	0x9aa5083a,0x9aa71517,0x9aa80624,0x9ab0137a,0x9ab1090d,0x9ab603a8,0x9ab70a55,0x9ab80697,
	0x9aba0716,0x9abc05ca,0x9ac000fe,0x9ac10a27,0x9ac20f76,0x9ac50c0e,0x9acb0a6c,0x9acc013e,
	0x9ad10421,0x9ad3128b,0x9ad805a1,0x9adf011f,0x9ae10a9e,0x9ae60cbc,0x9aeb1345,0x9aed1a1f,
	0x9aef1072,0x9af915a3,0x9afb0839,0x9b031a35,0x9b08105a,0x9b0f0966,0x9b13013f,0x9b1f0767,
	0x9b230bad,0x9b2f0203,0x9b3205c1,0x9b3b1805,0x9b3c066e,0x9b410a8a,0x9b4207be,0x9b430054,
	0x9b440f10,0x9b450cea,0x9b471657,0x9b481539,0x9b490b88,0x9b4d13e9,0x9b4f1429,0x9b510250,
	0x9b540d6f,0x9c7c17ba,0x9c7f1796,0x9c810c27,0x9c8204c7,0x9c85005b,0x9c860f01,0x9c870dee,
	0x9c880c23,0x9c8b0563,0x9c8d009f,0x9c8e071e,0x9c9012c5,0x9c910667,0x9c9208ff,0x9c94141a,
	0x9c95048f,0x9c9a0835,0x9c9b08c7,0x9c9c14ea,0x9c9e1522,0x9c9f1603,0x9ca005e3,0x9ca10b24,
	0x9ca20b6d,0x9ca30873,0x9ca40b34,0x9ca511a4,0x9ca61346,0x9ca70681,0x9ca81107,0x9ca90777,
	0x9cab0837,0x9cad0ffb,0x9cae0bda,0x9cb01a3f,0x9cb104d6,0x9cb20aa0,0x9cb301f1,0x9cb40636,
	0x9cb50de0,0x9cb60def,0x9cb703d5,0x9cb80940,0x9cba1198,0x9cbb1a20,0x9cbc04fc,0x9cbd03ea,
	0x9cc310de,0x9cc40487,0x9cc51019,0x9cc60566,0x9cc7078d,0x9cca0108,0x9ccb10f1,0x9ccc0038,
	0x9ccd0f58,0x9cce12b6,0x9ccf064b,0x9cd01698,0x9cd30afc,0x9cd4012a,0x9cd515ef,0x9cd6012c,
	0x9cd70c9e,0x9cd80d56,0x9cd91776,0x9cdc0678,0x9cdd1130,0x9cde0bbb,0x9cdf1a5b,0x9ce20b37,
	0x9e1f0dfa,0x9e200961,0x9e2107e2,0x9e221806,0x9e230d59,0x9e250e44,0x9e261613,0x9e280097,
	0x9e291916,0x9e2a0613,0x9e2b0404,0x9e2c0c20,0x9e2d1615,0x9e2f1670,0x9e310249,0x9e32103b,
	0x9e331809,0x9e3513ab,0x9e361233,0x9e371971,0x9e38048e,0x9e39063a,0x9e3a15a0,0x9e3d05b9,
	0x9e3e0c44,0x9e3f070c,0x9e410161,0x9e420b1e,0x9e4309ad,0x9e440628,0x9e450471,0x9e4617fb,
	0x9e4714f5,0x9e481321,0x9e49146c,0x9e4a106b,0x9e4b0d34,0x9e4c001e,0x9e4e00a8,0x9e4f0ea0,
	0x9e5102c7,0x9e550734,0x9e570485,0x9e58061d,0x9e5a02db,0x9e5b0cdf,0x9e5c1481,0x9e5e16a0,
	0x9e630874,0x9e6406ef,0x9e66174d,0x9e6718fa,0x9e680bf5,0x9e690b99,0x9e6a08ca,0x9e6b0978,
	0x9e6c1804,0x9e6d0c3c,0x9e70174f,0x9e710749,0x9e730654,0x9e7e031d,0x9e7f0c32,0x9e820818,
	0x9e8709da,0x9e8819c1,0x9e8b0d0f,0x9e920f59,0x9e930c3d,0x9e9d1161,0x9e9f0bbc,0x9ea60c96,
	0x9eb41036,0x9eb8051a,0x9ebb0c84,0x9ebd0cd0,0x9ebe0799,0x9ec40780,0x9ec9070d,0x9ecd11f5,
	0x9ece0b25,0x9ecf0df0,0x9ed106f1,0x9ed40f93,0x9ed80d7f,0x9edb0346,0x9edc02a1,0x9edd17a0,
	0x9edf16c6,0x9ee014da,0x9ee21037,0x9ee51001,0x9ee70b29,0x9ee90428,0x9eea0194,0x9eef002a,
	0x9ef91958,0x9efb0542,0x9efc0550,0x9efe0d4d,0x9f0b1816,0x9f0d13af,0x9f0e03f6,0x9f100db3,
	0x9f130629,0x9f17130c,0x9f190ec0,0x9f2011f7,0x9f2204f4,0x9f2c17ac,0x9f2f145f,0x9f3714b2,
	0x9f391658,0x9f3b00d0,0x9f3d1029,0x9f3e06a4,0x9f441895,0x9f500f3f,0x9f5107f3,0x9f7f025c,
	0x9f800229,0x9f830991,0x9f840bd9,0x9f850091,0x9f861343,0x9f871a1e,0x9f881735,0x9f8917e2,
	0x9f8a02d0,0x9f8b1046,0x9f8c144d,0x9f990bf6,0x9f9a05ef,0x9f9b09f8,0x9f9f0661,0x9fa01833,
	0xff011a6b,0xff021a6c,0xff031a6d,0xff041a6e,0xff051a6f,0xff061a70,0xff071a71,0xff081a72,
	0xff091a73,0xff0a1a74,0xff0b1a75,0xff0c1a76,0xff0d1a77,0xff0e1a78,0xff0f1a79,0xff101a7a,
	0xff111a7b,0xff121a7c,0xff131a7d,0xff141a7e,0xff151a7f,0xff161a80,0xff171a81,0xff181a82,
	0xff191a83,0xff1a1a84,0xff1b1a85,0xff1c1a86,0xff1d1a87,0xff1e1a88,0xff1f1a89,0xff201a8a,
	0xff211a8b,0xff221a8c,0xff231a8d,0xff241a8e,0xff251a8f,0xff261a90,0xff271a91,0xff281a92,
	0xff291a93,0xff2a1a94,0xff2b1a95,0xff2c1a96,0xff2d1a97,0xff2e1a98,0xff2f1a99,0xff301a9a,
	0xff311a9b,0xff321a9c,0xff331a9d,0xff341a9e,0xff351a9f,0xff361aa0,0xff371aa1,0xff381aa2,
	0xff391aa3,0xff3a1aa4,0xff3b1aa5,0xff3d1aa6,0xff3e1aa7,0xff3f1aa8,0xff401aa9,0xff411aaa,
	0xff421aab,0xff431aac,0xff441aad,0xff451aae,0xff461aaf,0xff471ab0,0xff481ab1,0xff491ab2,
	0xff4a1ab3,0xff4b1ab4,0xff4c1ab5,0xff4d1ab6,0xff4e1ab7,0xff4f1ab8,0xff501ab9,0xff511aba,
	0xff521abb,0xff531abc,0xff541abd,0xff551abe,0xff561abf,0xff571ac0,0xff581ac1,0xff591ac2,
	0xff5a1ac3,0xff5b1ac4,0xff5c1ac5,0xff5d1ac6,0xff5e1ac7,
	};

static const TCollationKeyTable TheChineseTable = 
	{ TheChineseKey, TheChineseIndex, 6861, NULL, NULL, 0 };

static const TCollationMethod TheChineseMethod =
	{ 0, NULL, &TheChineseTable, 0 };

void test_unicode_collations()
	{
	/*
	Note: the curious method of getting values greater than 255 into the strings is needed
	because GCC doesn't handle the \x notation properly: it zeroes the high byte, so
	L"\x2011" puts the value 0x0011, not 0x2011, into the string.
	*/
	TBuf<32> x, y;

	test.Next(_L("collation"));
	test_unicode_collation(_L("Graham"),_L("Graham"),0);		// equality
	test_unicode_collation(_L("something"),_L(""),1);			// something after nothing
	test_unicode_collation(_L("inform"),_L("information"),-1);	// prefixes come first
 	test_unicode_collation(_L("\x30CB\x30e5\x30fc"),_L("\x30CB\x30e5\x30fc\x30e0"),-1); // Katakana 
	test_unicode_collation(_L("\x3042\x308a"),_L("\x3042\x308a\x304c\x3068"),-1); // Hiragana
	test_unicode_collation(_L("unicode"),_L("consortium"),1);	// standard alphabetic ordering: lowercase
	test_unicode_collation(_L("AARON"),_L("AARDVARK"),1);		// standard alphabetic ordering: uppercase
	test_unicode_collation(_L("AARON"),_L("AARDVARK"),1,0);		// alphabetic ordering is significant at level 0
	test_unicode_collation(_L("hello"),_L("Hello"),1,3,&TheSwapCaseMethod);			// lowercase before uppercase
	test_unicode_collation(_L("hello"),_L("Hello"),-1,2);		// case is significant at level 2
	//test_unicode_collation(_L("hello"),_L("Hello"),0,1);		// ignore case at level 1
	test_unicode_collation(_L("hello"),_L("Hello"),0,1);
	test_unicode_collation(_L("hello"),_L("[H E L L O !]"),0,1);// ignore punctuation and case at level 1
	test_unicode_collation(_L("1234"),_L("abc"),-1);			// digits before letters
	x = _L("week day"); x[4] = 0x2011;							// (week-day with non-breaking hyphen)
	test_unicode_collation(x,_L("weekend"),-1);					// ignore punctuation if letters differ; d < e
	test_unicode_collation(x,_L("week-day"),1);					// compare punctuation if otherwise equal
	test_unicode_collation(x,_L("week-day"),0,2);				// ignore difference between hyphens at level 2
	test_unicode_collation(x,_L("Week-day"),-1);				// case difference outweighs punctuation ordering
	y = _L("a ngstro m"); y[1] = 0x30a; y[8] = 0x308;			// (a<ring>ngstro<umlaut>m with piece accents)
	test_unicode_collation(_L("\xe5ngstr\xf6m"),y,0);			// base+accent = precomposed (a<ring>ngstro<umlaut>m)
	test_unicode_collation(_L("Liege"),_L("Li\xe8ge"),-1);		// unaccented before accented...
	test_unicode_collation(_L("Liege"),_L("Li\xe8ge"),-1,1);	// accents are significant at level 1
	test_unicode_collation(_L("Liege"),_L("li\xe8ge"),-1);		// accentuation outweighs case
	test_unicode_collation(_L("Liege"),_L("li\xe8ge"),0,0);		// ignore accents and case at level 0
	test_unicode_collation(_L("\xe5ngstr\xf6m"),_L("zoo"),-1);	// a-ring before z by default
	// test_unicode_collation(_L("\xe5ngstr\xf6m"),_L("zoo"),1,3,&TheSwedishMethod);	// a-ring after z in Sweden
	test_unicode_collation(_L("Antidisestablishmentarian"),_L("antidisestablishmentariac"),1); 	// long strings that don't have identical prefixes
	
	test_unicode_collation(_L("\xFF86"),_L(""),1);
	test_unicode_collation(_L("\x30B9"),_L(""),1);
	// Equality 
	test_unicode_collation(_L("\xFF71"),_L("\xFF71"),0,3,&TheKanaMethod);  // Same Halfwidth Katakana characters
	test_unicode_collation(_L("\x30A2"),_L("\x30A2"),0,3,&TheKanaMethod);  // Same Katakana characters
	test_unicode_collation(_L("\xFF71\xFF67"),_L("\xFF71\xFF67"),0,3,&TheKanaMethod); // Same katakana Characters with small letter
	test_unicode_collation(_L("\x30b9\x30af\x30ea\x30fc\x30e0"),_L("\x30b9\x30af\x30ea\x30fc\x30e0"),0,3,&TheKanaMethod); // Scream in Katakana
	test_unicode_collation(_L("\x3042"),_L("\x3042"),0,3,&TheKanaMethod);  // same Hiragana characters
	test_unicode_collation(_L("\x3042\x308A"),_L("\x3042\x308A"),0,3,&TheKanaMethod); 
	test_unicode_collation(_L("\x304C"),_L("\x304B\x3099"),0,3,&TheKanaMethod);
	test_unicode_collation(_L("\x3072\x3063\x304f"),_L("\x3072\x3063\x304f"),0,3,&TheKanaMethod); // Hiragana word Hyaku
	// 1/2 width Katakana is sorted before Katakana 
	test_unicode_collation(_L("\xFF71"),_L("\x30A2"),-1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x30A2"),_L("\xFF71"), 1,3,&TheKanaMethod);
	test_unicode_collation(_L("\xFF86\xFF6D\xFF70\xFF7D"),_L("\x30CB\x30E5\x30FC\x30B9"),-1,3,&TheKanaMethod); // News Katakan 1/2 width & full width..this shoule be -1
	// 1/2 width katakana sorted before half width with small character;
	test_unicode_collation(_L("\xFF71"),_L("\xFF71\xFF67"),-1,3,&TheKanaMethod);  // same katakana characcter, one with a small character
	test_unicode_collation(_L("\xFF77"),_L("\xFF71\xFF6C"),1,3,&TheKanaMethod); // different Katakana character, one with small character 
	// Hiragana before Katakana & 1/2 width Katakana
	test_unicode_collation(_L("\x3042"),_L("\x30a2"),-1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x3042"),_L("\x30a2"),1,3,&TheSwapKanaMethod);
	test_unicode_collation(_L("\x3042"),_L("\x30cb"),-1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x308a"),_L("\x30a2\x30ea\x30e0"),1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x3042\x308a"),_L("\x30a2\x30ea"),-1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x3042\x308a\x304c\x3068"),_L("\xFF71\xFF86\xFF6D\xFF70\xff7D"),1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x3042"),_L("\xFF71"),-1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x3042\x308a"),_L("\x30a2\x30ea\x30e0\x30b9"),-1,3,&TheKanaMethod);

	// Test Katakana Nigori and Maru Sort sequence
	test_unicode_collation(_L("\xff8a"),_L("\xff8A\xff9e"),-1,3,&TheKanaMethod);
	test_unicode_collation(_L("\xff8a"),_L("\xff8a\xff9f"),-1,3,&TheKanaMethod);
	test_unicode_collation(_L("\xff8a\xff9e"),_L("\xff8a\xff9f"),-1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x30cf"),_L("\x30d0"),-1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x30cf"),_L("\x30d1"),-1,3,&TheKanaMethod); 
	test_unicode_collation(_L("\x30d1"),_L("\x30d0"),1,3,&TheKanaMethod); 
	test_unicode_collation(_L("\x306f"),_L("\x3070"),-1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x306f"),_L("\x3071"),-1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x3070"),_L("\x3071"),-1,3,&TheKanaMethod);
	test_unicode_collation(_L("\xff8a"),_L("\x30cf"),-1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x3071"),_L("\x3068"),1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x306f"),_L("\x30d1"),-1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x306f"),_L("\xff8a"),-1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x3070"),_L("\xff8a\xff9e"),-1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x3071"),_L("\xff8a\xff9f"),-1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x3042\x304e\x3089"),_L("\x3044"),-1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x3070"),_L("\x30cf"),1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x30cf"),_L("\x3070"),-1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x3070"),_L("\xff8a"),1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x3071"),_L("\xff8a"),1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x30d1"),_L("\x3071"),1,3,&TheKanaMethod);
	
	test_unicode_collation(_L("\x30ac"),_L("\x30ab"),1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x30a2\x30ac"),_L("\x30a2\x30ab"),1,3,&TheKanaMethod); // ka comes before Ga
	test_unicode_collation(_L("\x306b\x3058\x3085"),_L("\x306b\x3057\x308c"),-1,3,&TheKanaMethod);
	
	// Triplet support test 
	test_unicode_collation(_L("\x30ac\x30fc"),_L("\x30ae\x30fc"),-1,3,&TheKanaMethod);
	test_unicode_collation(_L("\x30ab\x30fc"),_L("\x30ab\x30fc"),0,3,&TheKanaMethod);
	test_unicode_collation(_L("\x30ab\x30a4"),_L("\x30ab\x30fc"),1,3,&TheKanaMethod);  
	test_unicode_collation(_L("\x30ab\x30a4"),_L("\x30ac"),1,3,&TheKanaMethod);
	
	//Simplified Chinese test starts. Note that the Chinese collation table only includes the ideological characters. 
	//The characters which are in the base table should come to the front while the characters which are not either 
	//in base table or client table should come after
	test.Next(_L("Simplified Chinese test starts"));
	test_unicode_collation(_L("\x554a"),_L("\x4f4f"),-1,3,&TheChineseMethod);//different sound
	test_unicode_collation(_L("\x54ed"),_L("\x5757"),-1,3,&TheChineseMethod);//different sound
	test_unicode_collation(_L("\x8d30"),_L("\x82ac"),-1,3,&TheChineseMethod);//different sound
	test_unicode_collation(_L("\x62bd"),_L("\x6577"),-1,3,&TheChineseMethod);//different sound
	test_unicode_collation(_L("\x75c5"),_L("\x7e94"),-1,3,&TheChineseMethod);//different sound
//same sound
	test_unicode_collation(_L("\x78e8"),_L("\x672b"),-1,3,&TheChineseMethod);//different tones
	test_unicode_collation(_L("\x5e9c"),_L("\x7236"),-1,3,&TheChineseMethod);//different tones
	test_unicode_collation(_L("\x7840"),_L("\x5904"),-1,3,&TheChineseMethod);//different tones
	test_unicode_collation(_L("\x5976"),_L("\x8010"),-1,3,&TheChineseMethod);//different tones
	test_unicode_collation(_L("\x7720"),_L("\x9762"),-1,3,&TheChineseMethod);//different tones
//same sound and stroke count
	test_unicode_collation(_L("\x5757"),_L("\x5feb"),-1,3,&TheChineseMethod);//different first stroke
	test_unicode_collation(_L("\x51b3"),_L("\x8bc0"),-1,3,&TheChineseMethod);//different first stroke
	test_unicode_collation(_L("\x5316"),_L("\x4ee4"),-1,3,&TheChineseMethod);//different first stroke
	test_unicode_collation(_L("\x62df"),_L("\x4f60"),1,3,&TheChineseMethod);//different radical
	test_unicode_collation(_L("\x6d1b"),_L("\x9a86"),-1,3,&TheChineseMethod);//different first stroke
//smae sound and same tones
	test_unicode_collation(_L("\x5757"),_L("\x4fa9"),-1,3,&TheChineseMethod);//different stroke count
	test_unicode_collation(_L("\x51e1"),_L("\x7e41"),-1,3,&TheChineseMethod);//different stroke count
	test_unicode_collation(_L("\x98ce"),_L("\x950b"),-1,3,&TheChineseMethod);//different stroke count
	test_unicode_collation(_L("\x5e01"),_L("\x5e87"),-1,3,&TheChineseMethod);//different stroke count
	test_unicode_collation(_L("\x529e"),_L("\x534a"),-1,3,&TheChineseMethod);//different stroke count
//compare the Chinese ideological characters to other characters which are not included in the Chinese collation table
	test_unicode_collation(_L("abc"),_L("\x4f4f"),-1,3,&TheChineseMethod);//compare alphabets to Chinese character
	test_unicode_collation(_L("zxc"),_L("\x4f4f"),-1,3,&TheChineseMethod);//compare alphabets to Chinese character
	test_unicode_collation(_L("\x3041"),_L("\x4f4f"),1,3,&TheChineseMethod);//compare a Hiragana to Chinese characters
	test_unicode_collation(_L("\x30f6"),_L("\x4f4f"),1,3,&TheChineseMethod);//compare a Katakana to Chinese characters
	test_unicode_collation(_L("\x3041"),_L("\x30f6"),-1,3,&TheChineseMethod);//compare a Hiragana to a Katakana
//compare two group of chinese characters
	test_unicode_collation(_L("\x8584\x554a"),_L("\x8584\x4f4f"),-1,3,&TheChineseMethod);//the first chinese character is the same
	test_unicode_collation(_L("\x5b89\x95ed"),_L("\x5b89\x6b65"),-1,3,&TheChineseMethod);//the first chinese character is the same
	test_unicode_collation(_L("\x60b2\x7c3f"),_L("\x60b2\x5e9c"),-1,3,&TheChineseMethod);//the first chinese character is the same
	test_unicode_collation(_L("\x8336\x5e01"),_L("\x8336\x5e87"),-1,3,&TheChineseMethod);//the first chinese character is the same
	test_unicode_collation(_L("\x4ea7\x529e"),_L("\x4ea7\x534a"),-1,3,&TheChineseMethod);//the first chinese character is the same

	test_unicode_collation(_L("\x3041\x554a"),_L("\x3041\x4f4f"),-1,3,&TheChineseMethod);//the first Hiragana is the same
	test_unicode_collation(_L("\x3063\x6bd4"),_L("\x3063\x660c"),-1,3,&TheChineseMethod);//the first Hiragana is the same
	test_unicode_collation(_L("\x30b7\x5999"),_L("\x30b7\x6728"),-1,3,&TheChineseMethod);//the first Katakana is the same
	test_unicode_collation(_L("\x3041\x534a"),_L("\x3041\x907e"),-1,3,&TheChineseMethod);//the first Katakana is the same

	test_unicode_collation(_L("\x3041\x554a"),_L("\x30f6\x4f4f"),-1,3,&TheChineseMethod);//the first symbole is different
	test_unicode_collation(_L("\x3041\x4fbc"),_L("\x3063\x5068"),-1,3,&TheChineseMethod);//the first symbole is different
	test_unicode_collation(_L("\x30b7\x6478"),_L("\x30c2\x51dd"),-1,3,&TheChineseMethod);//the first symbole is different
	test_unicode_collation(_L("\x3046\x5ff5"),_L("\x30ea\x5b81"),-1,3,&TheChineseMethod);//the first symbole is different
	test_unicode_collation(_L("\x3072\x7aed"),_L("\x254b\x670d"),1,3,&TheChineseMethod);//the first symbole is different
//compare full width and half width digits and letters
	test_unicode_collation(_L("\xff11"),_L("\x0031"),1,3,&TheChineseMethod);//full width "1" comes after half width "1"
	test_unicode_collation(_L("\x0032"),_L("\xff11"),1,3,&TheChineseMethod);//half width "2" comes after full width "1"
	test_unicode_collation(_L("\xff21"),_L("\x0061"),1,3,&TheChineseMethod);//full width "a" comes after half width "a"
	test_unicode_collation(_L("\x0062"),_L("\xff21"),1,3,&TheChineseMethod);//half width "b" comes after full width "a"
	}

_LIT(KFoo1, "foo");
_LIT(KFoo2, "FOO");
_LIT(KFoo3, "Foo");
_LIT(KNotFoo1, "fo\x300o");
_LIT(KNotFoo2, "foo ");
_LIT(KNotFoo3, "foo\x300");
_LIT(KNotFoo4, "fo,o");
_LIT(KSigma1, "\x3C3");
_LIT(KSigma2, "\x3C2");
_LIT(KSigma3, "\x3A3");
_LIT(KPeach, "pe\x302\x63he");
_LIT(KFish, "pe\x301\x63he\x301");

TInt CompareIWrapper(const TDesC& a, const TDesC& b)
	{
#if 0
	return a.CompareIdentifiers(b);
#else
	TCollationMethod method;
	method.iMainTable = 0;
	method.iOverrideTable = 0;
	method.iFlags = TCollationMethod::EIgnoreNone | TCollationMethod::EFoldCase;
	return a.CompareC(b, 2, &method);
#endif
	}

void test_identifiers()
	{
	// test that comparison is as expected
	test(0 == CompareIWrapper(KFoo1, KFoo1));
	test(0 == CompareIWrapper(KFoo1, KFoo3));
	test(0 == CompareIWrapper(KFoo2, KFoo3));
	test(0 == CompareIWrapper(KFoo2, KFoo1));
	test(0 == CompareIWrapper(KFoo3, KFoo1));
	test(0 == CompareIWrapper(KFoo3, KFoo2));
	test(0 != CompareIWrapper(KFoo1, KNotFoo1));
	test(0 != CompareIWrapper(KNotFoo2, KFoo1));
	test(0 != CompareIWrapper(KFoo1, KNotFoo3));
	test(0 != CompareIWrapper(KNotFoo4, KFoo1));
	test(0 == CompareIWrapper(KSigma1, KSigma2));
	test(0 == CompareIWrapper(KSigma1, KSigma3));
	test(0 != CompareIWrapper(KPeach, KFish));
	}

// This whole test should first use the japanese collation lookup table and if not found what it was 
// looking for then it will search the basic standard table ... 


GLDEF_C TInt E32Main(void)
    {

	test.Title();
	test.Start(_L("TCollate Testing"));

	test_unicode_collations();
	test_identifiers();

	test.End();
	return(KErrNone);
    }

#pragma warning ( default :4700)
#pragma warning ( default :4710) 
